!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-28 18:17             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 4015
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: UaVUV0 = 1
  integer, parameter :: FFaS0 = 2
  integer, parameter :: FFaS1 = 3
  integer, parameter :: FFaS2 = 4
  integer, parameter :: FFaV0 = 5
  integer, parameter :: FFaV1 = 6
  integer, parameter :: SVVS0 = 7
  integer, parameter :: UaSSU0 = 8
  integer, parameter :: UaUSS0 = 9
  integer, parameter :: UUaS0 = 10
  integer, parameter :: UUaV0 = 11
  integer, parameter :: UUaV1 = 12
  integer, parameter :: SUSUa0 = 13
  integer, parameter :: SUUaS0 = 14
  integer, parameter :: SUUa0 = 15
  integer, parameter :: SSUUa0 = 16
  integer, parameter :: VVSS0 = 17
  integer, parameter :: FaF0 = 18
  integer, parameter :: FaF1 = 19
  integer, parameter :: FaF2 = 20
  integer, parameter :: USSUa0 = 21
  integer, parameter :: VFaF0 = 22
  integer, parameter :: VFaF1 = 23
  integer, parameter :: SUaSU0 = 24
  integer, parameter :: VVV0 = 25
  integer, parameter :: VVV1 = 26
  integer, parameter :: FSFa0 = 27
  integer, parameter :: FSFa1 = 28
  integer, parameter :: FSFa2 = 29
  integer, parameter :: VVVV0 = 30
  integer, parameter :: VVVV1 = 31
  integer, parameter :: VUaU0 = 32
  integer, parameter :: VUaU1 = 33
  integer, parameter :: VVUUa0 = 34
  integer, parameter :: FaVF0 = 35
  integer, parameter :: FaVF1 = 36
  integer, parameter :: UUaVV0 = 37
  integer, parameter :: UaVU0 = 38
  integer, parameter :: SUaUS0 = 39
  integer, parameter :: FVFa0 = 40
  integer, parameter :: FVFa1 = 41
  integer, parameter :: UaSUS0 = 42
  integer, parameter :: FaFS0 = 43
  integer, parameter :: FaFS1 = 44
  integer, parameter :: FaFS2 = 45
  integer, parameter :: USUa0 = 46
  integer, parameter :: SV0 = 47
  integer, parameter :: VUVUa0 = 48
  integer, parameter :: VV0 = 49
  integer, parameter :: VV1 = 50
  integer, parameter :: VV2 = 51
  integer, parameter :: VV3 = 52
  integer, parameter :: UaVVU0 = 53
  integer, parameter :: SVSV0 = 54
  integer, parameter :: UaSU0 = 55
  integer, parameter :: FFa0 = 56
  integer, parameter :: FFa1 = 57
  integer, parameter :: FFa2 = 58
  integer, parameter :: FaFV0 = 59
  integer, parameter :: FaFV1 = 60
  integer, parameter :: SSSS0 = 61
  integer, parameter :: VUaUV0 = 62
  integer, parameter :: UVUaV0 = 63
  integer, parameter :: VS0 = 64
  integer, parameter :: SFFa0 = 65
  integer, parameter :: SFFa1 = 66
  integer, parameter :: SFFa2 = 67
  integer, parameter :: VUUa0 = 68
  integer, parameter :: VUUa1 = 69
  integer, parameter :: SFaF0 = 70
  integer, parameter :: SFaF1 = 71
  integer, parameter :: SFaF2 = 72
  integer, parameter :: VVS0 = 73
  integer, parameter :: SVV0 = 74
  integer, parameter :: FaSF0 = 75
  integer, parameter :: FaSF1 = 76
  integer, parameter :: FaSF2 = 77
  integer, parameter :: SVS0 = 78
  integer, parameter :: VVUaU0 = 79
  integer, parameter :: VUUaV0 = 80
  integer, parameter :: UaUVV0 = 81
  integer, parameter :: VSS0 = 82
  integer, parameter :: VSS1 = 83
  integer, parameter :: VSV0 = 84
  integer, parameter :: SS0 = 85
  integer, parameter :: SS1 = 86
  integer, parameter :: SS2 = 87
  integer, parameter :: SSVV0 = 88
  integer, parameter :: SSV0 = 89
  integer, parameter :: SSV1 = 90
  integer, parameter :: UVVUa0 = 91
  integer, parameter :: SSS0 = 92
  integer, parameter :: UVUa0 = 93
  integer, parameter :: SSUaU0 = 94
  integer, parameter :: VSSV0 = 95
  integer, parameter :: VUaVU0 = 96
  integer, parameter :: VSVS0 = 97
  integer, parameter :: USUaS0 = 98
  integer, parameter :: UaUS0 = 99
  integer, parameter :: VFFa0 = 100
  integer, parameter :: VFFa1 = 101
  integer, parameter :: UUaSS0 = 102
  integer, parameter :: SUaU0 = 103
  integer, parameter :: UaUV0 = 104
  integer, parameter :: UaUV1 = 105
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c4f = "1/2"
  complex(dp), parameter :: c5 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c5f = "-1/2"
  complex(dp), parameter :: c6 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c6f = "i_*sq2/2"
  complex(dp), parameter :: c7 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c7f = "-i_*sq2/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:105) :: lorentz_rank = (/0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1&
                                              , 1, 0, 0, 0, 0, 0, -1, -1, -1, 0&
                                              , 1, 1, 0, 1, 1, 1, 1, 1, 0, 0, 1&
                                              , 1, 0, 1, 1, 0, 1, 0, 1, 1, 0, 0&
                                              , 0, 0, 0, -1, 0, -1, -1, -1, -1 &
                                              , 0, 0, 0, -1, -1, -1, 0, 0, 0, 0&
                                              , 0, -1, 1, 1, 1, 1, 1, 1, 1, 1, &
                                              0, 0, 1, 1, 1, 1, 0, 0, 0, 1, 1, &
                                              0, -1, -1, -1, 0, 1, 1, 0, 0, 1, &
                                              0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, &
                                              1/)
  integer, dimension(1:105) :: recola_base = (/-14, 5, 9, 7, 15, 17, -2, -1, -1&
                                             , 1, 0, 161, -1, -1, 1, -1, -4, 0 &
                                             , 0, 0, -1, 53, 58, -1, 160, 12,  &
                                             21, 25, 27, -11, -111, 0, 162, -4 &
                                             , 57, 51, -12, 0, -1, 31, 35, -1, &
                                             6, 10, 8, 1, 0, -3, 0, 0, 0, 0, -2&
                                             , -14, 1, 0, 0, 0, 18, 16, -1, -13&
                                             , -14, 0, 23, 26, 28, 0, 163, 43, &
                                             46, 48, 2, 13, 41, 45, 47, 3, -4  &
                                             , -13, -12, 0, 4, 14, 0, 0, 0, -12&
                                             , 0, 11, -2, 1, 0, -1, -13, -3, -3&
                                             , -1, 1, 36, 33, -1, 1, 0, 164/)
  integer, dimension(1:105) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0/)
  character(len=*), parameter :: model_timestamp = "Wed Nov 28 18:03:37 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(8017)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 922, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 877, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 485, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_G0, 296, check)
      call createCurrent(P_ghG, P_g, P_g, P_ghGAnti, 3207, check)
      call createCurrent(P_t, P_tAnti, P_g, 3298, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_H, P_GPlus, 1973, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 1623, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WMinus, P_WPlus, 1639, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 1606, check)
      call createCurrent(P_ghWpAnti, P_H, P_GPlus, P_ghZ, 3520, check)
      call createCurrent(P_H, P_ghZ, P_H, P_ghZAnti, 442, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghA, P_WQMinus, 3099, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_WPlus, P_ghZ, 2543, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_H, 2699, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 522, check)
      call createCurrent(P_ghZAnti, P_G0, P_GPlus, P_ghWm, 1529, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_A, P_WPlus, 2626, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_A, P_WPlus, 1737, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GQMinus, 831, check)
      call createCurrent(P_H, P_ghA, P_ghWmAnti, P_GMinus, 3532, check)
      call createCurrent(P_GQMinus, P_H, P_ghWmAnti, P_ghA, 154, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_H, P_ghWp, 2111, check)
      call createCurrent(P_AQ, P_WPlus, P_WMinus, P_AQ, 3248, check)
      call createCurrent(P_GQPlus, P_ghA, P_GMinus, P_ghZAnti, 1536, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 241, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_GPlus, 1894, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WPlus, P_WMinus, 1310, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_GMinus, 142, check)
      call createCurrent(P_s, P_sAnti, P_H, 70, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWm, P_ghWmAnti, 2305, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_GQ0, 2782, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWm, P_WQPlus, 3653, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_HQ, 1519, check)
      call createCurrent(P_ghA, P_GMinus, P_GPlus, P_ghAAnti, 1398, check)
      call createCurrent(P_ZQ, P_ghZAnti, P_WMinus, P_ghWp, 3451, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_GPlus, 936, check)
      call createCurrent(P_g, P_cAnti, P_c, 1945, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 1087, check)
      call createCurrent(P_GMinus, P_ghWp, P_G0, P_ghAAnti, 1027, check)
      call createCurrent(P_G0, P_GMinus, P_ghZ, P_ghWmAnti, 2425, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_GQPlus, 2900, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_AQ, 1815, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_H, 90, check)
      call createCurrent(P_GQ0, P_WMinus, P_WPlus, P_GQ0, 3489, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 459, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghZAnti, P_GMinus, 3304, check)
      call createCurrent(P_Z, P_ghAAnti, P_ghWp, P_WMinus, 2070, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_GQ0, 1931, check)
      call createCurrent(P_ZQ, P_WMinus, P_H, P_GQPlus, 2194, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWpAnti, P_WQPlus, 1210, check)
      call createCurrent(P_GMinus, P_ghWp, P_H, P_ghAAnti, 2609, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_AQ, 2119, check)
      call createCurrent(P_sAnti, P_g, P_s, 304, check)
      call createCurrent(P_WQMinus, P_u, P_dAnti, 2181, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 2477, check)
      call createCurrent(P_HQ, P_ghWpAnti, P_G0, P_ghWp, 3112, check)
      call createCurrent(P_eMinus, P_ePlus, P_ZQ, 2858, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghWm, P_GPlus, 2746, check)
      call createCurrent(P_WQPlus, P_A, P_WQMinus, 1265, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 3955, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 1475, check)
      call createCurrent(P_GQ0, P_H, P_GMinus, P_GQPlus, 884, check)
      call createCurrent(P_ZQ, P_H, P_GMinus, P_WQPlus, 2447, check)
      call createCurrent(P_AQ, P_t, P_tAnti, 2905, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 2352, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghAAnti, P_ghA, 2338, check)
      call createCurrent(P_ghZ, P_WPlus, P_WMinus, P_ghZAnti, 3551, check)
      call createCurrent(P_ghWm, P_ghWpAnti, P_WPlus, P_WQPlus, 1267, check)
      call createCurrent(P_GQ0, P_G0, P_G0, P_GQ0, 2982, check)
      call createCurrent(P_WPlus, P_ghZ, P_WMinus, P_ghZAnti, 808, check)
      call createCurrent(P_HQ, P_H, P_GPlus, P_GQMinus, 2480, check)
      call createCurrent(P_WQMinus, P_H, P_WQPlus, 842, check)
      call createCurrent(P_H, P_ghZAnti, P_ghWp, P_GMinus, 2499, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_GQPlus, 1426, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 2432, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, P_H, 3500, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 2915, check)
      call createCurrent(P_ghWp, P_H, P_GMinus, P_ghAAnti, 2790, check)
      call createCurrent(P_HQ, P_ghWpAnti, P_GPlus, P_ghZ, 447, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 886, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_H, P_ghWp, 1773, check)
      call createCurrent(P_ghA, P_WPlus, P_ghAAnti, P_WMinus, 2221, check)
      call createCurrent(P_HQ, P_GPlus, P_ghZ, P_ghWpAnti, 3, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 945, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghWp, P_ghZAnti, 278, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 2426, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_GQMinus, 458, check)
      call createCurrent(P_HQ, P_ePlus, P_eMinus, 3665, check)
      call createCurrent(P_ghWmAnti, P_WPlus, P_WMinus, P_ghWm, 1782, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 517, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 2956, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_HQ, 1844, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 168, check)
      call createCurrent(P_cAnti, P_s, P_WQPlus, 3474, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 2399, check)
      call createCurrent(P_d, P_dAnti, P_GQ0, 3722, check)
      call createCurrent(P_HQ, P_H, P_ghZ, P_ghZAnti, 2199, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_ghWm, 65, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 2558, check)
      call createCurrent(P_AQ, P_G0, P_WPlus, P_GQMinus, 2832, check)
      call createCurrent(P_GQPlus, P_ghA, P_ghWpAnti, 213, check)
      call createCurrent(P_WQPlus, P_cAnti, P_s, 967, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_GQPlus, 859, check)
      call createCurrent(P_d, P_uAnti, P_WQPlus, 271, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WMinus, P_WPlus, 3178, check)
      call createCurrent(P_H, P_GPlus, P_ghWm, P_ghAAnti, 977, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_H, 163, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_A, 2745, check)
      call createCurrent(P_d, P_dAnti, 3832, check)
      call createCurrent(P_HQ, P_ghWm, P_G0, P_ghWmAnti, 3802, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 3903, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_GMinus, 2265, check)
      call createCurrent(P_ghWm, P_H, P_GPlus, P_ghZAnti, 2837, check)
      call createCurrent(P_HQ, P_G0, P_ZQ, 3108, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, P_Z, 3365, check)
      call createCurrent(P_H, P_ghAAnti, P_ghWm, P_GPlus, 1663, check)
      call createCurrent(P_GQMinus, P_ghWp, P_G0, P_ghZAnti, 645, check)
      call createCurrent(P_WMinus, P_ghWm, P_ghWmAnti, P_WPlus, 2567, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_GMinus, P_ghZ, 1627, check)
      call createCurrent(P_GQMinus, P_ghZ, P_GPlus, P_ghAAnti, 3723, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 574, check)
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 1732, check)
      call createCurrent(P_ghA, P_WPlus, P_ghAAnti, P_WQMinus, 3554, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, P_A, 1963, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_H, 1412, check)
      call createCurrent(P_GMinus, P_G0, P_ghWmAnti, P_ghA, 3173, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_GMinus, 2028, check)
      call createCurrent(P_A, P_WMinus, P_ghWp, P_ghZAnti, 2238, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 563, check)
      call createCurrent(P_HQ, P_bAnti, P_b, 1154, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_G0, 2186, check)
      call createCurrent(P_GQMinus, P_ePlus, P_nu_e, 1714, check)
      call createCurrent(P_bAnti, P_b, P_g, 1466, check)
      call createCurrent(P_cAnti, P_Z, P_c, 1141, check)
      call createCurrent(P_ghAAnti, P_H, P_GPlus, P_ghWm, 880, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 1142, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_AQ, 1497, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, 3357, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 2066, check)
      call createCurrent(P_WQMinus, P_Z, P_WPlus, P_ZQ, 1013, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 2676, check)
      call createCurrent(P_ghAAnti, P_G0, P_GPlus, P_ghWm, 2003, check)
      call createCurrent(P_WQMinus, P_A, P_ghWmAnti, P_ghZ, 725, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_H, P_ghWm, 1970, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 1228, check)
      call createCurrent(P_GQMinus, P_G0, P_Z, P_WQPlus, 624, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_HQ, 756, check)
      call createCurrent(P_A, P_ghWmAnti, P_WMinus, P_ghA, 2850, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 1151, check)
      call createCurrent(P_H, P_ghWmAnti, P_GMinus, P_ghZ, 2027, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_G0, 3574, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_GQPlus, 2934, check)
      call createCurrent(P_GQ0, P_H, P_ghWmAnti, P_ghWm, 1762, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WMinus, P_WQPlus, 1336, check)
      call createCurrent(P_t, P_Z, P_tAnti, 1137, check)
      call createCurrent(P_G0, P_dAnti, P_d, 1550, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, P_gQ, 527, check)
      call createCurrent(P_ghWm, P_G0, P_GPlus, P_ghAAnti, 3300, check)
      call createCurrent(P_HQ, P_ghAAnti, P_GMinus, P_ghWp, 732, check)
      call createCurrent(P_s, P_Z, P_sAnti, 759, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 1581, check)
      call createCurrent(P_HQ, P_u, P_uAnti, 3223, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghA, P_WQPlus, 195, check)
      call createCurrent(P_ZQ, P_H, P_H, P_ZQ, 2874, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WMinus, P_WQPlus, 3129, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 3044, check)
      call createCurrent(P_H, P_cAnti, P_c, 2754, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_AQ, 1614, check)
      call createCurrent(P_WQPlus, P_A, P_WMinus, P_ZQ, 232, check)
      call createCurrent(P_GQPlus, P_ghZ, P_ghWpAnti, 2513, check)
      call createCurrent(P_bAnti, P_b, P_Z, 3126, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 1231, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 490, check)
      call createCurrent(P_AQ, P_Z, P_WPlus, P_WQMinus, 2534, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWp, P_ghAAnti, 669, check)
      call createCurrent(P_HQ, P_H, P_WPlus, P_WQMinus, 1269, check)
      call createCurrent(P_ZQ, P_A, P_GMinus, P_GQPlus, 2283, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HQ, 3287, check)
      call createCurrent(P_ghWp, P_A, P_WMinus, P_ghZAnti, 471, check)
      call createCurrent(P_GPlus, P_ghWp, P_GMinus, P_ghWpAnti, 3305, check)
      call createCurrent(P_H, P_H, P_ghWmAnti, P_ghWm, 2829, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 2803, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, P_H, 2385, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 1079, check)
      call createCurrent(P_Z, P_ghWp, P_WMinus, P_ghAAnti, 3086, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_ghWp, 532, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_ghZ, 3467, check)
      call createCurrent(P_HQ, P_GPlus, P_G0, P_GQMinus, 1543, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 3363, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, P_A, 2025, check)
      call createCurrent(P_G0, P_uAnti, P_u, 2624, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HQ, 2328, check)
      call createCurrent(P_G0, P_c, P_cAnti, 2423, check)
      call createCurrent(P_WMinus, P_ghZ, P_Z, P_ghWmAnti, 2990, check)
      call createCurrent(P_G0, P_GMinus, P_ghWmAnti, P_ghZ, 990, check)
      call createCurrent(P_GQPlus, P_H, P_ghWpAnti, P_ghA, 3070, check)
      call createCurrent(P_Z, P_ghZAnti, P_WMinus, P_ghWp, 832, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, P_A, 3794, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_GQMinus, 1385, check)
      call createCurrent(P_Z, P_WPlus, P_ghWpAnti, P_ghZ, 1706, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 1595, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 3779, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_G0, 3091, check)
      call createCurrent(P_g, P_H, P_H, P_g, 3939, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_ghWm, 419, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 870, check)
      call createCurrent(P_HQ, P_G0, P_WMinus, P_WQPlus, 2976, check)
      call createCurrent(P_AQ, P_A, P_ghWp, P_ghWpAnti, 495, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 2042, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 3869, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, P_A, 2073, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_H, 1253, check)
      call createCurrent(P_b, P_tAnti, P_WQPlus, 2257, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 2435, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 3115, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 3810, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 4002, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_WMinus, P_ghA, 2166, check)
      call createCurrent(P_WQMinus, P_G0, P_GQPlus, 1322, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 2806, check)
      call createCurrent(P_G0, P_G0, P_ghWm, P_ghWmAnti, 3259, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_WMinus, P_ghA, 3710, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 2295, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 4009, check)
      call createCurrent(P_GQMinus, P_WMinus, P_WPlus, P_GQPlus, 2079, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, P_A, 1144, check)
      call createCurrent(P_WQPlus, P_ghWm, P_WPlus, P_ghWpAnti, 306, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 738, check)
      call createCurrent(P_GQMinus, P_Z, P_Z, P_GQPlus, 785, check)
      call createCurrent(P_sAnti, P_s, P_H, 3268, check)
      call createCurrent(P_WQPlus, P_Z, P_H, P_GQMinus, 2469, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 2879, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_G0, 1757, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, P_g, 515, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 3071, check)
      call createCurrent(P_GQPlus, P_eMinus, P_nu_eAnti, 2171, check)
      call createCurrent(P_Z, P_ghZ, P_ghWpAnti, P_WPlus, 2769, check)
      call createCurrent(P_Z, P_uAnti, P_u, 767, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 2645, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_A, 3553, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 993, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_GMinus, P_ghZ, 2957, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 2959, check)
      call createCurrent(P_HQ, P_muPlus, P_muMinus, 1907, check)
      call createCurrent(P_AQ, P_WMinus, P_GQPlus, 49, check)
      call createCurrent(P_GMinus, P_H, P_ghWp, P_ghZAnti, 3522, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_HQ, 1025, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 542, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 970, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 2636, check)
      call createCurrent(P_ZQ, P_GMinus, P_GPlus, P_ZQ, 1014, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 71, check)
      call createCurrent(P_ghWmAnti, P_H, P_GMinus, P_ghZ, 1799, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 2865, check)
      call createCurrent(P_dAnti, P_g, P_d, 2276, check)
      call createCurrent(P_GMinus, P_H, P_ghZ, P_ghWmAnti, 3755, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_A, 1578, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_A, 660, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 2273, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_H, 2339, check)
      call createCurrent(P_AQ, P_ghAAnti, P_WMinus, P_ghWp, 1270, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_A, P_ghWm, 1491, check)
      call createCurrent(P_ghZ, P_H, P_ghWpAnti, P_GQPlus, 3190, check)
      call createCurrent(P_AQ, P_H, P_WMinus, P_GQPlus, 2094, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_A, 1719, check)
      call createCurrent(P_ghWp, P_G0, P_GMinus, P_ghAAnti, 670, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_GQMinus, 473, check)
      call createCurrent(P_ZQ, P_G0, P_G0, P_ZQ, 559, check)
      call createCurrent(P_G0, P_GMinus, P_ghZAnti, P_ghWp, 3092, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, P_A, 901, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, P_HQ, 2057, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_HQ, 3256, check)
      call createCurrent(P_GPlus, P_ghA, P_G0, P_ghWpAnti, 3736, check)
      call createCurrent(P_WMinus, P_ghWp, P_A, P_ghAAnti, 1465, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 2744, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_GQMinus, 1040, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_ZQ, 1881, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 3991, check)
      call createCurrent(P_ZQ, P_GPlus, P_H, P_WQMinus, 170, check)
      call createCurrent(P_GQPlus, P_H, P_Z, P_WQMinus, 2184, check)
      call createCurrent(P_ZQ, P_Z, P_WPlus, P_WQMinus, 2733, check)
      call createCurrent(P_Z, P_ghZAnti, P_WPlus, P_ghWm, 3610, check)
      call createCurrent(P_ZQ, P_H, P_WMinus, P_GQPlus, 1832, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 2008, check)
      call createCurrent(P_ghZ, P_Z, P_ghWpAnti, P_WPlus, 3307, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_GPlus, 3000, check)
      call createCurrent(P_HQ, P_cAnti, P_c, 1215, check)
      call createCurrent(P_A, P_Z, P_H, P_H, 3825, check)
      call createCurrent(P_HQ, P_WMinus, P_G0, P_WQPlus, 2466, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_AQ, 2050, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_HQ, 3541, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 2160, check)
      call createCurrent(P_ZQ, P_WMinus, P_WQPlus, 149, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghWpAnti, P_GPlus, 2373, check)
      call createCurrent(P_HQ, P_GMinus, P_ghZAnti, P_ghWp, 1700, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, 1486, check)
      call createCurrent(P_G0, P_GPlus, P_ghWm, P_ghZAnti, 889, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_HQ, 2354, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 106, check)
      call createCurrent(P_GQ0, P_GMinus, P_GPlus, P_GQ0, 729, check)
      call createCurrent(P_ZQ, P_sAnti, P_s, 3705, check)
      call createCurrent(P_A, P_d, P_dAnti, 3306, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghAAnti, P_ghZ, 639, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 3751, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 3136, check)
      call createCurrent(P_HQ, P_GPlus, P_ghWm, P_ghZAnti, 711, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WQPlus, 424, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 3620, check)
      call createCurrent(P_ghZ, P_A, P_WPlus, P_ghWpAnti, 2263, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 3708, check)
      call createCurrent(P_ZQ, P_muPlus, P_muMinus, 965, check)
      call createCurrent(P_WQPlus, P_WMinus, P_H, P_HQ, 2122, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GQ0, 35, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 1767, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 3797, check)
      call createCurrent(P_c, P_cAnti, P_gQ, 399, check)
      call createCurrent(P_HQ, P_GMinus, P_G0, P_GQPlus, 2834, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_HQ, 1121, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_GQ0, 3443, check)
      call createCurrent(P_ZQ, P_WMinus, P_G0, P_GQPlus, 3175, check)
      call createCurrent(P_WQMinus, P_WPlus, P_A, P_AQ, 933, check)
      call createCurrent(P_GQPlus, P_WMinus, P_WPlus, P_GQMinus, 689, check)
      call createCurrent(P_G0, P_GMinus, P_ghA, P_ghWmAnti, 2724, check)
      call createCurrent(P_H, P_A, P_H, P_A, 3995, check)
      call createCurrent(P_GQ0, P_WMinus, P_GQPlus, 1498, check)
      call createCurrent(P_AQ, P_eMinus, P_ePlus, 431, check)
      call createCurrent(P_H, P_ghA, P_GPlus, P_ghWpAnti, 802, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 1586, check)
      call createCurrent(P_sAnti, P_A, P_s, 413, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, P_A, 427, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 365, check)
      call createCurrent(P_WQPlus, P_G0, P_GQMinus, 2306, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 654, check)
      call createCurrent(P_WPlus, P_Z, P_ghZAnti, P_ghWm, 2851, check)
      call createCurrent(P_G0, P_H, P_A, 3839, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, P_H, 2422, check)
      call createCurrent(P_ZQ, P_WMinus, P_A, P_WQPlus, 954, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_H, 1293, check)
      call createCurrent(P_cAnti, P_c, P_gQ, 1517, check)
      call createCurrent(P_A, P_ghWmAnti, P_Z, P_ghWm, 1879, check)
      call createCurrent(P_bAnti, P_t, P_GQMinus, 1833, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_A, P_WQPlus, 1055, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 3503, check)
      call createCurrent(P_AQ, P_GMinus, P_H, P_WQPlus, 2173, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_ghWm, 2740, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 1393, check)
      call createCurrent(P_WQMinus, P_nu_tau, P_tauPlus, 779, check)
      call createCurrent(P_GQPlus, P_nu_eAnti, P_eMinus, 2964, check)
      call createCurrent(P_Z, P_WPlus, P_ghZ, P_ghWpAnti, 578, check)
      call createCurrent(P_GQPlus, P_d, P_uAnti, 3770, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_H, P_ghWm, 3185, check)
      call createCurrent(P_AQ, P_G0, P_WMinus, P_GQPlus, 2646, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 3999, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_WPlus, P_ghWm, 3144, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWm, P_WPlus, 3646, check)
      call createCurrent(P_AQ, P_c, P_cAnti, 1792, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 3828, check)
      call createCurrent(P_WMinus, P_ghZ, P_WPlus, P_ghAAnti, 145, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, P_GQ0, 91, check)
      call createCurrent(P_g, P_b, P_bAnti, 619, check)
      call createCurrent(P_Z, P_WPlus, P_ghZAnti, P_ghWm, 2665, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, P_A, 1740, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 112, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, P_A, 2176, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_ghWp, P_GPlus, 3258, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HQ, 2882, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 1246, check)
      call createCurrent(P_uAnti, P_u, P_g, 1101, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_GQ0, 872, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, P_A, 1686, check)
      call createCurrent(P_AQ, P_GPlus, P_A, P_GQMinus, 1201, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_G0, 2788, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghZ, P_GPlus, 308, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 1116, check)
      call createCurrent(P_ZQ, P_GMinus, P_GPlus, P_AQ, 1800, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WMinus, P_WPlus, 3657, check)
      call createCurrent(P_cAnti, P_c, 3897, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 2574, check)
      call createCurrent(P_u, P_uAnti, 3884, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 3211, check)
      call createCurrent(P_sAnti, P_H, P_s, 3036, check)
      call createCurrent(P_HQ, P_GMinus, P_GQPlus, 2004, check)
      call createCurrent(P_gQ, P_g, P_gQ, 630, check)
      call createCurrent(P_HQ, P_t, P_tAnti, 598, check)
      call createCurrent(P_A, P_WPlus, P_ghWm, P_ghAAnti, 294, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_GQPlus, 244, check)
      call createCurrent(P_HQ, P_GPlus, P_ghAAnti, P_ghWm, 995, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWp, P_WQMinus, 2682, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Z, P_WMinus, 1653, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 2154, check)
      call createCurrent(P_AQ, P_tauPlus, P_tauMinus, 1366, check)
      call createCurrent(P_ghA, P_A, P_WPlus, P_ghWpAnti, 867, check)
      call createCurrent(P_WQMinus, P_GPlus, P_H, P_ZQ, 1811, check)
      call createCurrent(P_H, P_ghWp, P_GMinus, P_ghZAnti, 2381, check)
      call createCurrent(P_AQ, P_A, P_WMinus, P_WQPlus, 1673, check)
      call createCurrent(P_ghAAnti, P_H, P_ghWp, P_GMinus, 3194, check)
      call createCurrent(P_tAnti, P_t, P_Z, 2577, check)
      call createCurrent(P_ghWm, P_GPlus, P_GMinus, P_ghWmAnti, 3674, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghWmAnti, P_GMinus, 3094, check)
      call createCurrent(P_WPlus, P_ghWm, P_A, P_ghAAnti, 2092, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 2102, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, P_H, 3294, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_AQ, 1783, check)
      call createCurrent(P_ghWm, P_GPlus, P_G0, P_ghZAnti, 1501, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, P_HQ, 2855, check)
      call createCurrent(P_AQ, P_d, P_dAnti, 1575, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, P_H, 1436, check)
      call createCurrent(P_WQMinus, P_GPlus, P_ZQ, 2, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, P_Z, 2403, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 1691, check)
      call createCurrent(P_GQ0, P_sAnti, P_s, 3795, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_A, 2632, check)
      call createCurrent(P_WPlus, P_A, P_ghZ, P_ghWpAnti, 2311, check)
      call createCurrent(P_A, P_H, P_G0, 3899, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_HQ, 3251, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_H, 2138, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_ghWp, 1729, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 1608, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, P_A, 1448, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, P_gQ, 1309, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 3127, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghAAnti, P_WMinus, 2780, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_A, 2362, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 3951, check)
      call createCurrent(P_GQ0, P_Z, P_HQ, 2153, check)
      call createCurrent(P_G0, P_ghA, P_ghWmAnti, P_GMinus, 1633, check)
      call createCurrent(P_G0, P_H, P_G0, 1563, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_A, P_ghZ, 3095, check)
      call createCurrent(P_WQPlus, P_ghZ, P_ghWpAnti, 659, check)
      call createCurrent(P_GQPlus, P_G0, P_Z, P_WQMinus, 3721, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_AQ, 281, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_H, P_GQPlus, 1206, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Z, P_AQ, 3313, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_H, P_ghZ, 1332, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 3695, check)
      call createCurrent(P_muMinus, P_muPlus, P_HQ, 3072, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 2592, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_GPlus, P_ghA, 2751, check)
      call createCurrent(P_Z, P_WMinus, P_ghWmAnti, P_ghA, 3261, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 2804, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 2285, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 3425, check)
      call createCurrent(P_ghWm, P_A, P_WPlus, P_ghAAnti, 1460, check)
      call createCurrent(P_Z, P_A, P_ghWp, P_ghWpAnti, 339, check)
      call createCurrent(P_c, P_cAnti, P_G0, 2110, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WPlus, P_WQMinus, 3625, check)
      call createCurrent(P_WQMinus, P_ghA, P_WPlus, P_ghAAnti, 2844, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 1384, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_AQ, 3291, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_G0, P_ghA, 2281, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghZ, P_WQMinus, 2793, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_ZQ, 1651, check)
      call createCurrent(P_AQ, P_tauMinus, P_tauPlus, 210, check)
      call createCurrent(P_A, P_Z, P_ghWm, P_ghWmAnti, 928, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 1696, check)
      call createCurrent(P_G0, P_tAnti, P_t, 3311, check)
      call createCurrent(P_AQ, P_WPlus, P_ghWm, P_ghAAnti, 3739, check)
      call createCurrent(P_ghA, P_H, P_GMinus, P_ghWmAnti, 2663, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 3766, check)
      call createCurrent(P_ghWp, P_Z, P_ghZAnti, P_WMinus, 3409, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 2587, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 1604, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 3686, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 2270, check)
      call createCurrent(P_WQMinus, P_A, P_WPlus, P_AQ, 3212, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 2491, check)
      call createCurrent(P_dAnti, P_d, P_g, 261, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_GQPlus, 2528, check)
      call createCurrent(P_GQPlus, P_ghWm, P_H, P_ghZAnti, 3529, check)
      call createCurrent(P_A, P_ghWp, P_Z, P_ghWpAnti, 3447, check)
      call createCurrent(P_ghZ, P_GMinus, P_GPlus, P_ghZAnti, 3460, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghWp, P_ghAAnti, 1081, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 2861, check)
      call createCurrent(P_Z, P_ghWpAnti, P_WPlus, P_ghZ, 362, check)
      call createCurrent(P_A, P_ghA, P_WPlus, P_ghWpAnti, 2026, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GQ0, 476, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 2600, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GQMinus, 509, check)
      call createCurrent(P_H, P_ghA, P_GMinus, P_ghWmAnti, 2617, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 105, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_HQ, 805, check)
      call createCurrent(P_WQMinus, P_ghWp, P_WPlus, P_ghWpAnti, 1839, check)
      call createCurrent(P_WMinus, P_ghA, P_A, P_ghWmAnti, 3649, check)
      call createCurrent(P_WQMinus, P_GPlus, P_G0, P_AQ, 1532, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghZ, P_WQPlus, 543, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 3435, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 986, check)
      call createCurrent(P_ZQ, P_A, P_ghWpAnti, P_ghWp, 2673, check)
      call createCurrent(P_GPlus, P_ghA, P_ghAAnti, P_GMinus, 3442, check)
      call createCurrent(P_ghWmAnti, P_Z, P_Z, P_ghWm, 1131, check)
      call createCurrent(P_WQPlus, P_H, P_GMinus, P_ZQ, 2323, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 2227, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1870, check)
      call createCurrent(P_WQPlus, P_ghZ, P_WMinus, P_ghAAnti, 409, check)
      call createCurrent(P_s, P_sAnti, P_g, 2248, check)
      call createCurrent(P_HQ, P_c, P_cAnti, 1861, check)
      call createCurrent(P_uAnti, P_Z, P_u, 2951, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghAAnti, P_ghWm, 3453, check)
      call createCurrent(P_GQMinus, P_WMinus, P_GPlus, P_WQPlus, 2695, check)
      call createCurrent(P_A, P_WMinus, P_ghWmAnti, P_ghA, 2464, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 59, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, P_Z, 1540, check)
      call createCurrent(P_ghWm, P_WMinus, P_WPlus, P_ghWmAnti, 2344, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_GQPlus, 701, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_G0, P_ghZ, 1480, check)
      call createCurrent(P_t, P_tAnti, P_HQ, 1341, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, P_HQ, 2064, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 720, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZAnti, P_ghA, 463, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_G0, 3315, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_ZQ, 279, check)
      call createCurrent(P_ghZ, P_G0, P_GMinus, P_ghWmAnti, 748, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_A, P_WMinus, 3438, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_GMinus, 1524, check)
      call createCurrent(P_GQ0, P_WMinus, P_H, P_WQPlus, 601, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_H, 2935, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 724, check)
      call createCurrent(P_HQ, P_GPlus, P_GQMinus, 2641, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 2022, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Z, P_ZQ, 2077, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GQPlus, 3478, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_A, 1626, check)
      call createCurrent(P_GQ0, P_G0, P_HQ, 1107, check)
      call createCurrent(P_WQMinus, P_A, P_A, P_WQPlus, 299, check)
      call createCurrent(P_H, P_G0, P_Z, 295, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_G0, P_GPlus, 398, check)
      call createCurrent(P_ghWmAnti, P_Z, P_WMinus, P_ghA, 2260, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_GQ0, 2391, check)
      call createCurrent(P_ghWmAnti, P_ghWp, P_WMinus, P_WMinus, 397, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_GPlus, 688, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_GMinus, 763, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_GQ0, 1692, check)
      call createCurrent(P_GQ0, P_G0, P_ghWp, P_ghWpAnti, 714, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, P_A, 327, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_Z, 1764, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 4014, check)
      call createCurrent(P_AQ, P_GPlus, P_WQMinus, 2461, check)
      call createCurrent(P_H, P_H, P_ghWpAnti, P_ghWp, 1203, check)
      call createCurrent(P_GQPlus, P_GMinus, P_H, P_HQ, 2207, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_GPlus, 1882, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, P_A, 3777, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_GMinus, P_ghA, 33, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GMinus, P_GPlus, 622, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, P_GQ0, 1667, check)
      call createCurrent(P_tAnti, P_t, 3862, check)
      call createCurrent(P_H, P_ghWm, P_GPlus, P_ghZAnti, 3534, check)
      call createCurrent(P_G0, P_d, P_dAnti, 3555, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_G0, 2912, check)
      call createCurrent(P_bAnti, P_G0, P_b, 2702, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GQMinus, 1450, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_G0, 803, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_GQ0, 1934, check)
      call createCurrent(P_G0, P_GPlus, P_ghWpAnti, P_ghZ, 1392, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_H, 2875, check)
      call createCurrent(P_dAnti, P_u, P_GQMinus, 1282, check)
      call createCurrent(P_H, P_Z, P_G0, 1602, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 2045, check)
      call createCurrent(P_ghWp, P_GMinus, P_H, P_ghZAnti, 1413, check)
      call createCurrent(P_GQPlus, P_nu_tauAnti, P_tauMinus, 1828, check)
      call createCurrent(P_ghA, P_Z, P_WPlus, P_ghWpAnti, 674, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 66, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghA, P_ghZAnti, 3048, check)
      call createCurrent(P_H, P_ghWm, P_H, P_ghWmAnti, 3236, check)
      call createCurrent(P_AQ, P_Z, P_ghWm, P_ghWmAnti, 3103, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_G0, 3677, check)
      call createCurrent(P_H, P_H, P_ghZ, P_ghZAnti, 1240, check)
      call createCurrent(P_bAnti, P_Z, P_b, 919, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_H, P_GPlus, 2214, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZ, P_ghZAnti, 1351, check)
      call createCurrent(P_WQPlus, P_Z, P_Z, P_WQMinus, 150, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 3008, check)
      call createCurrent(P_ghZAnti, P_Z, P_ghWp, P_WMinus, 946, check)
      call createCurrent(P_GQMinus, P_A, P_GPlus, P_ZQ, 551, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, P_A, 1254, check)
      call createCurrent(P_d, P_dAnti, P_A, 3245, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_GQPlus, 2185, check)
      call createCurrent(P_ghZ, P_G0, P_GPlus, P_ghWpAnti, 1798, check)
      call createCurrent(P_ghG, P_ghGAnti, P_gQ, 615, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, P_A, 2047, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Z, P_AQ, 2324, check)
      call createCurrent(P_WQMinus, P_A, P_WQPlus, 3366, check)
      call createCurrent(P_AQ, P_Z, P_GMinus, P_GQPlus, 816, check)
      call createCurrent(P_GQMinus, P_WPlus, P_ZQ, 577, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWmAnti, P_ghA, 30, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_H, P_GMinus, 1777, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_GQ0, 3303, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 1434, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WQMinus, 2298, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghAAnti, P_WMinus, 2998, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_H, P_ghWp, 2063, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_G0, P_ghZ, 1190, check)
      call createCurrent(P_WPlus, P_WMinus, 3879, check)
      call createCurrent(P_H, P_ghAAnti, P_GMinus, P_ghWp, 260, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 3771, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_WPlus, P_ghWm, 1004, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 3834, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 2721, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GQPlus, 2999, check)
      call createCurrent(P_ghZAnti, P_G0, P_G0, P_ghZ, 1942, check)
      call createCurrent(P_Z, P_ghWp, P_A, P_ghWpAnti, 2741, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_A, P_ghWm, 1095, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_GPlus, P_ghZ, 2728, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 906, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 3301, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_H, 2241, check)
      call createCurrent(P_HQ, P_WMinus, P_GPlus, P_ZQ, 818, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 797, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 2232, check)
      call createCurrent(P_tauMinus, P_tauPlus, 3867, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 3233, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 829, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_GQ0, 2657, check)
      call createCurrent(P_ghWm, P_G0, P_G0, P_ghWmAnti, 1290, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 1019, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_ZQ, 391, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 3133, check)
      call createCurrent(P_AQ, P_WMinus, P_G0, P_GQPlus, 1541, check)
      call createCurrent(P_A, P_ghWm, P_A, P_ghWmAnti, 2869, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 1867, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_GPlus, 2669, check)
      call createCurrent(P_GPlus, P_ghWm, P_H, P_ghAAnti, 3735, check)
      call createCurrent(P_GQ0, P_GPlus, P_WQMinus, 2326, check)
      call createCurrent(P_d, P_G0, P_dAnti, 885, check)
      call createCurrent(P_GMinus, P_ghA, P_GPlus, P_ghZAnti, 1487, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 3275, check)
      call createCurrent(P_H, P_ghZAnti, P_GPlus, P_ghWm, 3063, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, 2192, check)
      call createCurrent(P_tAnti, P_b, P_GQPlus, 2267, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 1642, check)
      call createCurrent(P_HQ, P_tauMinus, P_tauPlus, 705, check)
      call createCurrent(P_ghWm, P_A, P_Z, P_ghWmAnti, 3694, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_H, P_GMinus, 3022, check)
      call createCurrent(P_HQ, P_s, P_sAnti, 1461, check)
      call createCurrent(P_AQ, P_Z, P_WMinus, P_WQPlus, 2942, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 3159, check)
      call createCurrent(P_AQ, P_muPlus, P_muMinus, 2634, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghZ, P_WQMinus, 1933, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_G0, 2108, check)
      call createCurrent(P_Z, P_ghZAnti, P_ghWm, P_WPlus, 2742, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_HQ, 1449, check)
      call createCurrent(P_AQ, P_H, P_GMinus, P_WQPlus, 673, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 3969, check)
      call createCurrent(P_GQ0, P_ePlus, P_eMinus, 2572, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_H, P_ghWp, 40, check)
      call createCurrent(P_HQ, P_Z, P_ZQ, 2142, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GPlus, P_GQMinus, 1420, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_AQ, 2218, check)
      call createCurrent(P_GQMinus, P_ghA, P_ghWmAnti, 2521, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZAnti, P_ghZ, 1584, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_G0, P_ghZ, 3504, check)
      call createCurrent(P_sAnti, P_s, P_gQ, 1312, check)
      call createCurrent(P_H, P_ghWpAnti, P_GPlus, P_ghA, 1557, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_H, P_GQMinus, 52, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GPlus, P_GMinus, 3420, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 663, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WMinus, P_WQPlus, 979, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_GPlus, 1745, check)
      call createCurrent(P_WQPlus, P_ghA, P_A, P_ghWpAnti, 2250, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, P_A, 1513, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWp, P_ghZAnti, 3157, check)
      call createCurrent(P_ZQ, P_Z, P_ghWpAnti, P_ghWp, 1408, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 3929, check)
      call createCurrent(P_ghWpAnti, P_A, P_A, P_ghWp, 2220, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_ghWm, P_GMinus, 1048, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_ghA, 2866, check)
      call createCurrent(P_g, P_d, P_dAnti, 403, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 3001, check)
      call createCurrent(P_ghA, P_G0, P_GPlus, P_ghWpAnti, 2310, check)
      call createCurrent(P_ZQ, P_Z, P_ghWm, P_ghWmAnti, 1718, check)
      call createCurrent(P_GQPlus, P_ghA, P_H, P_ghWpAnti, 602, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghA, P_ghZAnti, 1467, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZAnti, P_ghZ, 428, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_G0, 1544, check)
      call createCurrent(P_A, P_s, P_sAnti, 888, check)
      call createCurrent(P_WQMinus, P_ghA, P_ghWmAnti, 1592, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 1819, check)
      call createCurrent(P_Z, P_ghWpAnti, P_Z, P_ghWp, 1521, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 3793, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 3382, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_GMinus, P_ghZ, 3166, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_Z, 1099, check)
      call createCurrent(P_A, P_g, P_g, P_A, 3913, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_GQMinus, 2226, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 677, check)
      call createCurrent(P_A, P_H, P_Z, 3835, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 3032, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_GQMinus, 248, check)
      call createCurrent(P_AQ, P_ghWp, P_WMinus, P_ghAAnti, 3336, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 1021, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GQPlus, 2771, check)
      call createCurrent(P_d, P_g, P_dAnti, 1173, check)
      call createCurrent(P_g, P_t, P_tAnti, 2318, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 1455, check)
      call createCurrent(P_WQPlus, P_Z, P_GQMinus, 2300, check)
      call createCurrent(P_s, P_sAnti, P_AQ, 1857, check)
      call createCurrent(P_tAnti, P_t, P_ZQ, 3429, check)
      call createCurrent(P_HQ, P_ghWmAnti, P_G0, P_ghWm, 2798, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 3956, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_A, 773, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Z, P_WQMinus, 2459, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 851, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_GQ0, 3526, check)
      call createCurrent(P_ghWmAnti, P_H, P_H, P_ghWm, 976, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_G0, 3082, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_GQ0, 2140, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_H, 1133, check)
      call createCurrent(P_GQ0, P_WPlus, P_Z, P_GQMinus, 1283, check)
      call createCurrent(P_GQPlus, P_G0, P_ghZAnti, P_ghWm, 2430, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 2441, check)
      call createCurrent(P_dAnti, P_d, P_A, 2253, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_ZQ, 3131, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_GMinus, 1822, check)
      call createCurrent(P_u, P_uAnti, P_Z, 1167, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_ZQ, 1971, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, P_A, 2661, check)
      call createCurrent(P_GQMinus, P_ghA, P_H, P_ghWmAnti, 1284, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 3402, check)
      call createCurrent(P_H, P_GPlus, P_ghAAnti, P_ghWm, 1323, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 2335, check)
      call createCurrent(P_ZQ, P_H, P_ZQ, 3270, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_ghA, 46, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 2561, check)
      call createCurrent(P_GQPlus, P_cAnti, P_s, 1157, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, P_A, 1527, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_WPlus, P_ghA, 3346, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_G0, P_ghWm, 2268, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_WMinus, P_ghZ, 346, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghWm, P_ghWmAnti, 2093, check)
      call createCurrent(P_ghA, P_A, P_WMinus, P_ghWmAnti, 472, check)
      call createCurrent(P_G0, P_G0, 3906, check)
      call createCurrent(P_ghAAnti, P_H, P_GMinus, P_ghWp, 743, check)
      call createCurrent(P_GPlus, P_G0, P_ghZ, P_ghWpAnti, 1682, check)
      call createCurrent(P_A, P_b, P_bAnti, 3179, check)
      call createCurrent(P_WMinus, P_ghWp, P_Z, P_ghZAnti, 2583, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 1838, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 3817, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWm, P_WPlus, 3608, check)
      call createCurrent(P_ghWp, P_WMinus, P_Z, P_ghAAnti, 3807, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WPlus, P_WQMinus, 254, check)
      call createCurrent(P_b, P_bAnti, P_gQ, 3651, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_G0, 2029, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_HQ, 369, check)
      call createCurrent(P_WQMinus, P_Z, P_GQPlus, 1314, check)
      call createCurrent(P_c, P_H, P_cAnti, 1552, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GQMinus, 1720, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 3401, check)
      call createCurrent(P_WQPlus, P_GMinus, P_AQ, 1338, check)
      call createCurrent(P_ghWpAnti, P_Z, P_Z, P_ghWp, 268, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghZ, P_GMinus, 2178, check)
      call createCurrent(P_WQMinus, P_WPlus, P_H, P_HQ, 1726, check)
      call createCurrent(P_ghWpAnti, P_A, P_Z, P_ghWp, 1218, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_G0, 1975, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_GMinus, P_ghA, 2795, check)
      call createCurrent(P_WQMinus, P_H, P_Z, P_GQPlus, 2398, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_G0, 1542, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 956, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, P_Z, 2255, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_Z, 3750, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_H, P_GMinus, 1941, check)
      call createCurrent(P_HQ, P_GMinus, P_ghZ, P_ghWmAnti, 2155, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 1887, check)
      call createCurrent(P_GQPlus, P_GMinus, P_WPlus, P_WQMinus, 2666, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghA, P_ghZAnti, 817, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 2729, check)
      call createCurrent(P_GPlus, P_ghA, P_ghZAnti, P_GMinus, 3043, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, P_A, 3702, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 3441, check)
      call createCurrent(P_d, P_H, P_dAnti, 1760, check)
      call createCurrent(P_u, P_uAnti, P_ZQ, 2089, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 4010, check)
      call createCurrent(P_WQPlus, P_s, P_cAnti, 2183, check)
      call createCurrent(P_Z, P_H, P_A, 3824, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_A, P_WMinus, 950, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WMinus, P_WPlus, 806, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 1159, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 3894, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_H, 1120, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_GPlus, P_ghWm, 3505, check)
      call createCurrent(P_A, P_Z, P_ghWpAnti, P_ghWp, 626, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghZ, P_WMinus, 305, check)
      call createCurrent(P_ghWm, P_A, P_ghZAnti, P_WPlus, 1897, check)
      call createCurrent(P_WQMinus, P_ghA, P_WPlus, P_ghZAnti, 2085, check)
      call createCurrent(P_sAnti, P_s, P_G0, 461, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_GQMinus, 1199, check)
      call createCurrent(P_WQMinus, P_WMinus, P_ghWp, P_ghWmAnti, 1238, check)
      call createCurrent(P_Z, P_ghZAnti, P_ghWp, P_WMinus, 529, check)
      call createCurrent(P_WQMinus, P_Z, P_H, P_GQPlus, 3640, check)
      call createCurrent(P_WQPlus, P_G0, P_G0, P_WQMinus, 2512, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_GQPlus, 819, check)
      call createCurrent(P_u, P_G0, P_uAnti, 1940, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 2697, check)
      call createCurrent(P_AQ, P_Z, P_ghWp, P_ghWpAnti, 2524, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 640, check)
      call createCurrent(P_ghGAnti, P_ghG, P_gQ, 2233, check)
      call createCurrent(P_WQMinus, P_t, P_bAnti, 2688, check)
      call createCurrent(P_GQPlus, P_H, P_GQMinus, 2205, check)
      call createCurrent(P_gQ, P_tAnti, P_t, 528, check)
      call createCurrent(P_gQ, P_ghG, P_g, P_ghGAnti, 1211, check)
      call createCurrent(P_AQ, P_u, P_uAnti, 3155, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GMinus, P_GQPlus, 2939, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 242, check)
      call createCurrent(P_G0, P_sAnti, P_s, 570, check)
      call createCurrent(P_HQ, P_G0, P_GQ0, 3326, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWp, P_ghWpAnti, 1272, check)
      call createCurrent(P_HQ, P_G0, P_GPlus, P_GQMinus, 2864, check)
      call createCurrent(P_H, P_t, P_tAnti, 1202, check)
      call createCurrent(P_AQ, P_ghWm, P_WPlus, P_ghZAnti, 1128, check)
      call createCurrent(P_HQ, P_WMinus, P_GQPlus, 1570, check)
      call createCurrent(P_G0, P_ghWpAnti, P_GPlus, P_ghA, 2468, check)
      call createCurrent(P_GMinus, P_H, P_ghZAnti, P_ghWp, 1405, check)
      call createCurrent(P_WQPlus, P_G0, P_GMinus, P_AQ, 2706, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_Z, 1345, check)
      call createCurrent(P_H, P_GMinus, P_ghWmAnti, P_ghZ, 1278, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_GQPlus, 47, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 1447, check)
      call createCurrent(P_H, P_GMinus, P_ghAAnti, P_ghWp, 2454, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 2230, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_GMinus, 3698, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 1986, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_H, 1227, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWp, P_GMinus, 1243, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 204, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 1965, check)
      call createCurrent(P_G0, P_A, P_H, 3881, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 1672, check)
      call createCurrent(P_AQ, P_WMinus, P_A, P_WQPlus, 2714, check)
      call createCurrent(P_Z, P_WPlus, P_ghWm, P_ghZAnti, 155, check)
      call createCurrent(P_WQPlus, P_GPlus, P_WMinus, P_GQMinus, 2685, check)
      call createCurrent(P_G0, P_ghZAnti, P_G0, P_ghZ, 3096, check)
      call createCurrent(P_H, P_g, P_g, P_H, 3931, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_GMinus, P_ghA, 3635, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GMinus, P_GPlus, 3493, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 2786, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghAAnti, P_ghA, 1005, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_AQ, 1769, check)
      call createCurrent(P_WQPlus, P_GMinus, P_ZQ, 2312, check)
      call createCurrent(P_GQMinus, P_c, P_sAnti, 1825, check)
      call createCurrent(P_A, P_ghWp, P_WMinus, P_ghAAnti, 1562, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 2938, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_AQ, 3019, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 302, check)
      call createCurrent(P_dAnti, P_u, P_WQMinus, 1113, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_Z, P_ghWm, 2284, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 466, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 2680, check)
      call createCurrent(P_WMinus, P_Z, P_ghZ, P_ghWmAnti, 2610, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_Z, P_ghZ, 1275, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 1999, check)
      call createCurrent(P_GPlus, P_G0, P_ghWm, P_ghZAnti, 3669, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 2113, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 1558, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 2532, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 3253, check)
      call createCurrent(P_GQ0, P_s, P_sAnti, 3440, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_GQPlus, 2455, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_HQ, 2496, check)
      call createCurrent(P_WQPlus, P_GMinus, P_GQ0, 1188, check)
      call createCurrent(P_GPlus, P_H, P_ghWm, P_ghZAnti, 2470, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1163, check)
      call createCurrent(P_GQ0, P_ghAAnti, P_GPlus, P_ghWm, 609, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghA, P_GMinus, 3778, check)
      call createCurrent(P_Z, P_A, 3909, check)
      call createCurrent(P_GQ0, P_WPlus, P_GMinus, P_ZQ, 3342, check)
      call createCurrent(P_GQMinus, P_H, P_Z, P_WQPlus, 2357, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 833, check)
      call createCurrent(P_AQ, P_WMinus, P_WQPlus, 1294, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WPlus, P_WMinus, 488, check)
      call createCurrent(P_ZQ, P_ghWm, P_ghWmAnti, 3010, check)
      call createCurrent(P_Z, P_ghWp, P_ghAAnti, P_WMinus, 1896, check)
      call createCurrent(P_ghWm, P_Z, P_WPlus, P_ghZAnti, 137, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WPlus, P_WMinus, 292, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 2625, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 3873, check)
      call createCurrent(P_ghZ, P_WPlus, P_WMinus, P_ghAAnti, 2393, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_HQ, 3003, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Z, P_WQMinus, 2420, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 2302, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_ZQ, 3324, check)
      call createCurrent(P_WQMinus, P_GPlus, P_AQ, 896, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 721, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 2151, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_H, P_GQPlus, 539, check)
      call createCurrent(P_GMinus, P_ghZ, P_GPlus, P_ghAAnti, 2040, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghZ, P_WMinus, 3411, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 3671, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 2732, check)
      call createCurrent(P_ghWm, P_GPlus, P_G0, P_ghAAnti, 2726, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_HQ, 2649, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_HQ, 2510, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_G0, 3556, check)
      call createCurrent(P_HQ, P_GMinus, P_A, P_WQPlus, 3623, check)
      call createCurrent(P_ghA, P_WPlus, P_WMinus, P_ghAAnti, 2859, check)
      call createCurrent(P_WQPlus, P_WMinus, P_AQ, 1943, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_A, P_WPlus, 3792, check)
      call createCurrent(P_GMinus, P_ghA, P_G0, P_ghWmAnti, 3162, check)
      call createCurrent(P_ZQ, P_nu_e, P_nu_eAnti, 2764, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 2006, check)
      call createCurrent(P_ghA, P_WMinus, P_ghZAnti, P_WQPlus, 1594, check)
      call createCurrent(P_AQ, P_H, P_GPlus, P_WQMinus, 3599, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghZAnti, P_ghWp, 2277, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, P_H, 557, check)
      call createCurrent(P_HQ, P_dAnti, P_d, 2478, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HQ, 3247, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 2101, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, P_g, 699, check)
      call createCurrent(P_ghWm, P_Z, P_A, P_ghWmAnti, 43, check)
      call createCurrent(P_WQMinus, P_Z, P_ghWmAnti, P_ghZ, 798, check)
      call createCurrent(P_c, P_Z, P_cAnti, 291, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GQPlus, 223, check)
      call createCurrent(P_AQ, P_A, P_GMinus, P_GQPlus, 1053, check)
      call createCurrent(P_G0, P_bAnti, P_b, 3678, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_GMinus, P_ghA, 2056, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghWpAnti, P_ghWp, 2643, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghZ, P_WMinus, 1357, check)
      call createCurrent(P_WQMinus, P_GPlus, P_GQ0, 2603, check)
      call createCurrent(P_H, P_b, P_bAnti, 41, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWm, P_ghWmAnti, 3228, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 1947, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_Z, P_ghWm, 27, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_GQMinus, 1805, check)
      call createCurrent(P_HQ, P_ghWmAnti, P_H, P_ghWm, 2174, check)
      call createCurrent(P_t, P_tAnti, P_gQ, 2797, check)
      call createCurrent(P_dAnti, P_d, P_HQ, 1966, check)
      call createCurrent(P_gQ, P_g, P_g, P_gQ, 3359, check)
      call createCurrent(P_Z, P_Z, P_H, 2062, check)
      call createCurrent(P_G0, P_ghWmAnti, P_GMinus, P_ghA, 212, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, P_G0, 144, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_GMinus, 228, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 3605, check)
      call createCurrent(P_GMinus, P_ghZ, P_GPlus, P_ghZAnti, 50, check)
      call createCurrent(P_WQMinus, P_A, P_ghZ, P_ghWmAnti, 2650, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, P_H, 2384, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 1576, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 1638, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Z, P_ZQ, 2249, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 3558, check)
      call createCurrent(P_GQ0, P_GPlus, P_WMinus, P_ZQ, 1070, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_GPlus, 1295, check)
      call createCurrent(P_ZQ, P_nu_mu, P_nu_muAnti, 3783, check)
      call createCurrent(P_HQ, P_WPlus, P_Z, P_GQMinus, 3589, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_H, P_GPlus, 135, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_GQMinus, 2314, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_ZQ, 148, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghA, P_ghAAnti, 2997, check)
      call createCurrent(P_ePlus, P_eMinus, P_ZQ, 303, check)
      call createCurrent(P_ghZAnti, P_H, P_H, P_ghZ, 274, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 1347, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 1845, check)
      call createCurrent(P_Z, P_WPlus, P_ghAAnti, P_ghWm, 2891, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_GQPlus, 911, check)
      call createCurrent(P_H, P_A, P_G0, 3855, check)
      call createCurrent(P_u, P_uAnti, P_g, 2458, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, P_HQ, 334, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 3150, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghWm, P_WPlus, 855, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 1456, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_A, P_WQPlus, 846, check)
      call createCurrent(P_uAnti, P_u, P_AQ, 1207, check)
      call createCurrent(P_WQMinus, P_GPlus, P_G0, P_ZQ, 307, check)
      call createCurrent(P_ZQ, P_t, P_tAnti, 1368, check)
      call createCurrent(P_AQ, P_GPlus, P_G0, P_WQMinus, 1457, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_WPlus, P_ghZ, 1138, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 363, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 465, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_AQ, 3125, check)
      call createCurrent(P_GQ0, P_WMinus, P_GPlus, P_ZQ, 603, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, P_g, 2010, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 858, check)
      call createCurrent(P_GQPlus, P_tauMinus, P_nu_tauAnti, 684, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_GQ0, 1872, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZAnti, P_ghZ, 1223, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghZ, P_WMinus, 1972, check)
      call createCurrent(P_GQ0, P_ghWp, P_GMinus, P_ghAAnti, 2278, check)
      call createCurrent(P_u, P_g, P_uAnti, 1936, check)
      call createCurrent(P_ghA, P_WPlus, P_Z, P_ghWpAnti, 1008, check)
      call createCurrent(P_WMinus, P_A, P_ghZAnti, P_ghWp, 1522, check)
      call createCurrent(P_ZQ, P_uAnti, P_u, 3634, check)
      call createCurrent(P_ghZ, P_G0, P_G0, P_ghZAnti, 186, check)
      call createCurrent(P_WPlus, P_Z, P_ghZ, P_ghWpAnti, 1069, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 3552, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_WPlus, P_ghWm, 2703, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_Z, P_ghWm, 2979, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_GMinus, 2409, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, P_GQ0, 1624, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_HQ, 3272, check)
      call createCurrent(P_H, P_s, P_sAnti, 650, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 1873, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 3389, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_GPlus, P_ghZ, 2256, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_H, P_ghZ, 501, check)
      call createCurrent(P_ghWm, P_Z, P_WPlus, P_ghAAnti, 2612, check)
      call createCurrent(P_WQMinus, P_GMinus, P_GPlus, P_WQPlus, 480, check)
      call createCurrent(P_HQ, P_eMinus, P_ePlus, 492, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_GQMinus, 3107, check)
      call createCurrent(P_WQPlus, P_GMinus, P_GPlus, P_WQMinus, 2883, check)
      call createCurrent(P_WMinus, P_ghWp, P_WPlus, P_ghWpAnti, 2816, check)
      call createCurrent(P_G0, P_ghZ, P_ghWpAnti, P_GPlus, 795, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_GQPlus, 2188, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, P_Z, 1944, check)
      call createCurrent(P_H, P_ghWpAnti, P_H, P_ghWp, 1391, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 2686, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GQPlus, 3379, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 3468, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 3417, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 830, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_GPlus, 161, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWpAnti, P_WPlus, 2487, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 16, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 2413, check)
      call createCurrent(P_WQPlus, P_ghA, P_WMinus, P_ghZAnti, 981, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_H, 1741, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 2031, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 978, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 787, check)
      call createCurrent(P_ZQ, P_tAnti, P_t, 3377, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_H, P_GMinus, 178, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 1183, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_WMinus, P_ghZ, 1952, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_A, P_WQPlus, 3578, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 734, check)
      call createCurrent(P_GQMinus, P_G0, P_ghZ, P_ghWmAnti, 1496, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_GMinus, 1343, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 1300, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 3446, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 2836, check)
      call createCurrent(P_A, P_ghWm, P_Z, P_ghWmAnti, 3763, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_G0, P_ghA, 567, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, P_A, 464, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 3077, check)
      call createCurrent(P_GQ0, P_A, P_GPlus, P_WQMinus, 3764, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 1478, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, P_A, 751, check)
      call createCurrent(P_H, P_H, P_A, P_Z, 3864, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZAnti, P_ghA, 890, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 3910, check)
      call createCurrent(P_HQ, P_d, P_dAnti, 2383, check)
      call createCurrent(P_ghWm, P_ghWpAnti, P_WPlus, P_WPlus, 2246, check)
      call createCurrent(P_WQMinus, P_Z, P_Z, P_WQPlus, 1158, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GQPlus, 560, check)
      call createCurrent(P_A, P_ghWp, P_WMinus, P_ghZAnti, 340, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_GMinus, P_ghZ, 3513, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, P_Z, 1793, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 174, check)
      call createCurrent(P_Z, P_ghZ, P_WPlus, P_ghWpAnti, 2638, check)
      call createCurrent(P_t, P_tAnti, P_G0, 862, check)
      call createCurrent(P_ZQ, P_Z, P_HQ, 3320, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_GQPlus, 2766, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, P_Z, 2897, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 3327, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 335, check)
      call createCurrent(P_ghWmAnti, P_ghWp, P_WMinus, P_WQMinus, 3480, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_H, 544, check)
      call createCurrent(P_ZQ, P_ghWp, P_ghWpAnti, 1818, check)
      call createCurrent(P_GQ0, P_WPlus, P_GQMinus, 2139, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 1086, check)
      call createCurrent(P_G0, P_ghWm, P_ghZAnti, P_GPlus, 250, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_Z, P_ghZ, 2656, check)
      call createCurrent(P_WQPlus, P_A, P_A, P_WQMinus, 3575, check)
      call createCurrent(P_HQ, P_H, P_GMinus, P_GQPlus, 297, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_GPlus, P_ghZ, 2083, check)
      call createCurrent(P_H, P_ghA, P_ghWpAnti, P_GPlus, 1502, check)
      call createCurrent(P_GPlus, P_ghA, P_H, P_ghWpAnti, 942, check)
      call createCurrent(P_G0, P_b, P_bAnti, 3369, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_G0, 1083, check)
      call createCurrent(P_gQ, P_sAnti, P_s, 1837, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 3321, check)
      call createCurrent(P_WPlus, P_Z, P_ghWpAnti, P_ghZ, 2812, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 538, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 350, check)
      call createCurrent(P_WQPlus, P_tAnti, P_b, 1415, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_G0, P_ghWp, 1976, check)
      call createCurrent(P_WMinus, P_A, P_ghAAnti, P_ghWp, 2653, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 569, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_GMinus, P_ghWp, 1824, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 1774, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 217, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 2024, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 899, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_GQ0, 286, check)
      call createCurrent(P_GQ0, P_GMinus, P_A, P_WQPlus, 432, check)
      call createCurrent(P_HQ, P_GPlus, P_WMinus, P_ZQ, 2316, check)
      call createCurrent(P_HQ, P_ghWp, P_GMinus, P_ghAAnti, 2365, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 61, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_GMinus, 1657, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 573, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_A, P_ghWp, 2594, check)
      call createCurrent(P_G0, P_G0, P_ghWmAnti, P_ghWm, 1678, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_A, P_ghZ, 2591, check)
      call createCurrent(P_ghZAnti, P_Z, P_ghWm, P_WPlus, 895, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 3531, check)
      call createCurrent(P_H, P_Z, P_Z, 3141, check)
      call createCurrent(P_WQMinus, P_H, P_GPlus, P_AQ, 800, check)
      call createCurrent(P_WQMinus, P_WPlus, P_AQ, 1512, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_GMinus, P_ghWm, 3499, check)
      call createCurrent(P_ZQ, P_A, P_ghWm, P_ghWmAnti, 3627, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WQPlus, 963, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, P_A, 1234, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Z, P_WPlus, 1091, check)
      call createCurrent(P_GQMinus, P_ghZ, P_GPlus, P_ghZAnti, 1216, check)
      call createCurrent(P_ghWp, P_ghWmAnti, P_WMinus, P_WQMinus, 762, check)
      call createCurrent(P_HQ, P_WPlus, P_GMinus, P_ZQ, 2759, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_G0, P_ghWm, 1401, check)
      call createCurrent(P_H, P_g, P_H, P_g, 3975, check)
      call createCurrent(P_HQ, P_H, P_ghWpAnti, P_ghWp, 2896, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_Z, 3011, check)
      call createCurrent(P_s, P_A, P_sAnti, 229, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_GQ0, 376, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 3927, check)
      call createCurrent(P_ghZ, P_GPlus, P_G0, P_ghWpAnti, 1923, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghAAnti, P_ghA, 3285, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_GPlus, 2065, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_A, 2472, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 3081, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WMinus, P_WPlus, 2568, check)
      call createCurrent(P_H, P_G0, P_A, 3848, check)
      call createCurrent(P_GQ0, P_tAnti, P_t, 138, check)
      call createCurrent(P_ZQ, P_ghWp, P_WMinus, P_ghZAnti, 1746, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_WPlus, P_ghA, 1504, check)
      call createCurrent(P_HQ, P_Z, P_WMinus, P_GQPlus, 3691, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WPlus, P_WQMinus, 3618, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghZAnti, P_ghWm, 1858, check)
      call createCurrent(P_WQPlus, P_A, P_ghWpAnti, P_ghZ, 1916, check)
      call createCurrent(P_GQMinus, P_H, P_GPlus, P_HQ, 2604, check)
      call createCurrent(P_G0, P_H, P_Z, 860, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 3985, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_ZQ, 3713, check)
      call createCurrent(P_ZQ, P_WMinus, P_WPlus, P_AQ, 1553, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 141, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 3902, check)
      call createCurrent(P_ghA, P_GMinus, P_H, P_ghWmAnti, 2642, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 2542, check)
      call createCurrent(P_WQPlus, P_H, P_WMinus, P_GQ0, 3187, check)
      call createCurrent(P_Z, P_ghA, P_WPlus, P_ghWpAnti, 3238, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghZ, P_WPlus, 3394, check)
      call createCurrent(P_ghA, P_GPlus, P_GMinus, P_ghAAnti, 2919, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GQPlus, 1237, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghWmAnti, P_WMinus, 348, check)
      call createCurrent(P_GQPlus, P_ghA, P_G0, P_ghWpAnti, 1648, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HQ, 3624, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZ, P_ghZAnti, 2917, check)
      call createCurrent(P_cAnti, P_A, P_c, 1078, check)
      call createCurrent(P_g, P_g, P_H, 3933, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 2053, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 1492, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 2718, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_H, 74, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 121, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZAnti, P_ghA, 1848, check)
      call createCurrent(P_AQ, P_ghWp, P_Z, P_ghWpAnti, 2129, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GQMinus, 1071, check)
      call createCurrent(P_AQ, P_ePlus, P_eMinus, 3748, check)
      call createCurrent(P_AQ, P_WPlus, P_G0, P_GQMinus, 3183, check)
      call createCurrent(P_ghWp, P_A, P_WMinus, P_ghAAnti, 2895, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 1098, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, P_A, 1946, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 1317, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 3644, check)
      call createCurrent(P_AQ, P_s, P_sAnti, 1176, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 1262, check)
      call createCurrent(P_G0, P_ghZ, P_G0, P_ghZAnti, 1153, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_G0, 3539, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghZ, P_WMinus, 3567, check)
      call createCurrent(P_muMinus, P_muPlus, 3875, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_Z, 2098, check)
      call createCurrent(P_ghA, P_GMinus, P_G0, P_ghWmAnti, 2672, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_GMinus, P_ghA, 3495, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 3334, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, P_HQ, 2910, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 2369, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_ZQ, 2169, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, P_H, 2180, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_WMinus, P_ghWp, 494, check)
      call createCurrent(P_bAnti, P_b, P_G0, 134, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_A, 1750, check)
      call createCurrent(P_ghAAnti, P_Z, P_WPlus, P_ghWm, 479, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 3915, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 2118, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_HQ, 2038, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 4, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 923, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 15, check)
      call createCurrent(P_bAnti, P_b, P_AQ, 1281, check)
      call createCurrent(P_uAnti, P_u, P_H, 3492, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 934, check)
      call createCurrent(P_WQPlus, P_G0, P_GMinus, P_ZQ, 3606, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_Z, 1362, check)
      call createCurrent(P_WQPlus, P_nu_tauAnti, P_tauMinus, 3741, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_GPlus, P_ghA, 3687, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZAnti, P_ghA, 1085, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_ghZ, 2814, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 2187, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 3916, check)
      call createCurrent(P_AQ, P_sAnti, P_s, 3397, check)
      call createCurrent(P_A, P_Z, 3888, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghA, P_WMinus, 1803, check)
      call createCurrent(P_HQ, P_Z, P_GPlus, P_WQMinus, 226, check)
      call createCurrent(P_AQ, P_GPlus, P_Z, P_GQMinus, 3244, check)
      call createCurrent(P_ghZAnti, P_H, P_ghWp, P_GMinus, 631, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 452, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GMinus, P_GQPlus, 2817, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, 3374, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 1076, check)
      call createCurrent(P_b, P_bAnti, P_AQ, 190, check)
      call createCurrent(P_c, P_cAnti, P_HQ, 2622, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 1766, check)
      call createCurrent(P_b, P_bAnti, P_G0, 769, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 3612, check)
      call createCurrent(P_Z, P_ghA, P_WMinus, P_ghWmAnti, 3436, check)
      call createCurrent(P_ghA, P_A, P_ghWpAnti, P_WQPlus, 2792, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_GMinus, 264, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_ghWp, 1252, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 1977, check)
      call createCurrent(P_GQPlus, P_G0, P_ghA, P_ghWpAnti, 67, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 1600, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_HQ, 3193, check)
      call createCurrent(P_H, P_sAnti, P_s, 2148, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 489, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, P_GQ0, 809, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 3419, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 1985, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_GMinus, P_ghWp, 2009, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 2789, check)
      call createCurrent(P_AQ, P_Z, P_ghWmAnti, P_ghWm, 3673, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWp, P_WMinus, 2601, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 3490, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 3367, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_GQ0, 236, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghA, P_ghAAnti, 51, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 1089, check)
      call createCurrent(P_uAnti, P_d, P_GQPlus, 1781, check)
      call createCurrent(P_GQ0, P_c, P_cAnti, 3020, check)
      call createCurrent(P_A, P_ghZAnti, P_WPlus, P_ghWm, 3117, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Z, P_AQ, 2271, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_GQPlus, 2628, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 1404, check)
      call createCurrent(P_ghA, P_GPlus, P_G0, P_ghWpAnti, 2557, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 3582, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 3633, check)
      call createCurrent(P_WQMinus, P_dAnti, P_u, 1886, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 2039, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WPlus, P_WQMinus, 3428, check)
      call createCurrent(P_GPlus, P_ghWp, P_ghWpAnti, P_GMinus, 1396, check)
      call createCurrent(P_HQ, P_ghZ, P_GPlus, P_ghWpAnti, 3053, check)
      call createCurrent(P_ZQ, P_eMinus, P_ePlus, 1493, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghAAnti, P_WPlus, 3232, check)
      call createCurrent(P_u, P_uAnti, P_AQ, 1655, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 2421, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 3241, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 3690, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWmAnti, P_WMinus, 3289, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghA, P_ghZAnti, 3768, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_GQPlus, 2162, check)
      call createCurrent(P_Z, P_WMinus, P_ghA, P_ghWmAnti, 3080, check)
      call createCurrent(P_AQ, P_WPlus, P_ghZAnti, P_ghWm, 2689, check)
      call createCurrent(P_WQMinus, P_G0, P_Z, P_GQPlus, 352, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 3506, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 3868, check)
      call createCurrent(P_ZQ, P_c, P_cAnti, 3772, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 1823, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 2571, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_WMinus, P_ghA, 3214, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 2124, check)
      call createCurrent(P_H, P_ghWp, P_ghAAnti, P_GMinus, 1363, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_GQMinus, 1088, check)
      call createCurrent(P_WPlus, P_WPlus, P_ghWpAnti, P_ghWm, 3485, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_GQ0, 484, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 1852, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 3054, check)
      call createCurrent(P_G0, P_Z, 3842, check)
      call createCurrent(P_WQPlus, P_Z, P_ghA, P_ghWpAnti, 749, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, P_A, 3154, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_A, P_ghA, 1880, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_ZQ, 777, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 3874, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghA, P_WPlus, 1444, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 3384, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 3949, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 2613, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghA, P_GMinus, 446, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_Z, P_ghWp, 3666, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_GQ0, 2877, check)
      call createCurrent(P_Z, P_ghZ, P_ghWmAnti, P_WMinus, 3361, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_ZQ, 6, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 3865, check)
      call createCurrent(P_ZQ, P_G0, P_WPlus, P_GQMinus, 293, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_HQ, 2090, check)
      call createCurrent(P_GQMinus, P_ghZ, P_ghWmAnti, 2881, check)
      call createCurrent(P_WQPlus, P_H, P_GMinus, P_AQ, 2810, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_AQ, 1160, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_ZQ, 2360, check)
      call createCurrent(P_muPlus, P_muMinus, P_ZQ, 3676, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghA, P_WMinus, 1479, check)
      call createCurrent(P_G0, P_ghAAnti, P_GPlus, P_ghWm, 2953, check)
      call createCurrent(P_GQ0, P_muPlus, P_muMinus, 1503, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 267, check)
      call createCurrent(P_ghWp, P_A, P_A, P_ghWpAnti, 143, check)
      call createCurrent(P_WQPlus, P_ghZ, P_Z, P_ghWpAnti, 3604, check)
      call createCurrent(P_ZQ, P_nu_tauAnti, P_nu_tau, 2406, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GQPlus, 1339, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, 3507, check)
      call createCurrent(P_H, P_ghWm, P_ghZAnti, P_GPlus, 836, check)
      call createCurrent(P_GPlus, P_ghZ, P_GMinus, P_ghZAnti, 79, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 2387, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWm, P_ghWmAnti, 2351, check)
      call createCurrent(P_A, P_WPlus, P_ghWm, P_ghZAnti, 1801, check)
      call createCurrent(P_WQMinus, P_H, P_H, P_WQPlus, 1982, check)
      call createCurrent(P_HQ, P_tauPlus, P_tauMinus, 989, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Z, P_WPlus, 3198, check)
      call createCurrent(P_ghZ, P_WMinus, P_A, P_ghWmAnti, 770, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 2848, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_HQ, 3465, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 156, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_WMinus, P_ghA, 2054, check)
      call createCurrent(P_Z, P_Z, P_ghWpAnti, P_ghWp, 1631, check)
      call createCurrent(P_G0, P_ghA, P_GPlus, P_ghWpAnti, 147, check)
      call createCurrent(P_Z, P_H, P_H, P_A, 3841, check)
      call createCurrent(P_A, P_ghWpAnti, P_WPlus, P_ghZ, 2941, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWmAnti, P_ghWm, 1583, check)
      call createCurrent(P_gQ, P_t, P_tAnti, 3026, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, P_A, 1318, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 907, check)
      call createCurrent(P_sAnti, P_s, P_GQ0, 9, check)
      call createCurrent(P_GQ0, P_ghZ, P_G0, P_ghZAnti, 2826, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 2929, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_AQ, 2068, check)
      call createCurrent(P_ghWm, P_H, P_H, P_ghWmAnti, 1150, check)
      call createCurrent(P_WQPlus, P_WPlus, P_ghWpAnti, P_ghWm, 2606, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_ZQ, 1495, check)
      call createCurrent(P_ghZ, P_H, P_ghWmAnti, P_GMinus, 2575, check)
      call createCurrent(P_GQPlus, P_G0, P_WMinus, P_ZQ, 2156, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 590, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 116, check)
      call createCurrent(P_GPlus, P_H, P_ghAAnti, P_ghWm, 359, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_GQ0, 852, check)
      call createCurrent(P_eMinus, P_ePlus, P_GQ0, 215, check)
      call createCurrent(P_d, P_dAnti, P_gQ, 2349, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghAAnti, P_ghZ, 84, check)
      call createCurrent(P_WQMinus, P_muPlus, P_nu_mu, 535, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghZAnti, P_ghWm, 2987, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 547, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 3863, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 390, check)
      call createCurrent(P_ePlus, P_nu_e, P_WQMinus, 2652, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_G0, 2659, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_AQ, 2662, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 2497, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_G0, 2640, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_Z, 1474, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 1166, check)
      call createCurrent(P_tauPlus, P_tauMinus, 3816, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_ZQ, 2931, check)
      call createCurrent(P_Z, P_ghZ, P_WMinus, P_ghWmAnti, 1571, check)
      call createCurrent(P_GQ0, P_G0, P_ghWm, P_ghWmAnti, 234, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_AQ, 1459, check)
      call createCurrent(P_A, P_A, P_H, P_H, 4013, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 3684, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 3850, check)
      call createCurrent(P_WQMinus, P_Z, P_ghWmAnti, P_ghA, 289, check)
      call createCurrent(P_ZQ, P_bAnti, P_b, 1127, check)
      call createCurrent(P_ghWp, P_G0, P_G0, P_ghWpAnti, 313, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghA, P_GPlus, 225, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_ZQ, 903, check)
      call createCurrent(P_GQPlus, P_ghWm, P_ghZAnti, 11, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 3806, check)
      call createCurrent(P_WQMinus, P_Z, P_A, P_WQPlus, 381, check)
      call createCurrent(P_G0, P_GMinus, P_ghWmAnti, P_ghA, 2664, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_H, P_ghZ, 3731, check)
      call createCurrent(P_ghZ, P_H, P_GMinus, P_ghWmAnti, 2095, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghZ, P_GQMinus, 926, check)
      call createCurrent(P_HQ, P_GPlus, P_ghWm, P_ghAAnti, 695, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 2465, check)
      call createCurrent(P_WPlus, P_A, P_ghWm, P_ghAAnti, 321, check)
      call createCurrent(P_Z, P_u, P_uAnti, 726, check)
      call createCurrent(P_WMinus, P_ghA, P_WPlus, P_ghZAnti, 2476, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WMinus, P_WPlus, 3138, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 1645, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_Z, P_ghWp, 3231, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, 730, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 2553, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, P_Z, 1470, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 2692, check)
      call createCurrent(P_GQPlus, P_WPlus, P_WMinus, P_GQMinus, 3398, check)
      call createCurrent(P_g, P_H, P_g, P_H, 3919, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghWmAnti, P_GMinus, 998, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, P_A, 3386, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZ, P_ghZAnti, 2322, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 2862, check)
      call createCurrent(P_GQPlus, P_WMinus, P_HQ, 181, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_H, P_GQMinus, 3148, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_GPlus, 93, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 3767, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 2132, check)
      call createCurrent(P_s, P_sAnti, P_GQ0, 2193, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 2767, check)
      call createCurrent(P_u, P_Z, P_uAnti, 3404, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 3998, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_ghWm, P_GMinus, 2843, check)
      call createCurrent(P_GQPlus, P_WMinus, P_G0, P_AQ, 2481, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 597, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, P_A, 3745, check)
      call createCurrent(P_GPlus, P_G0, P_ghWpAnti, P_ghZ, 1511, check)
      call createCurrent(P_uAnti, P_A, P_u, 932, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, P_g, 737, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWm, P_ghAAnti, 1771, check)
      call createCurrent(P_WQPlus, P_H, P_GQMinus, 801, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_GMinus, 565, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 94, check)
      call createCurrent(P_sAnti, P_c, P_WQMinus, 1634, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 276, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_GPlus, 1242, check)
      call createCurrent(P_AQ, P_tAnti, P_t, 2215, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_ghZ, 1699, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_WPlus, P_ghA, 2867, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_AQ, 1609, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_GQPlus, 96, check)
      call createCurrent(P_WQPlus, P_Z, P_WMinus, P_ZQ, 3177, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_HQ, 2167, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_H, 1106, check)
      call createCurrent(P_s, P_sAnti, P_HQ, 3344, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 3498, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 758, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 2871, check)
      call createCurrent(P_H, P_H, P_ghZAnti, P_ghZ, 1379, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 2359, check)
      call createCurrent(P_bAnti, P_b, P_ZQ, 2259, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 1299, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghZ, P_GMinus, 3546, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 3898, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 3222, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 439, check)
      call createCurrent(P_H, P_g, P_g, 3963, check)
      call createCurrent(P_ghWm, P_A, P_ghAAnti, P_WPlus, 1032, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_G0, 931, check)
      call createCurrent(P_GQPlus, P_ghZ, P_GMinus, P_ghAAnti, 1892, check)
      call createCurrent(P_c, P_cAnti, P_GQ0, 1635, check)
      call createCurrent(P_AQ, P_GMinus, P_GPlus, P_ZQ, 3371, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_H, P_ghZ, 1050, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_G0, 780, check)
      call createCurrent(P_GQPlus, P_ghWm, P_GMinus, P_ghWmAnti, 440, check)
      call createCurrent(P_WPlus, P_ghA, P_Z, P_ghWpAnti, 3352, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_GQ0, 2805, check)
      call createCurrent(P_WQMinus, P_ghA, P_Z, P_ghWmAnti, 298, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_H, P_GPlus, 3056, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 2856, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 2428, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, P_H, 608, check)
      call createCurrent(P_G0, P_GMinus, P_ghWp, P_ghAAnti, 3341, check)
      call createCurrent(P_b, P_Z, P_bAnti, 3616, check)
      call createCurrent(P_d, P_dAnti, P_G0, 375, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 474, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 1987, check)
      call createCurrent(P_ghWpAnti, P_A, P_WPlus, P_ghZ, 1969, check)
      call createCurrent(P_GQ0, P_ghZ, P_GMinus, P_ghWmAnti, 3559, check)
      call createCurrent(P_GMinus, P_H, P_ghWmAnti, P_ghA, 675, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_GQ0, 3046, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 3074, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, P_HQ, 2115, check)
      call createCurrent(P_ghWp, P_GMinus, P_GPlus, P_ghWpAnti, 3335, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 1195, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 2242, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 1277, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_G0, 2585, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 3237, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_AQ, 64, check)
      call createCurrent(P_GQPlus, P_GMinus, P_AQ, 2046, check)
      call createCurrent(P_WQMinus, P_GMinus, P_WPlus, P_GQPlus, 1067, check)
      call createCurrent(P_HQ, P_G0, P_ghWmAnti, P_ghWm, 2109, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 2228, check)
      call createCurrent(P_Z, P_ghWm, P_WPlus, P_ghZAnti, 2578, check)
      call createCurrent(P_WQPlus, P_WMinus, P_GPlus, P_GQMinus, 3186, check)
      call createCurrent(P_ZQ, P_A, P_ghWp, P_ghWpAnti, 493, check)
      call createCurrent(P_ZQ, P_nu_tau, P_nu_tauAnti, 3593, check)
      call createCurrent(P_GQPlus, P_H, P_ghWm, P_ghZAnti, 1340, check)
      call createCurrent(P_A, P_ghWm, P_WPlus, P_ghAAnti, 2206, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 1103, check)
      call createCurrent(P_ZQ, P_WMinus, P_WPlus, P_ZQ, 2060, check)
      call createCurrent(P_ghWp, P_A, P_ghAAnti, P_WMinus, 166, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 3882, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 3946, check)
      call createCurrent(P_ghWpAnti, P_H, P_GPlus, P_ghA, 2191, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, P_A, 39, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GQPlus, 1843, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_GQ0, 1143, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_G0, 988, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_WMinus, P_ghWp, 1613, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghA, P_GQMinus, 3562, check)
      call createCurrent(P_HQ, P_G0, P_ghWm, P_ghWmAnti, 3521, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_G0, 1285, check)
      call createCurrent(P_Z, P_ghWm, P_A, P_ghWmAnti, 500, check)
      call createCurrent(P_A, P_ghWpAnti, P_A, P_ghWp, 2846, check)
      call createCurrent(P_ZQ, P_Z, P_GPlus, P_GQMinus, 2504, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_A, 1582, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WPlus, P_WMinus, 3184, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 2758, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, P_Z, 3343, check)
      call createCurrent(P_HQ, P_H, P_Z, P_ZQ, 449, check)
      call createCurrent(P_GQMinus, P_ghWp, P_GPlus, P_ghWpAnti, 2327, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_A, P_ghWp, 3385, check)
      call createCurrent(P_WQMinus, P_G0, P_GPlus, P_AQ, 3380, check)
      call createCurrent(P_H, P_ghAAnti, P_GPlus, P_ghWm, 2768, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_GPlus, 2112, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 1989, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WQMinus, 1652, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 2190, check)
      call createCurrent(P_A, P_A, P_ghWmAnti, P_ghWm, 582, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_Z, P_ghWm, 1802, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZ, P_ghAAnti, 2949, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghWm, P_WPlus, 3517, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_GPlus, P_ghA, 2916, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HQ, 366, check)
      call createCurrent(P_G0, P_ghZAnti, P_GPlus, P_ghWm, 2012, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_GPlus, P_ghZ, 3137, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 2245, check)
      call createCurrent(P_WQPlus, P_WMinus, P_WPlus, P_WQMinus, 3029, check)
      call createCurrent(P_WQMinus, P_ghWp, P_ghAAnti, 1789, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 1421, check)
      call createCurrent(P_WQPlus, P_H, P_WMinus, P_HQ, 386, check)
      call createCurrent(P_GQ0, P_WMinus, P_A, P_GQPlus, 1360, check)
      call createCurrent(P_GMinus, P_H, P_ghA, P_ghWmAnti, 596, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, P_Z, 592, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_Z, 3110, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 3826, check)
      call createCurrent(P_c, P_cAnti, P_H, 642, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_ghWm, 516, check)
      call createCurrent(P_GQPlus, P_G0, P_ghZ, P_ghWpAnti, 1410, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 2526, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Z, P_WPlus, 108, check)
      call createCurrent(P_H, P_H, P_H, P_H, 60, check)
      call createCurrent(P_GQ0, P_tauMinus, P_tauPlus, 1779, check)
      call createCurrent(P_ghA, P_H, P_ghWmAnti, P_GQMinus, 1877, check)
      call createCurrent(P_AQ, P_H, P_WPlus, P_GQMinus, 1646, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghAAnti, P_WQPlus, 3035, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, P_Z, 2830, check)
      call createCurrent(P_ghWmAnti, P_A, P_A, P_ghWm, 2290, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_Z, P_ghA, 182, check)
      call createCurrent(P_ghZ, P_Z, P_ghWmAnti, P_WQMinus, 671, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 3163, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 794, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 2705, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_H, 2067, check)
      call createCurrent(P_H, P_H, P_ghWp, P_ghWpAnti, 3172, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_GQPlus, 531, check)
      call createCurrent(P_GQ0, P_Z, P_WMinus, P_GQPlus, 88, check)
      call createCurrent(P_HQ, P_GPlus, P_H, P_GQMinus, 1132, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 1367, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 2773, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 3422, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_WPlus, P_ghZ, 3139, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, P_Z, 418, check)
      call createCurrent(P_HQ, P_H, P_ghWmAnti, P_ghWm, 1770, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_A, P_ghA, 3283, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 3042, check)
      call createCurrent(P_muMinus, P_muPlus, P_ZQ, 269, check)
      call createCurrent(P_s, P_sAnti, P_gQ, 1748, check)
      call createCurrent(P_G0, P_GMinus, P_ghWp, P_ghZAnti, 1499, check)
      call createCurrent(P_ZQ, P_H, P_Z, P_HQ, 2540, check)
      call createCurrent(P_cAnti, P_c, P_HQ, 54, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, P_HQ, 1566, check)
      call createCurrent(P_ghA, P_WPlus, P_ghZAnti, P_WQMinus, 693, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WQMinus, 2683, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_GQMinus, 3487, check)
      call createCurrent(P_AQ, P_ghAAnti, P_WPlus, P_ghWm, 3730, check)
      call createCurrent(P_WMinus, P_Z, P_ghAAnti, P_ghWp, 3484, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, P_A, 586, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 709, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 781, check)
      call createCurrent(P_GPlus, P_G0, P_ghWpAnti, P_ghA, 1968, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_G0, P_ghZ, 202, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_H, 2655, check)
      call createCurrent(P_GQPlus, P_nu_muAnti, P_muMinus, 56, check)
      call createCurrent(P_ghZ, P_A, P_WMinus, P_ghWmAnti, 1684, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_Z, P_ghZ, 2388, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 3836, check)
      call createCurrent(P_WQMinus, P_Z, P_G0, P_GQPlus, 841, check)
      call createCurrent(P_AQ, P_G0, P_GPlus, P_WQMinus, 1092, check)
      call createCurrent(P_WQMinus, P_ghA, P_A, P_ghWmAnti, 3106, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 1500, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 3466, check)
      call createCurrent(P_Z, P_ghWmAnti, P_WMinus, P_ghA, 3703, check)
      call createCurrent(P_AQ, P_ghWm, P_ghWmAnti, 925, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 3692, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, 82, check)
      call createCurrent(P_WPlus, P_A, P_ghWpAnti, P_ghA, 1960, check)
      call createCurrent(P_WQPlus, P_A, P_ghWpAnti, P_ghA, 2201, check)
      call createCurrent(P_g, P_s, P_sAnti, 1471, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_Z, 2331, check)
      call createCurrent(P_HQ, P_Z, P_H, P_ZQ, 717, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_A, P_WMinus, 3168, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWp, P_GMinus, 784, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_A, P_WMinus, 2011, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 735, check)
      call createCurrent(P_eMinus, P_ePlus, 3852, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 2049, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 2969, check)
      call createCurrent(P_dAnti, P_d, P_H, 3479, check)
      call createCurrent(P_ZQ, P_ghWp, P_Z, P_ghWpAnti, 1948, check)
      call createCurrent(P_WQPlus, P_ghWm, P_ghZAnti, 2933, check)
      call createCurrent(P_ghWp, P_ghWmAnti, P_WMinus, P_WMinus, 3319, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_ZQ, 3347, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 111, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 3407, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 866, check)
      call createCurrent(P_GQ0, P_ghWm, P_GPlus, P_ghZAnti, 3760, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 325, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 845, check)
      call createCurrent(P_A, P_ghWp, P_ghAAnti, P_WMinus, 3632, check)
      call createCurrent(P_ghZAnti, P_A, P_WMinus, P_ghWp, 1046, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_H, 861, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_G0, P_ghWp, 460, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_GQ0, 840, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 3753, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWp, P_WMinus, 209, check)
      call createCurrent(P_HQ, P_GPlus, P_WQMinus, 2647, check)
      call createCurrent(P_Z, P_H, P_Z, 3006, check)
      call createCurrent(P_A, P_tAnti, P_t, 1354, check)
      call createCurrent(P_WMinus, P_ghA, P_ghZAnti, P_WPlus, 2734, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 1572, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 1878, check)
      call createCurrent(P_A, P_H, P_Z, P_H, 3858, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 3527, check)
      call createCurrent(P_b, P_tAnti, P_GQPlus, 944, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 2439, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WMinus, P_WPlus, 1668, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 1979, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_GQMinus, 83, check)
      call createCurrent(P_GQMinus, P_H, P_ghA, P_ghWmAnti, 3781, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_GQPlus, 2370, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 1174, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_GQMinus, 2479, check)
      call createCurrent(P_GQPlus, P_Z, P_GMinus, P_ZQ, 1756, check)
      call createCurrent(P_g, P_dAnti, P_d, 3188, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_H, 873, check)
      call createCurrent(P_GQPlus, P_H, P_H, P_GQMinus, 255, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WQMinus, 382, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 1484, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_H, 253, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_H, P_GQMinus, 2802, check)
      call createCurrent(P_AQ, P_WPlus, P_Z, P_WQMinus, 1780, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_H, P_ghZ, 430, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWm, P_ghZAnti, 1953, check)
      call createCurrent(P_A, P_WMinus, P_ghZ, P_ghWmAnti, 2925, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_Z, P_ghWp, 681, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WQPlus, 2319, check)
      call createCurrent(P_WQPlus, P_WMinus, P_A, P_AQ, 3059, check)
      call createCurrent(P_ghA, P_WPlus, P_A, P_ghWpAnti, 1429, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 1337, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_G0, 3756, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 2889, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 1530, check)
      call createCurrent(P_GQMinus, P_Z, P_G0, P_WQPlus, 1488, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 3242, check)
      call createCurrent(P_g, P_c, P_cAnti, 183, check)
      call createCurrent(P_GQMinus, P_WPlus, P_G0, P_ZQ, 2815, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghA, P_WQPlus, 2320, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWpAnti, P_WPlus, 635, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_GMinus, 2849, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, P_A, 3230, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 750, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_ZQ, 564, check)
      call createCurrent(P_GQPlus, P_Z, P_GMinus, P_AQ, 2778, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 2485, check)
      call createCurrent(P_g, P_A, P_A, P_g, 3993, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, P_Z, 1327, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 3647, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_G0, 690, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 632, check)
      call createCurrent(P_GQPlus, P_ghA, P_GMinus, P_ghAAnti, 310, check)
      call createCurrent(P_HQ, P_H, P_H, P_HQ, 1984, check)
      call createCurrent(P_Z, P_ghWp, P_Z, P_ghWpAnti, 380, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_WPlus, P_ghZ, 3254, check)
      call createCurrent(P_H, P_GPlus, P_ghWpAnti, P_ghA, 2196, check)
      call createCurrent(P_GQPlus, P_WMinus, P_G0, P_ZQ, 985, check)
      call createCurrent(P_WQMinus, P_GPlus, P_H, P_AQ, 588, check)
      call createCurrent(P_ghWp, P_WPlus, P_ghWpAnti, P_WQMinus, 2573, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_GMinus, 1980, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 3700, check)
      call createCurrent(P_ghWmAnti, P_G0, P_G0, P_ghWm, 1561, check)
      call createCurrent(P_uAnti, P_u, P_GQ0, 198, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 694, check)
      call createCurrent(P_AQ, P_WMinus, P_ghWp, P_ghZAnti, 3601, check)
      call createCurrent(P_tAnti, P_t, P_A, 3516, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_A, 882, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 1636, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 3822, check)
      call createCurrent(P_WQMinus, P_WPlus, P_WPlus, P_WQMinus, 1335, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 618, check)
      call createCurrent(P_WMinus, P_GPlus, 3887, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 3907, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ZQ, 3491, check)
      call createCurrent(P_g, P_sAnti, P_s, 3488, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_A, 1710, check)
      call createCurrent(P_WMinus, P_ghA, P_WPlus, P_ghAAnti, 1198, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghZ, P_WQPlus, 3286, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_A, P_ghWp, 2940, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WQMinus, 3264, check)
      call createCurrent(P_GMinus, P_WPlus, 3885, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 3821, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_GPlus, 404, check)
      call createCurrent(P_ZQ, P_ghAAnti, P_WPlus, P_ghWm, 3628, check)
      call createCurrent(P_A, P_t, P_tAnti, 1650, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_GQPlus, 2531, check)
      call createCurrent(P_b, P_G0, P_bAnti, 3696, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 980, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_GQ0, 358, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghA, P_GPlus, 3255, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 3613, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 2502, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 1954, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 128, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WMinus, P_WPlus, 3689, check)
      call createCurrent(P_ZQ, P_d, P_dAnti, 2693, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghZ, P_WQPlus, 1751, check)
      call createCurrent(P_Z, P_s, P_sAnti, 776, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, P_A, 610, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_HQ, 252, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 1629, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 1988, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, 1733, check)
      call createCurrent(P_ghA, P_H, P_ghWmAnti, P_GMinus, 1765, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, P_H, 912, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 445, check)
      call createCurrent(P_ghWm, P_WPlus, P_Z, P_ghAAnti, 2237, check)
      call createCurrent(P_sAnti, P_s, P_g, 1791, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 3602, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWpAnti, P_ghZ, 1258, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_GQ0, 3142, check)
      call createCurrent(P_WPlus, P_GMinus, 3878, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_A, P_ghWm, 2639, check)
      call createCurrent(P_A, P_Z, P_H, 3905, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 3940, check)
      call createCurrent(P_A, P_H, P_A, P_H, 3924, check)
      call createCurrent(P_AQ, P_ghWm, P_WPlus, P_ghAAnti, 1108, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 1759, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 2279, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, P_Z, 2456, check)
      call createCurrent(P_ghZ, P_GPlus, P_GMinus, P_ghZAnti, 1654, check)
      call createCurrent(P_AQ, P_ghWm, P_Z, P_ghWmAnti, 3012, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 3661, check)
      call createCurrent(P_GMinus, P_H, P_ghAAnti, P_ghWp, 3701, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_AQ, 1742, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 1790, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghZ, P_GPlus, 612, check)
      call createCurrent(P_tAnti, P_t, P_g, 581, check)
      call createCurrent(P_GQPlus, P_H, P_WQMinus, 991, check)
      call createCurrent(P_GQPlus, P_Z, P_Z, P_GQMinus, 2775, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghA, P_ghAAnti, 3265, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 1386, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 421, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 3432, check)
      call createCurrent(P_GQ0, P_GPlus, P_A, P_WQMinus, 2660, check)
      call createCurrent(P_WPlus, P_ghWm, P_WPlus, P_ghWpAnti, 3481, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_G0, 3161, check)
      call createCurrent(P_HQ, P_GMinus, P_ghAAnti, P_ghWp, 1428, check)
      call createCurrent(P_HQ, P_WPlus, P_WMinus, P_HQ, 3533, check)
      call createCurrent(P_AQ, P_GPlus, P_GMinus, P_AQ, 1715, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_ZQ, 364, check)
      call createCurrent(P_nu_e, P_ePlus, P_WQMinus, 3050, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 3672, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_AQ, 1114, check)
      call createCurrent(P_WPlus, P_A, P_ghWpAnti, P_ghZ, 1926, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 789, check)
      call createCurrent(P_ghWp, P_WPlus, P_ghWpAnti, P_WMinus, 1292, check)
      call createCurrent(P_ghWm, P_WPlus, P_WMinus, P_ghWmAnti, 2105, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_G0, 778, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 3600, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 666, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZAnti, P_ghA, 3218, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 1950, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Z, P_WQPlus, 651, check)
      call createCurrent(P_A, P_ghAAnti, P_WPlus, P_ghWm, 2482, check)
      call createCurrent(P_g, P_g, P_g, 2172, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 1917, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 2586, check)
      call createCurrent(P_tAnti, P_b, P_WQPlus, 655, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 231, check)
      call createCurrent(P_GQPlus, P_ghAAnti, P_GMinus, P_ghA, 2017, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghA, P_WQMinus, 3296, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 3523, check)
      call createCurrent(P_ZQ, P_dAnti, P_d, 847, check)
      call createCurrent(P_Z, P_ghWp, P_ghZAnti, P_WMinus, 2827, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZ, P_ghAAnti, 283, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_ZQ, 3423, check)
      call createCurrent(P_ghAAnti, P_Z, P_ghWm, P_WPlus, 2175, check)
      call createCurrent(P_AQ, P_GPlus, P_GQMinus, 73, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_HQ, 395, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_ghZ, 1955, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 1951, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 2087, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 3292, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 1296, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 2952, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 417, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWm, P_ghZAnti, 1752, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 2860, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 1311, check)
      call createCurrent(P_d, P_dAnti, P_HQ, 825, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 1612, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 3288, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_HQ, 1914, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_H, P_ghWp, 2091, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_G0, 1280, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_ZQ, 3615, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 1232, check)
      call createCurrent(P_GQ0, P_WMinus, P_WQPlus, 230, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_GQ0, 1476, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghA, P_GMinus, 38, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_GQMinus, 1172, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_H, 2440, check)
      call createCurrent(P_WPlus, P_ghZ, P_A, P_ghWpAnti, 811, check)
      call createCurrent(P_GQPlus, P_ghWm, P_G0, P_ghZAnti, 356, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 1124, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 2135, check)
      call createCurrent(P_ghWpAnti, P_WMinus, P_ghWp, P_WPlus, 733, check)
      call createCurrent(P_WQPlus, P_nu_muAnti, P_muMinus, 2937, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 25, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_AQ, 740, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_A, P_WQMinus, 1112, check)
      call createCurrent(P_A, P_ghWm, P_ghZAnti, P_WPlus, 1893, check)
      call createCurrent(P_gQ, P_u, P_uAnti, 388, check)
      call createCurrent(P_Z, P_WMinus, P_ghWp, P_ghZAnti, 7, check)
      call createCurrent(P_GPlus, P_ghZ, P_H, P_ghWpAnti, 1856, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_AQ, 1105, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_A, P_ghWm, 2143, check)
      call createCurrent(P_H, P_H, P_H, 790, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 1640, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghAAnti, P_ghZ, 2374, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_A, 668, check)
      call createCurrent(P_H, P_ghWpAnti, P_GPlus, P_ghZ, 1574, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_H, P_ghWm, 224, check)
      call createCurrent(P_WQMinus, P_c, P_sAnti, 2498, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_GMinus, 2658, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_A, P_ghA, 706, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 2224, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 3486, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 3596, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 1616, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghAAnti, P_ghA, 553, check)
      call createCurrent(P_Z, P_ghA, P_ghWmAnti, P_WMinus, 2936, check)
      call createCurrent(P_ghZAnti, P_Z, P_WPlus, P_ghWm, 2081, check)
      call createCurrent(P_GQMinus, P_muPlus, P_nu_mu, 2308, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_GMinus, 918, check)
      call createCurrent(P_H, P_GMinus, P_ghWp, P_ghZAnti, 1370, check)
      call createCurrent(P_ghWpAnti, P_WMinus, P_WPlus, P_ghWp, 3798, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 3861, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_A, 2978, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 3961, check)
      call createCurrent(P_ePlus, P_eMinus, 3883, check)
      call createCurrent(P_AQ, P_G0, P_GMinus, P_WQPlus, 2235, check)
      call createCurrent(P_bAnti, P_t, P_WQMinus, 3217, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 1256, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 558, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 1191, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 3965, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_GQPlus, 1364, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_A, 343, check)
      call createCurrent(P_GQMinus, P_ghZ, P_H, P_ghWmAnti, 3089, check)
      call createCurrent(P_ghA, P_GPlus, P_GMinus, P_ghZAnti, 3323, check)
      call createCurrent(P_GQ0, P_d, P_dAnti, 2668, check)
      call createCurrent(P_A, P_WMinus, P_ghAAnti, P_ghWp, 477, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 1506, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 548, check)
      call createCurrent(P_g, P_g, P_H, P_H, 3937, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 930, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 4005, check)
      call createCurrent(P_ghA, P_A, P_ghWmAnti, P_WQMinus, 159, check)
      call createCurrent(P_ghZ, P_WMinus, P_Z, P_ghWmAnti, 2299, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZ, P_ghAAnti, 1603, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghA, P_WQMinus, 92, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 939, check)
      call createCurrent(P_ghWp, P_GMinus, P_H, P_ghAAnti, 2701, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghZ, P_GPlus, 3675, check)
      call createCurrent(P_GQMinus, P_Z, P_GPlus, P_ZQ, 196, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 423, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_GMinus, 1184, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, P_Z, 2755, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 2927, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_WMinus, P_ghWp, 3169, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 3733, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_Z, 974, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 3978, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 2899, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GPlus, P_GQMinus, 103, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_G0, P_ghZ, 3151, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghWp, P_ghWpAnti, 3114, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ZQ, 566, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 3934, check)
      call createCurrent(P_GPlus, P_ghZ, P_GMinus, P_ghAAnti, 429, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WQPlus, 2460, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 3932, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Z, P_WMinus, 591, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 3774, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 1119, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 3890, check)
      call createCurrent(P_G0, P_s, P_sAnti, 839, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 2556, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWp, P_WQMinus, 402, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_A, 2615, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghZ, P_GPlus, 1041, check)
      call createCurrent(P_ghZAnti, P_H, P_ghWm, P_GPlus, 456, check)
      call createCurrent(P_GQ0, P_ghZ, P_GPlus, P_ghWpAnti, 3274, check)
      call createCurrent(P_A, P_ghA, P_WMinus, P_ghWmAnti, 3396, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_ghWm, 357, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_G0, 3475, check)
      call createCurrent(P_WQMinus, P_Z, P_ghZ, P_ghWmAnti, 3421, check)
      call createCurrent(P_ZQ, P_G0, P_Z, P_GQ0, 3450, check)
      call createCurrent(P_GQPlus, P_G0, P_G0, P_GQMinus, 905, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_H, 1122, check)
      call createCurrent(P_H, P_A, P_Z, 3823, check)
      call createCurrent(P_Z, P_H, P_G0, 1023, check)
      call createCurrent(P_ghZ, P_H, P_H, P_ghZAnti, 1585, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, P_GQ0, 3078, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 1225, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 3893, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WQMinus, 2097, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 18, check)
      call createCurrent(P_GQ0, P_G0, P_GMinus, P_GQPlus, 2144, check)
      call createCurrent(P_WPlus, P_ghA, P_ghZAnti, P_WMinus, 441, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 4012, check)
      call createCurrent(P_tAnti, P_t, P_G0, 736, check)
      call createCurrent(P_AQ, P_A, P_ghWm, P_ghWmAnti, 1178, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_G0, 771, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 2994, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_GQPlus, 349, check)
      call createCurrent(P_ghWm, P_Z, P_Z, P_ghWmAnti, 3654, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_H, P_ghA, 125, check)
      call createCurrent(P_H, P_ghZAnti, P_ghWm, P_GPlus, 1829, check)
      call createCurrent(P_s, P_G0, P_sAnti, 3514, check)
      call createCurrent(P_GQMinus, P_GPlus, P_WMinus, P_WQPlus, 3060, check)
      call createCurrent(P_GQMinus, P_WPlus, P_G0, P_AQ, 45, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 387, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 1324, check)
      call createCurrent(P_A, P_sAnti, P_s, 3761, check)
      call createCurrent(P_A, P_ghWm, P_ghAAnti, P_WPlus, 2146, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 345, check)
      call createCurrent(P_sAnti, P_c, P_GQMinus, 2475, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, P_A, 436, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 330, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 3892, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_H, P_GPlus, 2114, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 2838, check)
      call createCurrent(P_d, P_A, P_dAnti, 1044, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_WPlus, P_ghA, 3656, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_GQMinus, 3568, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GQ0, 2593, check)
      call createCurrent(P_GQPlus, P_A, P_GMinus, P_ZQ, 1738, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_ZQ, 2791, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_Z, 331, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 158, check)
      call createCurrent(P_GQ0, P_Z, P_G0, P_ZQ, 1545, check)
      call createCurrent(P_GQPlus, P_Z, P_WQMinus, 2204, check)
      call createCurrent(P_c, P_cAnti, P_AQ, 687, check)
      call createCurrent(P_ghWm, P_WPlus, P_WPlus, P_ghWpAnti, 1910, check)
      call createCurrent(P_H, P_ghWp, P_ghZAnti, P_GMinus, 972, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, P_H, 1316, check)
      call createCurrent(P_WQPlus, P_Z, P_WQMinus, 1073, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 1874, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 3942, check)
      call createCurrent(P_ZQ, P_ePlus, P_eMinus, 2707, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghA, P_WMinus, 2247, check)
      call createCurrent(P_AQ, P_WPlus, P_A, P_WQMinus, 1996, check)
      call createCurrent(P_ghWp, P_Z, P_Z, P_ghWpAnti, 686, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 2236, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 554, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_HQ, 2890, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghWp, P_GMinus, 3221, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 3530, check)
      call createCurrent(P_WPlus, P_ghWp, P_WMinus, P_ghWpAnti, 1156, check)
      call createCurrent(P_GQ0, P_tauPlus, P_tauMinus, 34, check)
      call createCurrent(P_WQMinus, P_ghZ, P_A, P_ghWmAnti, 2261, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 2217, check)
      call createCurrent(P_A, P_H, P_H, P_A, 3983, check)
      call createCurrent(P_Z, P_WMinus, P_ghZAnti, P_ghWp, 2552, check)
      call createCurrent(P_G0, P_ghWpAnti, P_G0, P_ghWp, 1876, check)
      call createCurrent(P_A, P_A, P_ghWp, P_ghWpAnti, 152, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 3143, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 3844, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_H, P_GPlus, 1694, check)
      call createCurrent(P_GQMinus, P_H, P_WQPlus, 2198, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 3877, check)
      call createCurrent(P_ghWmAnti, P_A, P_WMinus, P_ghZ, 1869, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_A, 227, check)
      call createCurrent(P_H, P_ghWmAnti, P_GMinus, P_ghA, 2749, check)
      call createCurrent(P_ZQ, P_tauPlus, P_tauMinus, 3076, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 437, check)
      call createCurrent(P_ghWm, P_WPlus, P_A, P_ghZAnti, 2036, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_A, P_ghWm, 249, check)
      call createCurrent(P_muPlus, P_muMinus, P_HQ, 1580, check)
      call createCurrent(P_GQMinus, P_ghWp, P_H, P_ghZAnti, 2213, check)
      call createCurrent(P_s, P_sAnti, P_A, 638, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_A, P_ghA, 3437, check)
      call createCurrent(P_Z, P_A, P_ghWm, P_ghWmAnti, 715, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_A, 1755, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, P_Z, 1761, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_G0, 1534, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 3461, check)
      call createCurrent(P_AQ, P_WPlus, P_WQMinus, 1110, check)
      call createCurrent(P_WQMinus, P_A, P_WPlus, P_ZQ, 775, check)
      call createCurrent(P_d, P_dAnti, P_Z, 1956, check)
      call createCurrent(P_GQPlus, P_GMinus, P_A, P_ZQ, 3663, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, P_H, 629, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 3116, check)
      call createCurrent(P_GQPlus, P_H, P_WMinus, P_AQ, 941, check)
      call createCurrent(P_Z, P_bAnti, P_b, 3047, check)
      call createCurrent(P_GQ0, P_G0, P_WMinus, P_WQPlus, 2462, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 2120, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 3968, check)
      call createCurrent(P_GQ0, P_GPlus, P_Z, P_WQMinus, 1615, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 411, check)
      call createCurrent(P_GQPlus, P_A, P_A, P_GQMinus, 2644, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_GMinus, 3585, check)
      call createCurrent(P_GQMinus, P_GPlus, P_AQ, 1611, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghWpAnti, P_WPlus, 3734, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 2405, check)
      call createCurrent(P_Z, P_dAnti, P_d, 1010, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, P_HQ, 678, check)
      call createCurrent(P_ghA, P_GPlus, P_H, P_ghWpAnti, 2055, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 2231, check)
      call createCurrent(P_H, P_A, P_A, P_H, 3981, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WQPlus, 1462, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_Z, 1374, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 1814, check)
      call createCurrent(P_dAnti, P_H, P_d, 2157, check)
      call createCurrent(P_Z, P_WMinus, P_ghWp, P_ghAAnti, 2445, check)
      call createCurrent(P_HQ, P_A, P_GPlus, P_WQMinus, 3045, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWp, P_ghWpAnti, 843, check)
      call createCurrent(P_A, P_c, P_cAnti, 396, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 3960, check)
      call createCurrent(P_WMinus, P_ghWm, P_WPlus, P_ghWmAnti, 908, check)
      call createCurrent(P_t, P_tAnti, P_A, 1620, check)
      call createCurrent(P_GQPlus, P_H, P_ghWpAnti, P_ghZ, 3213, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WQPlus, 2131, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_GQPlus, 3622, check)
      call createCurrent(P_G0, P_ghWp, P_ghZAnti, P_GMinus, 2562, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 3483, check)
      call createCurrent(P_ZQ, P_Z, P_ghWmAnti, P_ghWm, 561, check)
      call createCurrent(P_GQPlus, P_GPlus, P_GMinus, P_GQMinus, 2985, check)
      call createCurrent(P_A, P_uAnti, P_u, 2550, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 1778, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 1812, check)
      call createCurrent(P_H, P_H, P_A, P_A, 3976, check)
      call createCurrent(P_s, P_H, P_sAnti, 3597, check)
      call createCurrent(P_GQMinus, P_WPlus, P_AQ, 1001, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, P_A, 2347, check)
      call createCurrent(P_muPlus, P_muMinus, P_GQ0, 2559, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_H, 3295, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_HQ, 414, check)
      call createCurrent(P_WQMinus, P_ghZ, P_WPlus, P_ghZAnti, 2147, check)
      call createCurrent(P_ghA, P_WMinus, P_WPlus, P_ghZAnti, 2954, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 2944, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_G0, 2522, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 4000, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Z, P_WMinus, 1890, check)
      call createCurrent(P_uAnti, P_u, 3889, check)
      call createCurrent(P_WQPlus, P_ghWm, P_ghAAnti, 1918, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 1747, check)
      call createCurrent(P_GQPlus, P_tAnti, P_b, 338, check)
      call createCurrent(P_HQ, P_WMinus, P_WPlus, P_HQ, 2424, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 1689, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WMinus, P_WQPlus, 3111, check)
      call createCurrent(P_GQ0, P_ghWp, P_H, P_ghWpAnti, 2717, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghAAnti, P_ghA, 2993, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_ZQ, 786, check)
      call createCurrent(P_HQ, P_WPlus, P_GQMinus, 3448, check)
      call createCurrent(P_s, P_g, P_sAnti, 2598, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 864, check)
      call createCurrent(P_GPlus, P_H, P_ghZ, P_ghWpAnti, 1847, check)
      call createCurrent(P_WQMinus, P_GPlus, P_HQ, 614, check)
      call createCurrent(P_H, P_A, P_H, P_Z, 3886, check)
      call createCurrent(P_A, P_ghWp, P_ghZAnti, P_WMinus, 1376, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_GQ0, 2696, check)
      call createCurrent(P_ZQ, P_A, P_ghWmAnti, P_ghWm, 3631, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, P_Z, 3167, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 3318, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_ZQ, 1736, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_Z, P_ghA, 3563, check)
      call createCurrent(P_WPlus, P_A, P_ghZAnti, P_ghWm, 2537, check)
      call createCurrent(P_ghAAnti, P_H, P_ghWm, P_GPlus, 1155, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, P_Z, 1909, check)
      call createCurrent(P_ghZ, P_A, P_ghWpAnti, P_WQPlus, 3497, check)
      call createCurrent(P_s, P_cAnti, P_GQPlus, 3769, check)
      call createCurrent(P_WQPlus, P_A, P_ghA, P_ghWpAnti, 1992, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_GPlus, P_ghWp, 3699, check)
      call createCurrent(P_b, P_bAnti, P_HQ, 1239, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 3577, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, P_Z, 3027, check)
      call createCurrent(P_WPlus, P_ghWp, P_ghWpAnti, P_WMinus, 237, check)
      call createCurrent(P_ghWm, P_A, P_WPlus, P_ghZAnti, 3664, check)
      call createCurrent(P_A, P_ghZ, P_ghWpAnti, P_WPlus, 3314, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZ, P_ghAAnti, 2800, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_G0, 3773, check)
      call createCurrent(P_WQMinus, P_H, P_GQPlus, 2873, check)
      call createCurrent(P_dAnti, P_d, 3819, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 3609, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 3580, check)
      call createCurrent(P_GQ0, P_WPlus, P_WQMinus, 68, check)
      call createCurrent(P_s, P_sAnti, P_Z, 1115, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 3987, check)
      call createCurrent(P_g, P_H, P_g, 3914, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghZ, P_GPlus, 1898, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 2991, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 3203, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_GQ0, 3572, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 1233, check)
      call createCurrent(P_ZQ, P_GMinus, P_Z, P_GQPlus, 898, check)
      call createCurrent(P_A, P_ghZAnti, P_ghWm, P_WPlus, 1546, check)
      call createCurrent(P_Z, P_A, P_ghWpAnti, P_ghWp, 1074, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_Z, 3051, check)
      call createCurrent(P_WMinus, P_Z, P_ghWmAnti, P_ghZ, 953, check)
      call createCurrent(P_HQ, P_H, P_ghWp, P_ghWpAnti, 285, check)
      call createCurrent(P_ghAAnti, P_A, P_ghWm, P_WPlus, 3762, check)
      call createCurrent(P_ZQ, P_GMinus, P_A, P_GQPlus, 1661, check)
      call createCurrent(P_WQMinus, P_Z, P_ghA, P_ghWmAnti, 1065, check)
      call createCurrent(P_cAnti, P_g, P_c, 3381, check)
      call createCurrent(P_gQ, P_ghGAnti, P_g, P_ghG, 2885, check)
      call createCurrent(P_ghWp, P_A, P_Z, P_ghWpAnti, 3659, check)
      call createCurrent(P_A, P_cAnti, P_c, 113, check)
      call createCurrent(P_u, P_dAnti, P_GQMinus, 1632, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_GQ0, 1020, check)
      call createCurrent(P_WPlus, P_ghA, P_A, P_ghWpAnti, 26, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 1961, check)
      call createCurrent(P_tAnti, P_H, P_t, 3679, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WQPlus, 3226, check)
      call createCurrent(P_sAnti, P_s, P_HQ, 2776, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_GQPlus, 3165, check)
      call createCurrent(P_WQPlus, P_ghZ, P_WMinus, P_ghZAnti, 2736, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_GMinus, P_ghWp, 1125, check)
      call createCurrent(P_ZQ, P_WPlus, P_GQMinus, 587, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 1102, check)
      call createCurrent(P_g, P_tAnti, P_t, 894, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghAAnti, P_ghA, 507, check)
      call createCurrent(P_ghWp, P_Z, P_WMinus, P_ghZAnti, 1827, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 3569, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_HQ, 2507, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 992, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 3851, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_A, P_ghZ, 876, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 3954, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_GQ0, 3037, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 1289, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 3950, check)
      call createCurrent(P_GQ0, P_ghWp, P_ghWpAnti, 3204, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_HQ, 3594, check)
      call createCurrent(P_GQMinus, P_ghWpAnti, P_GPlus, P_ghWp, 768, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 3926, check)
      call createCurrent(P_H, P_H, P_Z, P_A, 3833, check)
      call createCurrent(P_AQ, P_ghZAnti, P_WMinus, P_ghWp, 2901, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GQ0, 3378, check)
      call createCurrent(P_HQ, P_ghWmAnti, P_ghWm, 3668, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 3124, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 205, check)
      call createCurrent(P_t, P_g, P_tAnti, 1705, check)
      call createCurrent(P_WQMinus, P_WPlus, P_A, P_ZQ, 3088, check)
      call createCurrent(P_HQ, P_G0, P_ghWp, P_ghWpAnti, 636, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_HQ, 1928, check)
      call createCurrent(P_HQ, P_WPlus, P_H, P_WQMinus, 1146, check)
      call createCurrent(P_GQ0, P_Z, P_Z, P_GQ0, 2266, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 3785, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, P_Z, 910, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghA, P_ghAAnti, 3373, check)
      call createCurrent(P_GQMinus, P_A, P_Z, P_GQPlus, 1937, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WMinus, P_WPlus, 676, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 2627, check)
      call createCurrent(P_GMinus, P_G0, P_ghWmAnti, P_ghZ, 1842, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_A, P_ghZ, 3408, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 2292, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_GQ0, 3805, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 1795, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 3412, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 3895, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WQMinus, 203, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 1082, check)
      call createCurrent(P_HQ, P_H, P_ghWm, P_ghWmAnti, 1676, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, P_Z, 1045, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZ, P_ghZAnti, 2429, check)
      call createCurrent(P_G0, P_u, P_uAnti, 783, check)
      call createCurrent(P_H, P_GPlus, P_ghWm, P_ghZAnti, 996, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_H, 1849, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_HQ, 3758, check)
      call createCurrent(P_ZQ, P_WPlus, P_G0, P_GQMinus, 1758, check)
      call createCurrent(P_muPlus, P_muMinus, 3876, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_GQ0, 2152, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 595, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 2116, check)
      call createCurrent(P_GQ0, P_ghWm, P_GPlus, P_ghAAnti, 3787, check)
      call createCurrent(P_ZQ, P_Z, P_ghWp, P_ghWpAnti, 2203, check)
      call createCurrent(P_GQ0, P_H, P_WPlus, P_WQMinus, 2307, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_Z, 568, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 1871, check)
      call createCurrent(P_WQMinus, P_WPlus, P_WMinus, P_WQPlus, 3246, check)
      call createCurrent(P_dAnti, P_d, P_Z, 1022, check)
      call createCurrent(P_ghA, P_Z, P_ghWpAnti, P_WQPlus, 1015, check)
      call createCurrent(P_GQ0, P_ghWm, P_H, P_ghWmAnti, 3536, check)
      call createCurrent(P_AQ, P_ghWp, P_WMinus, P_ghZAnti, 3746, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 1990, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghZ, P_GMinus, 2739, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_ZQ, 3308, check)
      call createCurrent(P_b, P_A, P_bAnti, 2106, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZ, P_ghZAnti, 2906, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Z, P_ZQ, 360, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_GPlus, 454, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_HQ, 3007, check)
      call createCurrent(P_ghZ, P_WMinus, P_WPlus, P_ghAAnti, 753, check)
      call createCurrent(P_ghWp, P_Z, P_ghAAnti, P_WMinus, 3227, check)
      call createCurrent(P_HQ, P_muMinus, P_muPlus, 2974, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 3403, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_AQ, 1029, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 1863, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_WMinus, P_ghZ, 3195, check)
      call createCurrent(P_H, P_H, P_g, P_g, 3964, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghA, P_WPlus, 3040, check)
      call createCurrent(P_A, P_A, P_H, 3923, check)
      call createCurrent(P_AQ, P_GMinus, P_GQPlus, 1938, check)
      call createCurrent(P_Z, P_b, P_bAnti, 3293, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 1685, check)
      call createCurrent(P_t, P_tAnti, P_H, 1816, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_A, P_WPlus, 3650, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_H, P_ghWm, 3788, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_H, 3149, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 3639, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 2069, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 2731, check)
      call createCurrent(P_ZQ, P_G0, P_HQ, 3469, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_GQPlus, 2376, check)
      call createCurrent(P_WMinus, P_A, P_ghA, P_ghWmAnti, 2076, check)
      call createCurrent(P_ZQ, P_ghWm, P_A, P_ghWmAnti, 1681, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 3813, check)
      call createCurrent(P_g, P_ghG, P_g, P_ghGAnti, 2149, check)
      call createCurrent(P_ghWm, P_WPlus, P_Z, P_ghZAnti, 2539, check)
      call createCurrent(P_GQPlus, P_GMinus, P_A, P_AQ, 1306, check)
      call createCurrent(P_g, P_u, P_uAnti, 2619, check)
      call createCurrent(P_Z, P_ghWp, P_WMinus, P_ghZAnti, 3590, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_A, 1002, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_AQ, 2922, check)
      call createCurrent(P_AQ, P_GPlus, P_GMinus, P_ZQ, 3038, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 764, check)
      call createCurrent(P_AQ, P_GMinus, P_A, P_GQPlus, 3720, check)
      call createCurrent(P_GPlus, P_G0, P_ghAAnti, P_ghWm, 2304, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_GMinus, 1334, check)
      call createCurrent(P_ghAAnti, P_G0, P_GMinus, P_ghWp, 1920, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 2549, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 1035, check)
      call createCurrent(P_GMinus, P_ghWp, P_G0, P_ghZAnti, 2752, check)
      call createCurrent(P_ghZ, P_WPlus, P_Z, P_ghWpAnti, 2334, check)
      call createCurrent(P_WQPlus, P_Z, P_A, P_WQMinus, 1901, check)
      call createCurrent(P_HQ, P_G0, P_GMinus, P_GQPlus, 2023, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 2545, check)
      call createCurrent(P_WQPlus, P_Z, P_ghZ, P_ghWpAnti, 1587, check)
      call createCurrent(P_HQ, P_ghWpAnti, P_H, P_ghWp, 3406, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghA, P_WMinus, 1301, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_GQ0, 1539, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_GQMinus, 3550, check)
      call createCurrent(P_dAnti, P_d, P_GQ0, 2988, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 1831, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 1349, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 3697, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWp, P_ghZAnti, 1903, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 3871, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZAnti, P_ghZ, 3113, check)
      call createCurrent(P_sAnti, P_s, P_A, 123, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZ, P_ghZAnti, 813, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 2854, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 605, check)
      call createCurrent(P_Z, P_WMinus, P_ghZ, P_ghWmAnti, 2407, check)
      call createCurrent(P_u, P_uAnti, P_GQ0, 2536, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, P_GQ0, 2254, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GQMinus, 2353, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 3362, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_GQ0, 1350, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_G0, P_ghA, 1929, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 1538, check)
      call createCurrent(P_ghWp, P_H, P_GMinus, P_ghZAnti, 3482, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 377, check)
      call createCurrent(P_WQMinus, P_H, P_GPlus, P_ZQ, 2052, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 3540, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 1062, check)
      call createCurrent(P_ZQ, P_G0, P_WMinus, P_GQPlus, 1932, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_Z, 2835, check)
      call createCurrent(P_AQ, P_WMinus, P_ghAAnti, P_ghWp, 5, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_GMinus, 2368, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 938, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, P_gQ, 1319, check)
      call createCurrent(P_g, P_g, P_ghG, P_ghGAnti, 1899, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_A, P_WQMinus, 2467, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghZAnti, P_WQPlus, 2842, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_GPlus, 854, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_GQ0, 239, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_G0, 641, check)
      call createCurrent(P_A, P_WPlus, P_ghWpAnti, P_ghA, 102, check)
      call createCurrent(P_GQ0, P_GMinus, P_GQPlus, 1291, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 3688, check)
      call createCurrent(P_GQPlus, P_uAnti, P_d, 2943, check)
      call createCurrent(P_ZQ, P_GMinus, P_G0, P_WQPlus, 1205, check)
      call createCurrent(P_cAnti, P_c, P_g, 3592, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 2272, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_GPlus, 1813, check)
      call createCurrent(P_GQMinus, P_A, P_A, P_GQPlus, 1051, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_GPlus, 2631, check)
      call createCurrent(P_bAnti, P_b, P_GQ0, 3427, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_ZQ, 2616, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 3943, check)
      call createCurrent(P_WQMinus, P_WPlus, P_H, P_GQ0, 3052, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_HQ, 2474, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_GQ0, 3340, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_GMinus, 2136, check)
      call createCurrent(P_GQ0, P_uAnti, P_u, 3716, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_GMinus, P_ghZ, 857, check)
      call createCurrent(P_A, P_g, P_A, P_g, 3974, check)
      call createCurrent(P_GQ0, P_WPlus, P_A, P_GQMinus, 2137, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 8, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_GQPlus, 3375, check)
      call createCurrent(P_WQPlus, P_GPlus, P_GMinus, P_WQMinus, 101, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Z, P_WQPlus, 3545, check)
      call createCurrent(P_tAnti, P_t, P_H, 3607, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZ, P_ghAAnti, 1725, check)
      call createCurrent(P_AQ, P_b, P_bAnti, 153, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 1469, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_Z, P_ghA, 672, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, P_A, 1906, check)
      call createCurrent(P_GQMinus, P_WPlus, P_H, P_AQ, 2821, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 1003, check)
      call createCurrent(P_AQ, P_WPlus, P_H, P_GQMinus, 3350, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_ghA, 2590, check)
      call createCurrent(P_GQ0, P_t, P_tAnti, 2893, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_GQMinus, 328, check)
      call createCurrent(P_WPlus, P_A, P_ghWm, P_ghZAnti, 2819, check)
      call createCurrent(P_GPlus, P_ghA, P_GMinus, P_ghZAnti, 3786, check)
      call createCurrent(P_AQ, P_GMinus, P_Z, P_GQPlus, 2923, check)
      call createCurrent(P_u, P_H, P_uAnti, 2560, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_H, 623, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_G0, P_ghWm, 284, check)
      call createCurrent(P_AQ, P_GMinus, P_G0, P_WQPlus, 3780, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WPlus, P_WQMinus, 1598, check)
      call createCurrent(P_AQ, P_A, P_ghWpAnti, P_ghWp, 3502, check)
      call createCurrent(P_A, P_Z, P_ghWmAnti, P_ghWm, 924, check)
      call createCurrent(P_WQMinus, P_ghWpAnti, P_WPlus, P_ghWp, 3648, check)
      call createCurrent(P_GQ0, P_WPlus, P_WMinus, P_GQ0, 3376, check)
      call createCurrent(P_ghZAnti, P_A, P_ghWp, P_WMinus, 2336, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 1597, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghA, P_ghZAnti, 2538, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 2346, check)
      call createCurrent(P_A, P_Z, P_ghWp, P_ghWpAnti, 2785, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 1135, check)
      call createCurrent(P_HQ, P_H, P_HQ, 1683, check)
      call createCurrent(P_HQ, P_WMinus, P_A, P_GQPlus, 2501, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghAAnti, P_ghZ, 652, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 1373, check)
      call createCurrent(P_WQPlus, P_WMinus, P_H, P_GQ0, 2059, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 3571, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 984, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_G0, 23, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_Z, 1590, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghZ, P_WPlus, 312, check)
      call createCurrent(P_WPlus, P_ghA, P_WMinus, P_ghAAnti, 1168, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 75, check)
      call createCurrent(P_WQMinus, P_Z, P_WQPlus, 3104, check)
      call createCurrent(P_t, P_tAnti, 3843, check)
      call createCurrent(P_ZQ, P_Z, P_WMinus, P_WQPlus, 3206, check)
      call createCurrent(P_ghA, P_WMinus, P_Z, P_ghWmAnti, 2570, check)
      call createCurrent(P_ghWp, P_WMinus, P_Z, P_ghZAnti, 3123, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 788, check)
      call createCurrent(P_GQPlus, P_G0, P_WQMinus, 2500, check)
      call createCurrent(P_H, P_GMinus, P_ghA, P_ghWmAnti, 2457, check)
      call createCurrent(P_WQMinus, P_WPlus, P_GQ0, 2709, check)
      call createCurrent(P_H, P_ghWm, P_ghAAnti, P_GPlus, 3804, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 175, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 3944, check)
      call createCurrent(P_sAnti, P_G0, P_s, 658, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghAAnti, P_ghZ, 1194, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 2530, check)
      call createCurrent(P_GMinus, P_G0, P_ghZAnti, P_ghWp, 3815, check)
      call createCurrent(P_GQMinus, P_H, P_WPlus, P_AQ, 2629, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghZAnti, P_WQMinus, 1111, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 2380, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_GPlus, 184, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 2544, check)
      call createCurrent(P_GPlus, P_H, P_ghZAnti, P_ghWm, 1425, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghZ, P_WMinus, 1057, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_ZQ, 2340, check)
      call createCurrent(P_b, P_bAnti, P_A, 2355, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 1489, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_GQ0, 2133, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_H, P_GMinus, 2168, check)
      call createCurrent(P_A, P_G0, 3827, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 2986, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_GQ0, 2021, check)
      call createCurrent(P_HQ, P_GPlus, P_GMinus, P_HQ, 2975, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GPlus, P_GMinus, 389, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_A, 3147, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghZ, P_WQPlus, 3164, check)
      call createCurrent(P_ZQ, P_tauMinus, P_tauPlus, 2252, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_GQMinus, 136, check)
      call createCurrent(P_uAnti, P_G0, P_u, 2845, check)
      call createCurrent(P_A, P_A, P_ghWpAnti, P_ghWp, 1630, check)
      call createCurrent(P_HQ, P_GPlus, P_ghZAnti, P_ghWm, 438, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WMinus, P_WPlus, 948, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_WPlus, P_ghWm, 401, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_G0, 180, check)
      call createCurrent(P_g, P_g, P_g, P_g, 1957, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_H, P_ghWm, 2371, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WPlus, P_WMinus, 648, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 3360, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 3918, check)
      call createCurrent(P_GQMinus, P_tauPlus, P_nu_tau, 2195, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghA, P_WQPlus, 2973, check)
      call createCurrent(P_ghWmAnti, P_Z, P_A, P_ghWm, 3439, check)
      call createCurrent(P_GMinus, P_ghA, P_GPlus, P_ghAAnti, 2377, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 410, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HQ, 2533, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 647, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, P_Z, 1734, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghWpAnti, P_WPlus, 1749, check)
      call createCurrent(P_GPlus, P_H, P_ghWpAnti, P_ghZ, 3706, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_WMinus, P_ghA, 3250, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_G0, P_ghA, 1411, check)
      call createCurrent(P_GQ0, P_G0, P_WPlus, P_WQMinus, 3297, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 426, check)
      call createCurrent(P_ePlus, P_eMinus, P_GQ0, 1361, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 2444, check)
      call createCurrent(P_Z, P_ghWpAnti, P_A, P_ghWp, 1075, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 913, check)
      call createCurrent(P_HQ, P_GMinus, P_GPlus, P_HQ, 2607, check)
      call createCurrent(P_ghWm, P_H, P_GPlus, P_ghAAnti, 2719, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_G0, P_GMinus, 2564, check)
      call createCurrent(P_WQMinus, P_G0, P_G0, P_WQPlus, 2730, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WQMinus, 2970, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 3800, check)
      call createCurrent(P_u, P_uAnti, P_HQ, 3561, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 1458, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_AQ, 3216, check)
      call createCurrent(P_H, P_d, P_dAnti, 2514, check)
      call createCurrent(P_ghWpAnti, P_G0, P_GPlus, P_ghZ, 467, check)
      call createCurrent(P_WQPlus, P_ghWm, P_WMinus, P_ghWmAnti, 280, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, P_Z, 2582, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, P_HQ, 1509, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 2382, check)
      call createCurrent(P_gQ, P_b, P_bAnti, 1192, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 3747, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_G0, P_ghWp, 14, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_Z, 3790, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_A, P_ghZ, 3002, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 583, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 4008, check)
      call createCurrent(P_G0, P_G0, P_ghZ, P_ghZAnti, 1397, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 160, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, P_H, 3670, check)
      call createCurrent(P_ghWp, P_WMinus, P_A, P_ghAAnti, 2239, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_GQMinus, 3789, check)
      call createCurrent(P_AQ, P_Z, P_ghWpAnti, P_ghWp, 122, check)
      call createCurrent(P_Z, P_Z, P_ghWm, P_ghWmAnti, 3132, check)
      call createCurrent(P_G0, P_ghZAnti, P_GMinus, P_ghWp, 3332, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 2735, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WPlus, P_WMinus, 3017, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HQ, 3542, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WMinus, P_WQPlus, 347, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, P_Z, 702, check)
      call createCurrent(P_ghZ, P_GMinus, P_GPlus, P_ghAAnti, 266, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 3980, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_ZQ, 497, check)
      call createCurrent(P_G0, P_t, P_tAnti, 1017, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghAAnti, P_ghA, 625, check)
      call createCurrent(P_WQPlus, P_nu_eAnti, P_eMinus, 2363, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWpAnti, P_ghWp, 3709, check)
      call createCurrent(P_cAnti, P_c, P_G0, 1439, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 3102, check)
      call createCurrent(P_WQPlus, P_Z, P_WMinus, P_AQ, 468, check)
      call createCurrent(P_A, P_ghWpAnti, P_WPlus, P_ghA, 580, check)
      call createCurrent(P_ghA, P_H, P_ghWpAnti, P_GPlus, 921, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_Z, P_ghZ, 1139, check)
      call createCurrent(P_ghZ, P_A, P_ghWpAnti, P_WPlus, 2163, check)
      call createCurrent(P_ghA, P_A, P_ghWpAnti, P_WPlus, 1809, check)
      call createCurrent(P_HQ, P_Z, P_Z, P_HQ, 220, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 1047, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_ZQ, 3655, check)
      call createCurrent(P_tAnti, P_t, P_AQ, 1100, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_H, P_GQMinus, 1248, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWm, P_GPlus, 2390, check)
      call createCurrent(P_ZQ, P_WPlus, P_H, P_GQMinus, 374, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 1382, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_G0, P_ghWm, 2996, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 600, check)
      call createCurrent(P_ePlus, P_eMinus, P_HQ, 1033, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Z, P_WPlus, 2361, check)
      call createCurrent(P_HQ, P_GMinus, P_ghWmAnti, P_ghZ, 2694, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_GPlus, P_ghZ, 1599, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_A, P_ghA, 2554, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 1804, check)
      call createCurrent(P_GMinus, P_ghZ, P_H, P_ghWmAnti, 3717, check)
      call createCurrent(P_WQMinus, P_A, P_Z, P_WQPlus, 3189, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 48, check)
      call createCurrent(P_ghWm, P_H, P_ghZAnti, P_GQPlus, 2841, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, P_G0, 63, check)
      call createCurrent(P_AQ, P_WMinus, P_H, P_GQPlus, 3180, check)
      call createCurrent(P_Z, P_ghAAnti, P_WPlus, P_ghWm, 373, check)
      call createCurrent(P_ZQ, P_ghWp, P_WMinus, P_ghAAnti, 856, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghA, P_WPlus, 1331, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, 1431, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_GPlus, 1307, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 2808, check)
      call createCurrent(P_Z, P_A, P_H, P_H, 3866, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_Z, 3680, check)
      call createCurrent(P_GQMinus, P_WPlus, P_H, P_ZQ, 322, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 1702, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghZ, P_ghWmAnti, 3390, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 1786, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 997, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, P_Z, 1579, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 265, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 1193, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 3118, check)
      call createCurrent(P_ghZ, P_H, P_ghWmAnti, P_GQMinus, 848, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 2968, check)
      call createCurrent(P_H, P_ghZ, P_ghWmAnti, P_GMinus, 2170, check)
      call createCurrent(P_HQ, P_uAnti, P_u, 3524, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 526, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghZ, P_G0, 2356, check)
      call createCurrent(P_sAnti, P_s, P_Z, 2914, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 1329, check)
      call createCurrent(P_ghZ, P_A, P_ghWmAnti, P_WQMinus, 140, check)
      call createCurrent(P_ghWmAnti, P_A, P_WMinus, P_ghA, 1810, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_ghWp, 1915, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 3584, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, P_Z, 3267, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 2779, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghA, P_WPlus, 1520, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 585, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 3996, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_A, 2763, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 3986, check)
      call createCurrent(P_WMinus, P_Z, P_ghZAnti, P_ghWp, 1859, check)
      call createCurrent(P_HQ, P_ghZAnti, P_H, P_ghZ, 975, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_ZQ, 2274, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, P_Z, 1297, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, P_A, 593, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_GPlus, 1649, check)
      call createCurrent(P_HQ, P_A, P_WMinus, P_GQPlus, 3636, check)
      call createCurrent(P_GMinus, P_GPlus, 3908, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_GPlus, 2823, check)
      call createCurrent(P_WPlus, P_Z, P_ghWpAnti, P_ghA, 512, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghA, P_WMinus, 2824, check)
      call createCurrent(P_A, P_ghA, P_ghWmAnti, P_WMinus, 2431, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 1601, check)
      call createCurrent(P_Z, P_cAnti, P_c, 3372, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, P_A, 499, check)
      call createCurrent(P_H, P_ghZ, P_GPlus, P_ghWpAnti, 3727, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZAnti, P_ghZ, 486, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 3857, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 2041, check)
      call createCurrent(P_AQ, P_WMinus, P_ghZAnti, P_ghWp, 258, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 712, check)
      call createCurrent(P_GQPlus, P_Z, P_H, P_WQMinus, 2043, check)
      call createCurrent(P_ZQ, P_GPlus, P_Z, P_GQMinus, 2527, check)
      call createCurrent(P_Z, P_ghWmAnti, P_Z, P_ghWm, 1662, check)
      call createCurrent(P_GQPlus, P_WMinus, P_H, P_ZQ, 3240, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, P_H, 3414, check)
      call createCurrent(P_cAnti, P_H, P_c, 1687, check)
      call createCurrent(P_Z, P_ghA, P_ghWpAnti, P_WPlus, 951, check)
      call createCurrent(P_ghZAnti, P_A, P_WPlus, P_ghWm, 1214, check)
      call createCurrent(P_H, P_H, 3880, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_H, P_ghA, 3775, check)
      call createCurrent(P_GPlus, P_ghWm, P_H, P_ghZAnti, 42, check)
      call createCurrent(P_G0, P_ghZ, P_GPlus, P_ghWpAnti, 2857, check)
      call createCurrent(P_ghWm, P_WMinus, P_ghWmAnti, P_WPlus, 1093, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_H, P_GQPlus, 957, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 2189, check)
      call createCurrent(P_cAnti, P_c, P_A, 311, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghWp, P_WMinus, 2711, check)
      call createCurrent(P_H, P_GPlus, P_ghZAnti, P_ghWm, 80, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_HQ, 2289, check)
      call createCurrent(P_GPlus, P_ghWm, P_GMinus, P_ghWmAnti, 1784, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GQPlus, 3471, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 1039, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 320, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_WPlus, P_ghA, 2928, check)
      call createCurrent(P_A, P_A, P_A, P_A, 3947, check)
      call createCurrent(P_s, P_cAnti, P_WQPlus, 722, check)
      call createCurrent(P_ZQ, P_ghWp, P_A, P_ghWpAnti, 2161, check)
      call createCurrent(P_GQ0, P_GMinus, P_WQPlus, 3501, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_HQ, 2219, check)
      call createCurrent(P_ZQ, P_muMinus, P_muPlus, 2822, check)
      call createCurrent(P_WQPlus, P_A, P_ghZ, P_ghWpAnti, 2375, check)
      call createCurrent(P_ZQ, P_GPlus, P_GMinus, P_AQ, 518, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 1806, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 3621, check)
      call createCurrent(P_ZQ, P_ghWm, P_WPlus, P_ghZAnti, 1031, check)
      call createCurrent(P_H, P_Z, P_H, P_A, 3831, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_G0, 620, check)
      call createCurrent(P_GQ0, P_b, P_bAnti, 1841, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 1588, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 1387, check)
      call createCurrent(P_GQMinus, P_H, P_GQPlus, 3197, check)
      call createCurrent(P_HQ, P_ghWp, P_ghWpAnti, 2286, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_G0, P_GPlus, 1994, check)
      call createCurrent(P_GQ0, P_G0, P_H, P_HQ, 1939, check)
      call createCurrent(P_ghAAnti, P_Z, P_ghWp, P_WMinus, 12, check)
      call createCurrent(P_GQPlus, P_H, P_ghZ, P_ghWpAnti, 1885, check)
      call createCurrent(P_WQPlus, P_Z, P_ghWpAnti, P_ghZ, 799, check)
      call createCurrent(P_GQPlus, P_WMinus, P_ZQ, 2415, check)
      call createCurrent(P_ghWm, P_A, P_A, P_ghWmAnti, 3809, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_HQ, 1505, check)
      call createCurrent(P_GQ0, P_H, P_GPlus, P_GQMinus, 1851, check)
      call createCurrent(P_WQPlus, P_ghA, P_Z, P_ghWpAnti, 3317, check)
      call createCurrent(P_GQ0, P_G0, P_GPlus, P_GQMinus, 2667, check)
      call createCurrent(P_eMinus, P_ePlus, P_AQ, 86, check)
      call createCurrent(P_Z, P_ghAAnti, P_WMinus, P_ghWp, 1922, check)
      call createCurrent(P_H, P_tAnti, P_t, 3090, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WPlus, P_WMinus, 318, check)
      call createCurrent(P_sAnti, P_s, P_ZQ, 2392, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_GQ0, 2071, check)
      call createCurrent(P_WQMinus, P_ghWp, P_WMinus, P_ghWmAnti, 793, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_HQ, 3013, check)
      call createCurrent(P_A, P_H, P_A, 3997, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_HQ, 1688, check)
      call createCurrent(P_HQ, P_ghWp, P_H, P_ghWpAnti, 3302, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_H, 3518, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_G0, P_ghWp, 3791, check)
      call createCurrent(P_WQMinus, P_ghWp, P_ghZAnti, 2687, check)
      call createCurrent(P_GQMinus, P_G0, P_WPlus, P_ZQ, 1482, check)
      call createCurrent(P_GQPlus, P_WMinus, P_GQ0, 1084, check)
      call createCurrent(P_ZQ, P_WPlus, P_WQMinus, 2293, check)
      call createCurrent(P_ZQ, P_G0, P_GPlus, P_WQMinus, 2911, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 937, check)
      call createCurrent(P_Z, P_G0, P_H, 2566, check)
      call createCurrent(P_tAnti, P_G0, P_t, 3316, check)
      call createCurrent(P_GQPlus, P_GMinus, P_H, P_GQ0, 1721, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 2712, check)
      call createCurrent(P_H, P_GMinus, P_ghWmAnti, P_ghA, 189, check)
      call createCurrent(P_AQ, P_WMinus, P_WPlus, P_ZQ, 1589, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 1038, check)
      call createCurrent(P_uAnti, P_u, P_HQ, 2992, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_H, 1147, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghWmAnti, P_WMinus, 3171, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WPlus, P_WMinus, 3331, check)
      call createCurrent(P_GQPlus, P_Z, P_G0, P_WQMinus, 3023, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 1375, check)
      call createCurrent(P_tAnti, P_Z, P_t, 3009, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, P_Z, 2358, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_GPlus, 282, check)
      call createCurrent(P_ghWp, P_WMinus, P_A, P_ghZAnti, 2637, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 2945, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Z, P_WMinus, 1862, check)
      call createCurrent(P_GQMinus, P_Z, P_WQPlus, 238, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 1889, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, P_Z, 1298, check)
      call createCurrent(P_HQ, P_sAnti, P_s, 3459, check)
      call createCurrent(P_GQ0, P_Z, P_WPlus, P_GQMinus, 2605, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WQPlus, 1030, check)
      call createCurrent(P_AQ, P_WPlus, P_ghWm, P_ghZAnti, 191, check)
      call createCurrent(P_d, P_dAnti, P_H, 2492, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 1036, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_GQ0, 2005, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 333, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_H, 240, check)
      call createCurrent(P_WMinus, P_Z, P_ghWmAnti, P_ghA, 2876, check)
      call createCurrent(P_AQ, P_WMinus, P_ghWp, P_ghAAnti, 3579, check)
      call createCurrent(P_b, P_bAnti, P_g, 355, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WMinus, P_WQPlus, 949, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_GMinus, 2182, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_H, 2329, check)
      call createCurrent(P_gQ, P_s, P_sAnti, 2503, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_HQ, 2674, check)
      call createCurrent(P_A, P_ghZ, P_ghWmAnti, P_WMinus, 2303, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 95, check)
      call createCurrent(P_WQPlus, P_G0, P_Z, P_GQMinus, 2269, check)
      call createCurrent(P_ghZAnti, P_Z, P_WMinus, P_ghWp, 3278, check)
      call createCurrent(P_HQ, P_ghWm, P_H, P_ghWmAnti, 1895, check)
      call createCurrent(P_GQMinus, P_H, P_GPlus, P_GQ0, 1064, check)
      call createCurrent(P_G0, P_GMinus, P_ghAAnti, P_ghWp, 1537, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_HQ, 372, check)
      call createCurrent(P_ghZ, P_GPlus, P_GMinus, P_ghAAnti, 434, check)
      call createCurrent(P_ZQ, P_s, P_sAnti, 524, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 1344, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 1000, check)
      call createCurrent(P_dAnti, P_d, P_ZQ, 804, check)
      call createCurrent(P_ghA, P_Z, P_ghWmAnti, P_WQMinus, 2580, check)
      call createCurrent(P_ghAAnti, P_A, P_ghWp, P_WMinus, 1913, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_Z, 2839, check)
      call createCurrent(P_WQMinus, P_A, P_ghA, P_ghWmAnti, 1325, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_WMinus, P_ghA, 2546, check)
      call createCurrent(P_GQ0, P_G0, P_ghZ, P_ghZAnti, 2565, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghZ, P_WPlus, 3200, check)
      call createCurrent(P_WMinus, P_WMinus, P_ghWmAnti, P_ghWp, 2280, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 315, check)
      call createCurrent(P_WMinus, P_Z, P_ghA, P_ghWmAnti, 3714, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_HQ, 201, check)
      call createCurrent(P_sAnti, P_Z, P_s, 1674, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_A, P_WQPlus, 523, check)
      call createCurrent(P_ghWm, P_GPlus, P_H, P_ghAAnti, 3025, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_ZQ, 2967, check)
      call createCurrent(P_H, P_A, P_A, 3988, check)
      call createCurrent(P_WPlus, P_ghZ, P_Z, P_ghWpAnti, 1352, check)
      call createCurrent(P_AQ, P_WPlus, P_ghAAnti, P_ghWm, 1432, check)
      call createCurrent(P_ghWmAnti, P_G0, P_GMinus, P_ghZ, 1136, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghA, P_GPlus, 1559, check)
      call createCurrent(P_WQPlus, P_WMinus, P_WMinus, P_WQPlus, 3410, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 1883, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 2704, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 3097, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GQPlus, 1797, check)
      call createCurrent(P_ghZAnti, P_H, P_ghWm, P_GQPlus, 2523, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, P_HQ, 550, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_GQMinus, 371, check)
      call createCurrent(P_ZQ, P_GPlus, P_GQMinus, 1868, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 1287, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 36, check)
      call createCurrent(P_GQ0, P_u, P_uAnti, 1666, check)
      call createCurrent(P_ghWpAnti, P_ghWm, P_WPlus, P_WPlus, 3426, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 999, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WMinus, P_WQPlus, 416, check)
      call createCurrent(P_G0, P_ghWmAnti, P_G0, P_ghWm, 1577, check)
      call createCurrent(P_ghA, P_WMinus, P_ghAAnti, P_WQPlus, 3122, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WMinus, P_WPlus, 2762, check)
      call createCurrent(P_dAnti, P_A, P_d, 1427, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_H, P_ghZ, 3061, check)
      call createCurrent(P_tAnti, P_A, P_t, 2894, check)
      call createCurrent(P_AQ, P_ghWp, P_A, P_ghWpAnti, 3064, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, P_A, 1533, check)
      call createCurrent(P_GPlus, P_WMinus, 3860, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 1126, check)
      call createCurrent(P_HQ, P_H, P_ghZAnti, P_ghZ, 1381, check)
      call createCurrent(P_Z, P_tAnti, P_t, 1096, check)
      call createCurrent(P_WQMinus, P_WMinus, P_WPlus, P_WQPlus, 1257, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, P_Z, 3548, check)
      call createCurrent(P_GMinus, P_ghZ, P_G0, P_ghWmAnti, 3284, check)
      call createCurrent(P_GQMinus, P_GPlus, P_H, P_HQ, 104, check)
      call createCurrent(P_WPlus, P_Z, P_ghWm, P_ghZAnti, 2608, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 3257, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_H, 2165, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 1365, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 3971, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 3174, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghA, P_WMinus, 2001, check)
      call createCurrent(P_WQPlus, P_A, P_Z, P_WQMinus, 929, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WQPlus, 97, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_G0, 2965, check)
      call createCurrent(P_s, P_sAnti, 3847, check)
      call createCurrent(P_A, P_ghZAnti, P_ghWp, P_WMinus, 3643, check)
      call createCurrent(P_GQMinus, P_Z, P_A, P_GQPlus, 1356, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghZ, P_WPlus, 317, check)
      call createCurrent(P_ghWpAnti, P_G0, P_G0, P_ghWp, 214, check)
      call createCurrent(P_GQ0, P_ghWm, P_ghWmAnti, 3085, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWmAnti, P_ghZ, 3719, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WMinus, P_WQPlus, 2595, check)
      call createCurrent(P_ghWm, P_GMinus, P_GPlus, P_ghWmAnti, 607, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 3476, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_GPlus, 2417, check)
      call createCurrent(P_G0, P_ghAAnti, P_GMinus, P_ghWp, 1490, check)
      call createCurrent(P_GQMinus, P_Z, P_GPlus, P_AQ, 1403, check)
      call createCurrent(P_ghWpAnti, P_Z, P_WPlus, P_ghA, 3084, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 1235, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 917, check)
      call createCurrent(P_GQMinus, P_G0, P_WQPlus, 707, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghA, P_ghAAnti, 1263, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghA, P_WMinus, 692, check)
      call createCurrent(P_WQMinus, P_GPlus, P_GMinus, P_WQPlus, 536, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Z, P_WMinus, 1054, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 4001, check)
      call createCurrent(P_GPlus, P_ghA, P_GMinus, P_ghAAnti, 2852, check)
      call createCurrent(P_ghWmAnti, P_H, P_GMinus, P_ghA, 837, check)
      call createCurrent(P_A, P_ghWm, P_WPlus, P_ghZAnti, 1261, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Z, P_WQPlus, 3395, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 599, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 3784, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_ZQ, 115, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GQ0, 691, check)
      call createCurrent(P_GQ0, P_GMinus, P_WPlus, P_ZQ, 3560, check)
      call createCurrent(P_uAnti, P_u, P_Z, 3811, check)
      call createCurrent(P_GQMinus, P_Z, P_H, P_WQPlus, 2414, check)
      call createCurrent(P_GQMinus, P_ghZ, P_G0, P_ghWmAnti, 273, check)
      call createCurrent(P_GMinus, P_ghA, P_ghZAnti, P_GPlus, 1494, check)
      call createCurrent(P_WQMinus, P_sAnti, P_c, 392, check)
      call createCurrent(P_G0, P_ghWm, P_GPlus, P_ghAAnti, 1787, check)
      call createCurrent(P_ZQ, P_A, P_WPlus, P_WQMinus, 747, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_GQ0, 1485, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghZ, P_WQMinus, 2453, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 881, check)
      call createCurrent(P_HQ, P_ghWm, P_GPlus, P_ghAAnti, 367, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 2315, check)
      call createCurrent(P_G0, P_GPlus, P_ghAAnti, P_ghWm, 621, check)
      call createCurrent(P_WMinus, P_A, P_ghWp, P_ghZAnti, 1244, check)
      call createCurrent(P_GQMinus, P_ghWp, P_ghZAnti, 1437, check)
      call createCurrent(P_ZQ, P_nu_muAnti, P_nu_mu, 2294, check)
      call createCurrent(P_WQPlus, P_Z, P_ghWpAnti, P_ghA, 2051, check)
      call createCurrent(P_G0, P_GPlus, P_ghZ, P_ghWpAnti, 164, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 3130, check)
      call createCurrent(P_c, P_cAnti, P_g, 844, check)
      call createCurrent(P_GQ0, P_Z, P_GMinus, P_WQPlus, 2799, check)
      call createCurrent(P_GQ0, P_A, P_WPlus, P_GQMinus, 1660, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghZAnti, P_ghWp, 3598, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_GPlus, 3808, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_A, P_WMinus, 172, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 2596, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GQMinus, 2738, check)
      call createCurrent(P_A, P_A, P_ghWm, P_ghWmAnti, 2394, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 2366, check)
      call createCurrent(P_ghAAnti, P_A, P_WMinus, P_ghWp, 3243, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWpAnti, P_ghWp, 69, check)
      call createCurrent(P_GQMinus, P_WPlus, P_WMinus, P_GQPlus, 3711, check)
      call createCurrent(P_HQ, P_ghZAnti, P_ghZ, 935, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, P_H, 849, check)
      call createCurrent(P_HQ, P_A, P_WPlus, P_GQMinus, 1012, check)
      call createCurrent(P_AQ, P_WMinus, P_Z, P_WQPlus, 3477, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_GPlus, 761, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghWm, P_ghZAnti, 3208, check)
      call createCurrent(P_GQPlus, P_H, P_WMinus, P_ZQ, 728, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 3109, check)
      call createCurrent(P_ZQ, P_WPlus, P_A, P_WQMinus, 1204, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 3004, check)
      call createCurrent(P_H, P_A, P_Z, P_H, 3845, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 2287, check)
      call createCurrent(P_GQ0, P_ghAAnti, P_GMinus, P_ghWp, 185, check)
      call createCurrent(P_gQ, P_dAnti, P_d, 3016, check)
      call createCurrent(P_H, P_ghZ, P_ghWpAnti, P_GPlus, 3263, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Z, P_WMinus, 1180, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWm, P_WQPlus, 1853, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 2633, check)
      call createCurrent(P_H, P_u, P_uAnti, 2820, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 628, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 323, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghZ, P_WMinus, 1959, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 2002, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 1060, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_H, P_ghA, 3196, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_HQ, 893, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_Z, P_ghZ, 505, check)
      call createCurrent(P_ghWmAnti, P_WPlus, P_ghWm, P_WMinus, 1730, check)
      call createCurrent(P_WQMinus, P_H, P_WPlus, P_HQ, 1507, check)
      call createCurrent(P_GQ0, P_ghWp, P_GMinus, P_ghZAnti, 1348, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WQPlus, 435, check)
      call createCurrent(P_GQMinus, P_dAnti, P_u, 2243, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 2446, check)
      call createCurrent(P_Z, P_Z, P_ghWmAnti, P_ghWm, 120, check)
      call createCurrent(P_bAnti, P_g, P_b, 2044, check)
      call createCurrent(P_GMinus, P_ghWm, P_ghWmAnti, P_GPlus, 2961, check)
      call createCurrent(P_GQMinus, P_H, P_WPlus, P_ZQ, 157, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWmAnti, P_ghZ, 2980, check)
      call createCurrent(P_ghA, P_WPlus, P_ghZAnti, P_WMinus, 727, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_GMinus, 3181, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 3510, check)
      call createCurrent(P_GQMinus, P_ghAAnti, P_GPlus, P_ghZ, 2396, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 482, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 3725, check)
      call createCurrent(P_GQMinus, P_H, P_ghWmAnti, P_ghZ, 2623, check)
      call createCurrent(P_H, P_dAnti, P_d, 1510, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 3508, check)
      call createCurrent(P_GQPlus, P_ghZ, P_GMinus, P_ghZAnti, 3337, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_ZQ, 1641, check)
      call createCurrent(P_c, P_cAnti, 3891, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 1728, check)
      call createCurrent(P_g, P_bAnti, P_b, 955, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghAAnti, P_ghZ, 3642, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_G0, 572, check)
      call createCurrent(P_HQ, P_G0, P_G0, P_HQ, 940, check)
      call createCurrent(P_WPlus, P_WPlus, P_ghWm, P_ghWpAnti, 1109, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 58, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 2506, check)
      call createCurrent(P_GQMinus, P_WPlus, P_GQ0, 2488, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, P_Z, 1220, check)
      call createCurrent(P_G0, P_ghWp, P_G0, P_ghWpAnti, 540, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, P_Z, 1372, check)
      call createCurrent(P_WQPlus, P_eMinus, P_nu_eAnti, 2433, check)
      call createCurrent(P_GQ0, P_A, P_WMinus, P_GQPlus, 878, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 78, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_G0, 1731, check)
      call createCurrent(P_HQ, P_ghWpAnti, P_ghWp, 1927, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_WMinus, P_ghZ, 2932, check)
      call createCurrent(P_GPlus, P_G0, P_ghA, P_ghWpAnti, 2847, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 206, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_A, 1528, check)
      call createCurrent(P_c, P_sAnti, P_WQMinus, 1548, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_Z, 1621, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 2886, check)
      call createCurrent(P_A, P_ghWpAnti, P_Z, P_ghWp, 1708, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 1707, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 1568, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 1716, check)
      call createCurrent(P_Z, P_WPlus, P_ghWm, P_ghAAnti, 1221, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghA, P_ghAAnti, 1394, check)
      call createCurrent(P_ghA, P_WPlus, P_WMinus, P_ghZAnti, 1564, check)
      call createCurrent(P_d, P_dAnti, P_AQ, 2452, check)
      call createCurrent(P_bAnti, P_b, P_A, 3573, check)
      call createCurrent(P_ghZ, P_H, P_ghWpAnti, P_GPlus, 1518, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_ghWm, 1855, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 3544, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_A, P_WPlus, 3538, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_GMinus, 3075, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WPlus, P_WMinus, 1854, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 534, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 1912, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_GQ0, 2684, check)
      call createCurrent(P_H, P_GPlus, P_ghWpAnti, P_ghZ, 2364, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 2588, check)
      call createCurrent(P_Z, P_Z, P_ghWp, P_ghWpAnti, 2525, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_H, 3152, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_ZQ, 1704, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 1389, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, P_Z, 549, check)
      call createCurrent(P_GPlus, P_ghWm, P_G0, P_ghZAnti, 2813, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 3049, check)
      call createCurrent(P_HQ, P_GPlus, P_A, P_WQMinus, 3724, check)
      call createCurrent(P_ghWp, P_WPlus, P_WMinus, P_ghWpAnti, 1974, check)
      call createCurrent(P_Z, P_WPlus, P_ghA, P_ghWpAnti, 1830, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_G0, P_ghA, 2164, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WQMinus, 1821, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 3039, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GQPlus, 556, check)
      call createCurrent(P_G0, P_G0, P_ghZAnti, P_ghZ, 2125, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 3202, check)
      call createCurrent(P_ZQ, P_u, P_uAnti, 2493, check)
      call createCurrent(P_Z, P_ghWmAnti, P_A, P_ghWm, 3145, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_GMinus, 1515, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 3464, check)
      call createCurrent(P_GPlus, P_H, P_ghWm, P_ghAAnti, 2035, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_A, P_ghZ, 2451, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_WMinus, P_ghWp, 3158, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Z, P_WQMinus, 3814, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_AQ, 900, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, P_g, 2033, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_A, P_WQMinus, 1978, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_G0, 2410, check)
      call createCurrent(P_A, P_WPlus, P_ghWpAnti, P_ghZ, 2563, check)
      call createCurrent(P_GQ0, P_GPlus, P_G0, P_GQMinus, 2216, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_GQ0, 742, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 2621, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WPlus, P_WMinus, 99, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghWp, P_ghWpAnti, 3611, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 814, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, P_A, 72, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghAAnti, P_GMinus, 2753, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_GMinus, 1656, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WPlus, P_WMinus, 828, check)
      call createCurrent(P_ghWmAnti, P_A, P_Z, P_ghWm, 475, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 576, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 2809, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 2770, check)
      call createCurrent(P_GQ0, P_H, P_WMinus, P_WQPlus, 1414, check)
      call createCurrent(P_ghWm, P_Z, P_ghZAnti, P_WPlus, 3458, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 552, check)
      call createCurrent(P_GQ0, P_WPlus, P_H, P_WQMinus, 1763, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZ, P_ghAAnti, 2208, check)
      call createCurrent(P_WMinus, P_A, P_ghWmAnti, P_ghZ, 2088, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_G0, 656, check)
      call createCurrent(P_t, P_bAnti, P_GQMinus, 1247, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghZAnti, P_WPlus, 2127, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GQMinus, 2831, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 2463, check)
      call createCurrent(P_b, P_bAnti, 3912, check)
      call createCurrent(P_g, P_g, P_A, P_g, 4006, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_A, 3069, check)
      call createCurrent(P_WQMinus, P_WMinus, P_ghWmAnti, P_ghWp, 3028, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghAAnti, P_ghZ, 2121, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghZ, P_WPlus, 973, check)
      call createCurrent(P_Z, P_G0, 3896, check)
      call createCurrent(P_ghA, P_H, P_GPlus, P_ghWpAnti, 2801, check)
      call createCurrent(P_GQMinus, P_nu_tau, P_tauPlus, 1717, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_HQ, 3757, check)
      call createCurrent(P_GQ0, P_H, P_ghWm, P_ghWmAnti, 667, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghZ, P_WQMinus, 521, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 22, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 2145, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_GPlus, 1743, check)
      call createCurrent(P_ghZ, P_Z, P_WPlus, P_ghWpAnti, 2209, check)
      call createCurrent(P_HQ, P_ghZAnti, P_GPlus, P_ghWm, 1697, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_G0, 968, check)
      call createCurrent(P_ghZ, P_Z, P_WMinus, P_ghWmAnti, 3754, check)
      call createCurrent(P_u, P_dAnti, P_WQMinus, 405, check)
      call createCurrent(P_uAnti, P_g, P_u, 3413, check)
      call createCurrent(P_G0, P_ghWp, P_GMinus, P_ghZAnti, 3662, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_GPlus, 1483, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Z, P_WQPlus, 1330, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghZAnti, P_GPlus, 887, check)
      call createCurrent(P_WMinus, P_A, P_ghZ, P_ghWmAnti, 385, check)
      call createCurrent(P_ZQ, P_Z, P_GMinus, P_GQPlus, 2962, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_H, P_GQMinus, 3015, check)
      call createCurrent(P_t, P_tAnti, P_ZQ, 1891, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 3652, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 2418, check)
      call createCurrent(P_WQPlus, P_ghA, P_ghWpAnti, 2948, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghA, P_GPlus, 20, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_HQ, 822, check)
      call createCurrent(P_u, P_uAnti, P_gQ, 1962, check)
      call createCurrent(P_G0, P_A, 3900, check)
      call createCurrent(P_HQ, P_GMinus, P_H, P_GQPlus, 1061, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghZAnti, P_WPlus, 176, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 3984, check)
      call createCurrent(P_GMinus, P_H, P_ghWmAnti, P_ghZ, 451, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghA, P_WPlus, 2651, check)
      call createCurrent(P_A, P_WPlus, P_ghAAnti, P_ghWm, 3354, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 915, check)
      call createCurrent(P_HQ, P_ghWm, P_GPlus, P_ghZAnti, 384, check)
      call createCurrent(P_ZQ, P_WMinus, P_Z, P_WQPlus, 644, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 2379, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WMinus, P_WPlus, 520, check)
      call createCurrent(P_b, P_H, P_bAnti, 969, check)
      call createCurrent(P_GMinus, P_G0, P_ghWp, P_ghZAnti, 1647, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_HQ, 1187, check)
      call createCurrent(P_H, P_ghWp, P_GMinus, P_ghAAnti, 2579, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 457, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_HQ, 959, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_A, P_ghA, 3120, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 1378, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Z, P_WPlus, 28, check)
      call createCurrent(P_A, P_g, P_g, P_g, 4007, check)
      call createCurrent(P_H, P_Z, P_A, 3846, check)
      call createCurrent(P_ZQ, P_GPlus, P_G0, P_WQMinus, 1043, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 2103, check)
      call createCurrent(P_ghWp, P_H, P_ghZAnti, P_GQMinus, 2576, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_G0, 823, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 696, check)
      call createCurrent(P_dAnti, P_d, P_G0, 2437, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_HQ, 3262, check)
      call createCurrent(P_G0, P_cAnti, P_c, 1302, check)
      call createCurrent(P_WQMinus, P_ghZ, P_WPlus, P_ghAAnti, 1593, check)
      call createCurrent(P_GQ0, P_GPlus, P_H, P_GQMinus, 81, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 3557, check)
      call createCurrent(P_WMinus, P_ghA, P_Z, P_ghWmAnti, 2313, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghZ, P_WPlus, 3587, check)
      call createCurrent(P_c, P_G0, P_cAnti, 171, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_AQ, 2117, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_G0, 124, check)
      call createCurrent(P_G0, P_ghA, P_ghWpAnti, P_GPlus, 2520, check)
      call createCurrent(P_WQMinus, P_ePlus, P_nu_e, 2518, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 1056, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 165, check)
      call createCurrent(P_Z, P_ghWm, P_ghZAnti, P_WPlus, 1958, check)
      call createCurrent(P_GQMinus, P_nu_e, P_ePlus, 300, check)
      call createCurrent(P_H, P_ghWmAnti, P_H, P_ghWm, 462, check)
      call createCurrent(P_ZQ, P_GMinus, P_WQPlus, 815, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 3224, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Z, P_WPlus, 1463, check)
      call createCurrent(P_GQ0, P_GPlus, P_GQMinus, 1006, check)
      call createCurrent(P_ghZ, P_GPlus, P_H, P_ghWpAnti, 2342, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghA, P_WPlus, 1658, check)
      call createCurrent(P_ZQ, P_A, P_WMinus, P_WQPlus, 21, check)
      call createCurrent(P_ghWm, P_GPlus, P_H, P_ghZAnti, 3329, check)
      call createCurrent(P_WMinus, P_Z, P_ghWp, P_ghZAnti, 891, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WPlus, P_WQMinus, 2555, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 555, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, P_Z, 1104, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WPlus, P_WQMinus, 1409, check)
      call createCurrent(P_GQPlus, P_Z, P_A, P_GQMinus, 1090, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 1260, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_GPlus, P_ghA, 2750, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_ZQ, 3434, check)
      call createCurrent(P_GQPlus, P_H, P_GMinus, P_GQ0, 1313, check)
      call createCurrent(P_ghZ, P_Z, P_ghWmAnti, P_WMinus, 1904, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, P_Z, 530, check)
      call createCurrent(P_GQPlus, P_H, P_ghZAnti, P_ghWm, 1355, check)
      call createCurrent(P_H, P_G0, P_G0, 1711, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 3005, check)
      call createCurrent(P_bAnti, P_b, P_gQ, 2484, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 3219, check)
      call createCurrent(P_A, P_ghA, P_ghWpAnti, P_WPlus, 2713, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 4003, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_H, P_ghWm, 194, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 3989, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 3732, check)
      call createCurrent(P_ghAAnti, P_A, P_WPlus, P_ghWm, 653, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 3405, check)
      call createCurrent(P_HQ, P_GMinus, P_ghWp, P_ghAAnti, 1230, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghA, P_WMinus, 1072, check)
      call createCurrent(P_g, P_ghGAnti, P_g, P_ghG, 3658, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, P_Z, 197, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_GQ0, 1556, check)
      call createCurrent(P_H, P_ghZAnti, P_GMinus, P_ghWp, 354, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_GQPlus, 2128, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_GQ0, 2234, check)
      call createCurrent(P_gQ, P_ghG, P_ghGAnti, 2904, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_GQ0, 1175, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, P_G0, 3281, check)
      call createCurrent(P_WQMinus, P_ghZ, P_ghWmAnti, 2611, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_Z, P_ghWp, 2777, check)
      call createCurrent(P_ZQ, P_H, P_GQ0, 2104, check)
      call createCurrent(P_g, P_g, P_g, P_A, 3922, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_GQ0, 2408, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 2240, check)
      call createCurrent(P_A, P_dAnti, P_d, 3685, check)
      call createCurrent(P_A, P_bAnti, P_b, 1342, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 2397, check)
      call createCurrent(P_gQ, P_ghGAnti, P_ghG, 2419, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_ZQ, 2321, check)
      call createCurrent(P_sAnti, P_s, 3830, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_A, P_WPlus, 1052, check)
      call createCurrent(P_ghZ, P_H, P_GPlus, P_ghWpAnti, 1250, check)
      call createCurrent(P_A, P_ghAAnti, P_ghWp, P_WMinus, 1993, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_GQMinus, 869, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 1271, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 2471, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_HQ, 606, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_HQ, 2698, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghZ, P_WMinus, 1423, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, P_GQ0, 3277, check)
      call createCurrent(P_ghA, P_Z, P_ghWmAnti, P_WMinus, 682, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 222, check)
      call createCurrent(P_gQ, P_d, P_dAnti, 1026, check)
      call createCurrent(P_ghGAnti, P_g, P_g, P_ghG, 1637, check)
      call createCurrent(P_HQ, P_GPlus, P_Z, P_WQMinus, 3473, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_G0, 782, check)
      call createCurrent(P_Z, P_H, P_A, P_H, 3853, check)
      call createCurrent(P_GQMinus, P_G0, P_ghA, P_ghWmAnti, 1208, check)
      call createCurrent(P_GQMinus, P_Z, P_GQPlus, 2880, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghAAnti, P_WPlus, 2599, check)
      call createCurrent(P_gQ, P_c, P_cAnti, 2202, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_Z, P_ghWp, 3457, check)
      call createCurrent(P_ghWp, P_Z, P_WMinus, P_ghAAnti, 594, check)
      call createCurrent(P_A, P_ghZ, P_WPlus, P_ghWpAnti, 2995, check)
      call createCurrent(P_HQ, P_G0, P_ghWpAnti, P_ghWp, 664, check)
      call createCurrent(P_ZQ, P_cAnti, P_c, 3128, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_H, P_ghA, 412, check)
      call createCurrent(P_WQMinus, P_H, P_WPlus, P_GQ0, 2743, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, 3383, check)
      call createCurrent(P_Z, P_ghWmAnti, P_WMinus, P_ghZ, 1712, check)
      call createCurrent(P_Z, P_ghAAnti, P_ghWm, P_WPlus, 3715, check)
      call createCurrent(P_u, P_uAnti, P_G0, 3058, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_GMinus, P_ghWm, 3543, check)
      call createCurrent(P_HQ, P_Z, P_GMinus, P_WQPlus, 1259, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_GQMinus, 262, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_Z, 2977, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_AQ, 2404, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_GQPlus, 746, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghA, P_ghAAnti, 3153, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_Z, 1693, check)
      call createCurrent(P_t, P_G0, P_tAnti, 1326, check)
      call createCurrent(P_GMinus, P_ghA, P_H, P_ghWmAnti, 943, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghWmAnti, P_ghWm, 1670, check)
      call createCurrent(P_ZQ, P_GPlus, P_WQMinus, 3146, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 496, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 827, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Z, P_WPlus, 1754, check)
      call createCurrent(P_G0, P_GPlus, P_ghZAnti, P_ghWm, 2325, check)
      call createCurrent(P_GQPlus, P_ghZ, P_H, P_ghWpAnti, 77, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_HQ, 1209, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_H, 643, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 1377, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWm, P_GPlus, 2061, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 3356, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 2489, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_Z, P_ghZ, 1695, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 3820, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 1591, check)
      call createCurrent(P_u, P_A, P_uAnti, 3235, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 1129, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_ZQ, 1162, check)
      call createCurrent(P_GQ0, P_H, P_G0, P_HQ, 107, check)
      call createCurrent(P_WQPlus, P_WMinus, P_A, P_ZQ, 545, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WQMinus, 453, check)
      call createCurrent(P_G0, P_ghWm, P_ghAAnti, P_GPlus, 2372, check)
      call createCurrent(P_WPlus, P_ghA, P_ghAAnti, P_WMinus, 1949, check)
      call createCurrent(P_t, P_H, P_tAnti, 1007, check)
      call createCurrent(P_d, P_dAnti, P_ZQ, 1481, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 1665, check)
      call createCurrent(P_ghWp, P_GPlus, P_GMinus, P_ghWpAnti, 1417, check)
      call createCurrent(P_GQMinus, P_ghA, P_G0, P_ghWmAnti, 1328, check)
      call createCurrent(P_A, P_ghZAnti, P_WMinus, P_ghWp, 2416, check)
      call createCurrent(P_ZQ, P_GPlus, P_A, P_GQMinus, 1276, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_ZQ, 2863, check)
      call createCurrent(P_ghA, P_WMinus, P_ghZAnti, P_WPlus, 2547, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 3199, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, P_H, 3570, check)
      call createCurrent(P_WMinus, P_ghWp, P_Z, P_ghAAnti, 3083, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_ghWp, 1388, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_ZQ, 741, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 57, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 443, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 1983, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghWp, P_WMinus, 2490, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 2515, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_GQ0, 1196, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 1024, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 169, check)
      call createCurrent(P_GQMinus, P_GPlus, P_A, P_AQ, 3619, check)
      call createCurrent(P_WMinus, P_WMinus, P_ghWp, P_ghWmAnti, 344, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 716, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 1523, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_AQ, 3358, check)
      call createCurrent(P_GQ0, P_G0, P_ghZAnti, P_ghZ, 2529, check)
      call createCurrent(P_tAnti, P_t, P_GQ0, 745, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 537, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_GPlus, P_ghWp, 1698, check)
      call createCurrent(P_WQPlus, P_GMinus, P_HQ, 277, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 3952, check)
      call createCurrent(P_H, P_uAnti, P_u, 481, check)
      call createCurrent(P_GQMinus, P_t, P_bAnti, 1186, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 766, check)
      call createCurrent(P_gQ, P_bAnti, P_b, 579, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 3535, check)
      call createCurrent(P_G0, P_ghWm, P_G0, P_ghWmAnti, 3799, check)
      call createCurrent(P_GPlus, P_G0, P_ghWm, P_ghAAnti, 2972, check)
      call createCurrent(P_A, P_u, P_uAnti, 1441, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_A, P_WMinus, 637, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_HQ, 3310, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WQPlus, 754, check)
      call createCurrent(P_GQ0, P_G0, P_ghWpAnti, P_ghWp, 2774, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 3271, check)
      call createCurrent(P_GQMinus, P_H, P_H, P_GQPlus, 1185, check)
      call createCurrent(P_H, P_ghAAnti, P_ghWp, P_GMinus, 1241, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 3744, check)
      call createCurrent(P_ghWpAnti, P_Z, P_A, P_ghWp, 3299, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 1840, check)
      call createCurrent(P_WQPlus, P_H, P_H, P_WQMinus, 1669, check)
      call createCurrent(P_ZQ, P_GMinus, P_H, P_WQPlus, 256, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 3182, check)
      call createCurrent(P_WQPlus, P_A, P_WMinus, P_AQ, 1443, check)
      call createCurrent(P_gQ, P_g, P_ghGAnti, P_ghG, 127, check)
      call createCurrent(P_ghZAnti, P_H, P_GPlus, P_ghWm, 2618, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_H, 1796, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 879, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_GQ0, 1358, check)
      call createCurrent(P_GQPlus, P_G0, P_WMinus, P_AQ, 3718, check)
      call createCurrent(P_HQ, P_GMinus, P_Z, P_WQPlus, 947, check)
      call createCurrent(P_GQ0, P_ghWm, P_G0, P_ghWmAnti, 2675, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 3565, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_GPlus, P_ghA, 3273, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 2332, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WQPlus, 617, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 1569, check)
      call createCurrent(P_ghA, P_H, P_ghWpAnti, P_GQPlus, 2589, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_ZQ, 2748, check)
      call createCurrent(P_g, P_A, P_g, P_g, 3930, check)
      call createCurrent(P_ghWmAnti, P_G0, P_GMinus, P_ghA, 2412, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_A, P_WMinus, 3445, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 1846, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1171, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 1911, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWpAnti, P_ghA, 2541, check)
      call createCurrent(P_GQMinus, P_G0, P_ghZAnti, P_ghWp, 1249, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghAAnti, P_ghA, 76, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 2811, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 2772, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 765, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 2395, check)
      call createCurrent(P_GQPlus, P_ghWmAnti, P_GMinus, P_ghWm, 2620, check)
      call createCurrent(P_WPlus, P_ghA, P_WMinus, P_ghZAnti, 207, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 1321, check)
      call createCurrent(P_g, P_g, P_ghGAnti, P_ghG, 1416, check)
      call createCurrent(P_Z, P_ghWm, P_ghAAnti, P_WPlus, 2892, check)
      call createCurrent(P_GQMinus, P_WPlus, P_HQ, 3512, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 2907, check)
      call createCurrent(P_ghA, P_Z, P_ghWpAnti, P_WPlus, 2747, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_H, 2761, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 1406, check)
      call createCurrent(P_WQPlus, P_H, P_WQMinus, 2878, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 3765, check)
      call createCurrent(P_ghZ, P_WPlus, P_A, P_ghWpAnti, 1315, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_GQMinus, 275, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 2223, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_HQ, 270, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_H, P_GQPlus, 2072, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 3066, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_Z, P_ghA, 3603, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghZ, P_GMinus, 3057, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 723, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_GPlus, 1288, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 3957, check)
      call createCurrent(P_AQ, P_muMinus, P_muPlus, 1454, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 3387, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_Z, 2828, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_G0, 3494, check)
      call createCurrent(P_GQ0, P_cAnti, P_c, 1134, check)
      call createCurrent(P_H, P_ghZAnti, P_H, P_ghZ, 2264, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_A, P_ghWp, 1735, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 1359, check)
      call createCurrent(P_WPlus, P_A, P_ghAAnti, P_ghWm, 2946, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_GQPlus, 1703, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, P_A, 1744, check)
      call createCurrent(P_c, P_sAnti, P_GQMinus, 3330, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 1607, check)
      call createCurrent(P_A, P_WMinus, P_ghA, P_ghWmAnti, 100, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 2016, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_GPlus, 2648, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghA, P_WPlus, 1219, check)
      call createCurrent(P_d, P_uAnti, P_GQPlus, 2262, check)
      call createCurrent(P_ghZ, P_GMinus, P_G0, P_ghWmAnti, 649, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 2958, check)
      call createCurrent(P_HQ, P_ghWmAnti, P_GMinus, P_ghZ, 233, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_A, P_WPlus, 2096, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 353, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 422, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 3801, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_H, P_GQMinus, 3105, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghZAnti, P_WMinus, 118, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 469, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 139, check)
      call createCurrent(P_WPlus, P_ghWm, P_WMinus, P_ghWmAnti, 3519, check)
      call createCurrent(P_gQ, P_uAnti, P_u, 1664, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 3994, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_GQ0, 1864, check)
      call createCurrent(P_GQPlus, P_ghZ, P_G0, P_ghWpAnti, 2107, check)
      call createCurrent(P_u, P_uAnti, P_H, 257, check)
      call createCurrent(P_WQPlus, P_ghA, P_WMinus, P_ghAAnti, 1820, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, P_GQ0, 2075, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZAnti, P_ghZ, 3260, check)
      call createCurrent(P_muPlus, P_muMinus, P_AQ, 498, check)
      call createCurrent(P_WQPlus, P_GMinus, P_G0, P_ZQ, 511, check)
      call createCurrent(P_ZQ, P_ghZAnti, P_WPlus, P_ghWm, 703, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 2150, check)
      call createCurrent(P_WPlus, P_ghWm, P_Z, P_ghZAnti, 1226, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_GMinus, P_ghZ, 1560, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 444, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 208, check)
      call createCurrent(P_g, P_A, P_g, P_A, 3979, check)
      call createCurrent(P_GQ0, P_GMinus, P_G0, P_GQPlus, 914, check)
      call createCurrent(P_ZQ, P_ghWm, P_WPlus, P_ghAAnti, 760, check)
      call createCurrent(P_ZQ, P_GMinus, P_GQPlus, 1222, check)
      call createCurrent(P_A, P_ghWmAnti, P_WMinus, P_ghZ, 2807, check)
      call createCurrent(P_AQ, P_A, P_WPlus, P_WQMinus, 2483, check)
      call createCurrent(P_HQ, P_H, P_G0, P_GQ0, 1016, check)
      call createCurrent(P_GMinus, P_G0, P_ghWp, P_ghAAnti, 1369, check)
      call createCurrent(P_t, P_tAnti, P_AQ, 2909, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 1059, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghA, P_GQPlus, 2126, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_Z, 2058, check)
      call createCurrent(P_d, P_dAnti, P_g, 2868, check)
      call createCurrent(P_HQ, P_GPlus, P_ghWpAnti, P_ghZ, 2783, check)
      call createCurrent(P_WQPlus, P_GMinus, P_H, P_ZQ, 2401, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_GQ0, 1619, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_G0, 1245, check)
      call createCurrent(P_ghZ, P_Z, P_ghWpAnti, P_WQPlus, 755, check)
      call createCurrent(P_AQ, P_bAnti, P_b, 2030, check)
      call createCurrent(P_ghWp, P_WMinus, P_WMinus, P_ghWmAnti, 3098, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_G0, 2211, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 2597, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghA, P_ghZAnti, 1303, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 29, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 2378, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Z, P_WQMinus, 533, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWm, P_GPlus, 3629, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 2756, check)
      call createCurrent(P_GQ0, P_G0, P_Z, P_ZQ, 406, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghAAnti, P_ghWp, 1266, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 3210, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 3928, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 3917, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 3990, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 3595, check)
      call createCurrent(P_t, P_tAnti, P_GQ0, 415, check)
      call createCurrent(P_ghWp, P_GMinus, P_G0, P_ghZAnti, 3269, check)
      call createCurrent(P_GQMinus, P_A, P_GQPlus, 2000, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 3837, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghZ, P_GQPlus, 3726, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWmAnti, P_WMinus, 1442, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_Z, 3525, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_GQ0, 243, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 1177, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 2014, check)
      call createCurrent(P_GQ0, P_WPlus, P_G0, P_WQMinus, 2018, check)
      call createCurrent(P_GQMinus, P_bAnti, P_t, 2007, check)
      call createCurrent(P_ghA, P_WMinus, P_WPlus, P_ghAAnti, 502, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 3959, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ZQ, 2960, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 2134, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_H, 2671, check)
      call createCurrent(P_GPlus, P_GMinus, 3904, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_ZQ, 2341, check)
      call createCurrent(P_A, P_ghZ, P_WMinus, P_ghWmAnti, 1399, check)
      call createCurrent(P_WPlus, P_A, P_ghA, P_ghWpAnti, 1304, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Z, P_WMinus, 3796, check)
      call createCurrent(P_ghWm, P_Z, P_ghAAnti, P_WPlus, 1788, check)
      call createCurrent(P_c, P_g, P_cAnti, 1902, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 3945, check)
      call createCurrent(P_WQPlus, P_Z, P_G0, P_GQMinus, 3444, check)
      call createCurrent(P_c, P_cAnti, P_Z, 235, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghA, P_ghAAnti, 1255, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 3449, check)
      call createCurrent(P_H, P_GPlus, P_ghZ, P_ghWpAnti, 483, check)
      call createCurrent(P_WMinus, P_ghZ, P_A, P_ghWmAnti, 199, check)
      call createCurrent(P_AQ, P_GPlus, P_H, P_WQMinus, 32, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 2123, check)
      call createCurrent(P_muMinus, P_muPlus, P_AQ, 1181, check)
      call createCurrent(P_WQPlus, P_WMinus, P_GQ0, 1286, check)
      call createCurrent(P_WQMinus, P_tauPlus, P_nu_tau, 513, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWmAnti, P_WQMinus, 2737, check)
      call createCurrent(P_HQ, P_GMinus, P_ghWp, P_ghZAnti, 1251, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 1935, check)
      call createCurrent(P_ghA, P_Z, P_WMinus, P_ghWmAnti, 850, check)
      call createCurrent(P_GQPlus, P_muMinus, P_nu_muAnti, 1400, check)
      call createCurrent(P_A, P_WMinus, P_ghZAnti, P_ghWp, 2158, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_A, 1817, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_GQ0, 3682, check)
      call createCurrent(P_GQMinus, P_H, P_ghWp, P_ghZAnti, 3215, check)
      call createCurrent(P_dAnti, P_Z, P_d, 1981, check)
      call createCurrent(P_AQ, P_GMinus, P_WQPlus, 3660, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWpAnti, P_ghWp, 2635, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_H, 966, check)
      call createCurrent(P_WQMinus, P_bAnti, P_t, 2569, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_GQMinus, 2345, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WPlus, P_WMinus, 2947, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_Z, P_ghWm, 634, check)
      call createCurrent(P_AQ, P_uAnti, P_u, 3452, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 3967, check)
      call createCurrent(P_HQ, P_Z, P_WPlus, P_GQMinus, 3737, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_H, P_GQPlus, 3018, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 927, check)
      call createCurrent(P_ghA, P_A, P_ghWmAnti, P_WMinus, 193, check)
      call createCurrent(P_GQ0, P_muMinus, P_muPlus, 3416, check)
      call createCurrent(P_cAnti, P_c, P_ZQ, 2966, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 2159, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 2908, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 1165, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_GMinus, 865, check)
      call createCurrent(P_dAnti, P_d, P_AQ, 3693, check)
      call createCurrent(P_uAnti, P_u, P_G0, 646, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_H, 132, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 1148, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWmAnti, P_ghWm, 1526, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 1888, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 1472, check)
      call createCurrent(P_WMinus, P_Z, P_ghWp, P_ghAAnti, 1346, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_WPlus, P_ghZ, 2887, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghWpAnti, P_GPlus, 772, check)
      call createCurrent(P_GPlus, P_G0, P_ghZAnti, P_ghWm, 13, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_WPlus, P_ghWm, 3415, check)
      call createCurrent(P_WQPlus, P_GMinus, P_G0, P_AQ, 478, check)
      call createCurrent(P_WQMinus, P_nu_mu, P_muPlus, 3455, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, P_Z, 3160, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWp, P_ghWpAnti, 3583, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_A, 316, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 272, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_H, 3515, check)
      call createCurrent(P_HQ, P_A, P_GMinus, P_WQPlus, 17, check)
      call createCurrent(P_AQ, P_ghWp, P_ghWpAnti, 1418, check)
      call createCurrent(P_WPlus, P_Z, P_ghA, P_ghWpAnti, 2288, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_A, 1438, check)
      call createCurrent(P_Z, P_WMinus, P_ghAAnti, P_ghWp, 710, check)
      call createCurrent(P_ZQ, P_Z, P_H, P_HQ, 3364, check)
      call createCurrent(P_ZQ, P_WPlus, P_Z, P_WQMinus, 3470, check)
      call createCurrent(P_GQMinus, P_GPlus, P_A, P_ZQ, 162, check)
      call createCurrent(P_G0, P_G0, P_H, 309, check)
      call createCurrent(P_AQ, P_ghZAnti, P_WPlus, P_ghWm, 245, check)
      call createCurrent(P_s, P_sAnti, P_ZQ, 902, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WPlus, P_WQMinus, 3170, check)
      call createCurrent(P_uAnti, P_H, P_u, 3192, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_GMinus, 216, check)
      call createCurrent(P_WMinus, P_ghZ, P_WPlus, P_ghZAnti, 3472, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_GQ0, 1430, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghA, P_ghZAnti, 1224, check)
      call createCurrent(P_GPlus, P_H, P_ghWpAnti, P_ghA, 3704, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZAnti, P_ghZ, 1884, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_GQ0, 987, check)
      call createCurrent(P_HQ, P_ghWm, P_ghWmAnti, 1865, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_G0, 3067, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 3972, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_GQ0, 2787, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_GPlus, 2367, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_HQ, 3681, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 3992, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_GQ0, 3742, check)
      call createCurrent(P_GQMinus, P_ghA, P_GPlus, P_ghZAnti, 19, check)
      call createCurrent(P_GQPlus, P_Z, P_GQMinus, 1169, check)
      call createCurrent(P_GQMinus, P_G0, P_G0, P_GQPlus, 708, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_GPlus, P_ghWm, 2020, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_HQ, 2449, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 2727, check)
      call createCurrent(P_HQ, P_H, P_WMinus, P_WQPlus, 2508, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 3935, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 2509, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_GQ0, 2872, check)
      call createCurrent(P_WQMinus, P_WPlus, P_GMinus, P_GQPlus, 301, check)
      call createCurrent(P_uAnti, P_u, P_ZQ, 2177, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 2581, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZAnti, P_ghA, 1130, check)
      call createCurrent(P_H, P_GPlus, P_ghA, P_ghWpAnti, 3348, check)
      call createCurrent(P_GQ0, P_H, P_GQ0, 3683, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 1305, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GQMinus, 117, check)
      call createCurrent(P_ZQ, P_GPlus, P_GMinus, P_ZQ, 3041, check)
      call createCurrent(P_A, P_ghWmAnti, P_A, P_ghWm, 680, check)
      call createCurrent(P_dAnti, P_d, P_gQ, 3566, check)
      call createCurrent(P_GPlus, P_ghWm, P_G0, P_ghAAnti, 1525, check)
      call createCurrent(P_A, P_A, P_g, P_g, 3921, check)
      call createCurrent(P_G0, P_ghWp, P_ghAAnti, P_GMinus, 130, check)
      call createCurrent(P_GQ0, P_H, P_H, P_GQ0, 1776, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_A, 2443, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 1212, check)
      call createCurrent(P_cAnti, P_s, P_GQPlus, 1371, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 4011, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_H, 2015, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_GQPlus, 3073, check)
      call createCurrent(P_b, P_bAnti, P_Z, 2048, check)
      call createCurrent(P_GQ0, P_WMinus, P_G0, P_WQPlus, 1452, check)
      call createCurrent(P_ghWp, P_G0, P_ghAAnti, P_GMinus, 2197, check)
      call createCurrent(P_GQ0, P_eMinus, P_ePlus, 633, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_GQ0, 3191, check)
      call createCurrent(P_Z, P_Z, 3901, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_AQ, 700, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_H, 114, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 1753, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 3920, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 1123, check)
      call createCurrent(P_WPlus, P_ghWm, P_Z, P_ghAAnti, 246, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 200, check)
      call createCurrent(P_GQPlus, P_WPlus, P_GMinus, P_WQMinus, 3537, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 167, check)
      call createCurrent(P_WQPlus, P_muMinus, P_nu_muAnti, 3424, check)
      call createCurrent(P_g, P_g, 3838, check)
      call createCurrent(P_ghWpAnti, P_H, P_H, P_ghWp, 2903, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_Z, 2100, check)
      call createCurrent(P_G0, P_ghWp, P_GMinus, P_ghAAnti, 3617, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghZAnti, P_WMinus, 3370, check)
      call createCurrent(P_WQPlus, P_H, P_Z, P_GQMinus, 1464, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 87, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 3966, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghAAnti, P_GPlus, 1835, check)
      call createCurrent(P_Z, P_sAnti, P_s, 1419, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 3055, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_HQ, 2833, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_GQMinus, 904, check)
      call createCurrent(P_GQPlus, P_A, P_GQMinus, 2282, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZ, P_ghAAnti, 1152, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 342, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WQPlus, 2690, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_AQ, 774, check)
      call createCurrent(P_GMinus, P_ghA, P_ghAAnti, P_GPlus, 562, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZAnti, P_ghA, 1473, check)
      call createCurrent(P_WMinus, P_ghWp, P_WMinus, P_ghWmAnti, 2677, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 2840, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 3093, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 1217, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 2343, check)
      call createCurrent(P_ghWp, P_Z, P_A, P_ghWpAnti, 433, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_GQMinus, 3547, check)
      call createCurrent(P_GMinus, P_ghWp, P_GPlus, P_ghWpAnti, 192, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 3970, check)
      call createCurrent(P_GQPlus, P_WMinus, P_H, P_AQ, 697, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, P_Z, 1, check)
      call createCurrent(P_A, P_G0, P_H, 3829, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Z, P_ZQ, 571, check)
      call createCurrent(P_G0, P_G0, P_ghWp, P_ghWpAnti, 2691, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWpAnti, P_ghZ, 2212, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_AQ, 3433, check)
      call createCurrent(P_GMinus, P_H, P_ghWp, P_ghAAnti, 2080, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 589, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 1596, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 3276, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 3953, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_WMinus, P_ghZ, 1435, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_GQ0, 393, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghZ, P_WPlus, 3100, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 2551, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_AQ, 834, check)
      call createCurrent(P_GQPlus, P_A, P_Z, P_GQMinus, 2505, check)
      call createCurrent(P_HQ, P_WPlus, P_WQMinus, 3140, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 2084, check)
      call createCurrent(P_ghWp, P_H, P_ghAAnti, P_GMinus, 3782, check)
      call createCurrent(P_WQPlus, P_WPlus, P_ghWm, P_ghWpAnti, 425, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WQMinus, 3249, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 3941, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 1451, check)
      call createCurrent(P_HQ, P_ghWp, P_G0, P_ghWpAnti, 263, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, P_HQ, 3062, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 3872, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 173, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 1274, check)
      call createCurrent(P_Z, P_WMinus, P_ghWmAnti, P_ghZ, 719, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_G0, 1236, check)
      call createCurrent(P_eMinus, P_ePlus, P_HQ, 1117, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 146, check)
      call createCurrent(P_sAnti, P_s, P_AQ, 1422, check)
      call createCurrent(P_cAnti, P_G0, P_c, 361, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_AQ, 2442, check)
      call createCurrent(P_WQPlus, P_WPlus, P_WMinus, P_WQMinus, 731, check)
      call createCurrent(P_ZQ, P_A, P_GPlus, P_GQMinus, 3205, check)
      call createCurrent(P_AQ, P_A, P_ghWmAnti, P_ghWm, 324, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WMinus, P_WQPlus, 853, check)
      call createCurrent(P_A, P_ghAAnti, P_ghWm, P_WPlus, 470, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 892, check)
      call createCurrent(P_GQMinus, P_sAnti, P_c, 2678, check)
      call createCurrent(P_WQPlus, P_ghWmAnti, P_WMinus, P_ghWm, 3576, check)
      call createCurrent(P_ghWp, P_A, P_ghZAnti, P_WMinus, 1618, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_GPlus, P_ghWm, 1677, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 1308, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 1850, check)
      call createCurrent(P_WMinus, P_WPlus, 3859, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 1028, check)
      call createCurrent(P_Z, P_A, P_ghWmAnti, P_ghWm, 1713, check)
      call createCurrent(P_G0, P_ghA, P_GMinus, P_ghWmAnti, 337, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 287, check)
      call createCurrent(P_ePlus, P_nu_e, P_GQMinus, 519, check)
      call createCurrent(P_bAnti, P_H, P_b, 450, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_G0, P_GMinus, 1189, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 3614, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 3948, check)
      call createCurrent(P_HQ, P_WPlus, P_G0, P_WQMinus, 1182, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_ZQ, 487, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 351, check)
      call createCurrent(P_ghWp, P_GMinus, P_G0, P_ghAAnti, 503, check)
      call createCurrent(P_GQMinus, P_u, P_dAnti, 791, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_AQ, 2438, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWp, P_GMinus, 2765, check)
      call createCurrent(P_nu_e, P_ePlus, P_GQMinus, 1768, check)
      call createCurrent(P_bAnti, P_A, P_b, 1565, check)
      call createCurrent(P_G0, P_GPlus, P_ghWpAnti, P_ghA, 188, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 3962, check)
      call createCurrent(P_HQ, P_ghZ, P_GMinus, P_ghWmAnti, 2032, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_H, 1605, check)
      call createCurrent(P_muMinus, P_muPlus, P_GQ0, 1383, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_HQ, 3759, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 744, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghZ, P_WPlus, 2926, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghAAnti, P_ghWm, 810, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_G0, P_ghWm, 3119, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 821, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 2448, check)
      call createCurrent(P_GQPlus, P_H, P_ghA, P_ghWpAnti, 2853, check)
      call createCurrent(P_ghWpAnti, P_ghWm, P_WPlus, P_WQPlus, 863, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 3079, check)
      call createCurrent(P_A, P_WPlus, P_ghA, P_ghWpAnti, 2725, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 2722, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 319, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_GQ0, 3325, check)
      call createCurrent(P_c, P_A, P_cAnti, 1644, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_GQMinus, 826, check)
      call createCurrent(P_ghZAnti, P_G0, P_GMinus, P_ghWp, 960, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 1268, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 541, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_GQ0, 1468, check)
      call createCurrent(P_GMinus, P_G0, P_ghZ, P_ghWmAnti, 1924, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 661, check)
      call createCurrent(P_ghWpAnti, P_G0, P_GPlus, P_ghA, 1679, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 685, check)
      call createCurrent(P_ghWm, P_G0, P_ghAAnti, P_GPlus, 982, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_G0, P_ghZ, 739, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 1964, check)
      call createCurrent(P_ZQ, P_Z, P_G0, P_GQ0, 3368, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HQ, 2074, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 98, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 2548, check)
      call createCurrent(P_Z, P_A, P_H, 3840, check)
      call createCurrent(P_A, P_WPlus, P_ghZ, P_ghWpAnti, 3400, check)
      call createCurrent(P_GQPlus, P_ghAAnti, P_GMinus, P_ghZ, 3135, check)
      call createCurrent(P_bAnti, P_b, 3911, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 508, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 2333, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghAAnti, P_WQMinus, 1709, check)
      call createCurrent(P_A, P_H, P_H, P_Z, 3849, check)
      call createCurrent(P_GQPlus, P_s, P_cAnti, 1739, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_G0, 3220, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 3982, check)
      call createCurrent(P_GQPlus, P_H, P_GMinus, P_HQ, 792, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_GQPlus, 3322, check)
      call createCurrent(P_GQ0, P_bAnti, P_b, 1197, check)
      call createCurrent(P_cAnti, P_c, P_GQ0, 958, check)
      call createCurrent(P_uAnti, P_u, P_gQ, 1535, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_Z, P_ghA, 3134, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_Z, 2297, check)
      call createCurrent(P_WMinus, P_A, P_ghWp, P_ghAAnti, 2200, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 3870, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WQPlus, 0, check)
      call createCurrent(P_HQ, P_WMinus, P_WQPlus, 3349, check)
      call createCurrent(P_t, P_tAnti, P_Z, 2386, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 131, check)
      call createCurrent(P_Z, P_ghWm, P_Z, P_ghWmAnti, 2130, check)
      call createCurrent(P_A, P_WMinus, P_ghWmAnti, P_ghZ, 971, check)
      call createCurrent(P_G0, P_GPlus, P_ghA, P_ghWpAnti, 1037, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_H, P_ghA, 400, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWp, P_ghWpAnti, 796, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 1440, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghAAnti, P_ghWp, 1617, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 2317, check)
      call createCurrent(P_ghA, P_GMinus, P_GPlus, P_ghZAnti, 1011, check)
      call createCurrent(P_ZQ, P_WPlus, P_WMinus, P_AQ, 1018, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 3176, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Z, P_WMinus, 2436, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 336, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_GQ0, 3707, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 1179, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghWm, P_ghAAnti, 3225, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 1727, check)
      call createCurrent(P_WPlus, P_ghWmAnti, P_WMinus, P_ghWm, 2981, check)
      call createCurrent(P_GMinus, P_ghWp, P_H, P_ghZAnti, 133, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 3936, check)
      call createCurrent(P_A, P_ghWp, P_A, P_ghWpAnti, 1453, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghA, P_ghZAnti, 179, check)
      call createCurrent(P_ZQ, P_nu_eAnti, P_nu_e, 129, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_HQ, 290, check)
      call createCurrent(P_ePlus, P_eMinus, P_AQ, 3030, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 627, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_A, 1794, check)
      call createCurrent(P_ghA, P_WMinus, P_ghAAnti, P_WPlus, 1549, check)
      call createCurrent(P_GQMinus, P_ghAAnti, P_GPlus, P_ghA, 1118, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 3209, check)
      call createCurrent(P_GPlus, P_H, P_ghA, P_ghWpAnti, 2210, check)
      call createCurrent(P_HQ, P_ghWp, P_GMinus, P_ghZAnti, 3393, check)
      call createCurrent(P_GQ0, P_H, P_ghWpAnti, P_ghWp, 1625, check)
      call createCurrent(P_WQPlus, P_GMinus, P_H, P_AQ, 2225, check)
      call createCurrent(P_ZQ, P_b, P_bAnti, 3626, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWpAnti, P_ghWp, 3391, check)
      call createCurrent(P_WPlus, P_ghZ, P_WMinus, P_ghAAnti, 3388, check)
      call createCurrent(P_ghA, P_G0, P_GMinus, P_ghWmAnti, 3743, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_GMinus, 546, check)
      call createCurrent(P_Z, P_WPlus, P_ghWpAnti, P_ghA, 491, check)
      call createCurrent(P_ghWp, P_H, P_ghZAnti, P_GMinus, 110, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, P_g, 1264, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_GMinus, 1140, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_A, P_ghWp, 211, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_GQMinus, 1555, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 177, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_H, P_ghWp, 2473, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_GMinus, 994, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_GQ0, 10, check)
      call createCurrent(P_ZQ, P_WPlus, P_WMinus, P_ZQ, 2681, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, P_G0, 824, check)
      call createCurrent(P_b, P_bAnti, P_GQ0, 326, check)
      call createCurrent(P_gQ, P_cAnti, P_c, 3252, check)
      call createCurrent(P_Z, P_ghWm, P_WPlus, P_ghAAnti, 2602, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_GPlus, P_ghZ, 2898, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_GQ0, 370, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 1333, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 3462, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Z, P_AQ, 1775, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 1905, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 1068, check)
      call createCurrent(P_A, P_ghAAnti, P_WMinus, P_ghWp, 1077, check)
      call createCurrent(P_H, P_H, P_ghWm, P_ghWmAnti, 1516, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 2082, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 2794, check)
      call createCurrent(P_s, P_sAnti, P_G0, 3290, check)
      call createCurrent(P_GQMinus, P_nu_mu, P_muPlus, 3549, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 3925, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 2516, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WMinus, P_WQPlus, 1675, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HQ, 3752, check)
      call createCurrent(P_H, P_bAnti, P_b, 3509, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 752, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 1049, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 1390, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_Z, P_ghA, 1724, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_Z, 368, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZAnti, P_ghA, 1407, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_G0, P_ghA, 3586, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 2251, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 119, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, P_HQ, 1690, check)
      call createCurrent(P_ZQ, P_G0, P_GMinus, P_WQPlus, 1925, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 2884, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 3977, check)
      call createCurrent(P_G0, P_ghWmAnti, P_GMinus, P_ghZ, 2913, check)
      call createCurrent(P_ghZAnti, P_H, P_GMinus, P_ghWp, 2350, check)
      call createCurrent(P_G0, P_G0, P_ghWpAnti, P_ghWp, 3749, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_ghWp, P_GPlus, 2434, check)
      call createCurrent(P_Z, P_t, P_tAnti, 510, check)
      call createCurrent(P_WMinus, P_ghA, P_ghAAnti, P_WPlus, 3645, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 1514, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_H, 2099, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_G0, P_ghZ, 2716, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_Z, P_ghWm, 3591, check)
      call createCurrent(P_GQ0, P_H, P_ZQ, 1042, check)
      call createCurrent(P_WQMinus, P_G0, P_GPlus, P_ZQ, 2902, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_HQ, 1997, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_HQ, 916, check)
      call createCurrent(P_H, P_ghWm, P_GPlus, P_ghAAnti, 3511, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_H, P_GQPlus, 1161, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWmAnti, P_ghWm, 3588, check)
      call createCurrent(P_Z, P_c, P_cAnti, 3239, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 3279, check)
      call createCurrent(P_HQ, P_tAnti, P_t, 126, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 3280, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_H, 1930, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_AQ, 514, check)
      call createCurrent(P_GMinus, P_G0, P_ghA, P_ghWmAnti, 2400, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 2963, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 3973, check)
      call createCurrent(P_WQPlus, P_ghZ, P_A, P_ghWpAnti, 835, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Z, P_WPlus, 2708, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_Z, 920, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 2034, check)
      call createCurrent(P_b, P_g, P_bAnti, 85, check)
      call createCurrent(P_gQ, P_g, P_ghG, P_ghGAnti, 868, check)
      call createCurrent(P_GQ0, P_A, P_GMinus, P_WQPlus, 2495, check)
      call createCurrent(P_WQMinus, P_Z, P_WPlus, P_AQ, 2275, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 3456, check)
      call createCurrent(P_GQ0, P_H, P_ghWp, P_ghWpAnti, 1628, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 1164, check)
      call createCurrent(P_H, P_GMinus, P_ghWp, P_ghAAnti, 1353, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, P_gQ, 611, check)
      call createCurrent(P_GQMinus, P_H, P_ghZAnti, P_ghWp, 408, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 1900, check)
      call createCurrent(P_GQ0, P_WMinus, P_Z, P_GQPlus, 2723, check)
      call createCurrent(P_WMinus, P_A, P_ghWmAnti, P_ghA, 838, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 1034, check)
      call createCurrent(P_GQMinus, P_ghA, P_GPlus, P_ghAAnti, 1808, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_G0, 952, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghA, P_GMinus, 1094, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 883, check)
      call createCurrent(P_WQPlus, P_d, P_uAnti, 2950, check)
      call createCurrent(P_H, P_GMinus, P_ghZ, P_ghWmAnti, 2984, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 1433, check)
      call createCurrent(P_G0, P_ghWm, P_GPlus, P_ghZAnti, 1477, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 2679, check)
      call createCurrent(P_WQMinus, P_ghZ, P_Z, P_ghWmAnti, 1567, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_HQ, 1701, check)
      call createCurrent(P_ZQ, P_WMinus, P_GQPlus, 448, check)
      call createCurrent(P_bAnti, P_b, P_HQ, 2402, check)
      call createCurrent(P_AQ, P_cAnti, P_c, 2086, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZ, P_ghZAnti, 332, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 2720, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_G0, P_ghWp, 383, check)
      call createCurrent(P_GQ0, P_ghWp, P_G0, P_ghWpAnti, 584, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_Z, 3087, check)
      call createCurrent(P_AQ, P_dAnti, P_d, 3355, check)
      call createCurrent(P_HQ, P_G0, P_WPlus, P_WQMinus, 24, check)
      call createCurrent(P_tAnti, P_t, P_gQ, 807, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 1659, check)
      call createCurrent(P_ZQ, P_H, P_GPlus, P_WQMinus, 1622, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 1875, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_G0, 1573, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_WPlus, P_ghA, 89, check)
      call createCurrent(P_ghA, P_WMinus, P_A, P_ghWmAnti, 3031, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_GQ0, 3229, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WQMinus, 3339, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WPlus, P_WQMinus, 1080, check)
      call createCurrent(P_AQ, P_A, P_GPlus, P_GQMinus, 37, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ZQ, 657, check)
      call createCurrent(P_WQPlus, P_uAnti, P_d, 1273, check)
      call createCurrent(P_WQMinus, P_nu_e, P_ePlus, 3312, check)
      call createCurrent(P_G0, P_ghZ, P_GMinus, P_ghWmAnti, 2291, check)
      call createCurrent(P_WPlus, P_Z, P_ghWm, P_ghAAnti, 1320, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghA, P_WPlus, 897, check)
      call createCurrent(P_G0, P_ghZ, P_ghZAnti, P_G0, 3776, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_H, P_GPlus, 3454, check)
      call createCurrent(P_GQ0, P_dAnti, P_d, 2330, check)
      call createCurrent(P_H, P_ghZ, P_GMinus, P_ghWmAnti, 109, check)
      call createCurrent(P_ghWm, P_WMinus, P_ghWmAnti, P_WQPlus, 3399, check)
      call createCurrent(P_A, P_WMinus, P_ghWp, P_ghAAnti, 2013, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghA, P_GPlus, 288, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghWpAnti, P_ghWp, 2486, check)
      call createCurrent(P_ghZAnti, P_H, P_ghWp, P_GQMinus, 1866, check)
      call createCurrent(P_ZQ, P_ghAAnti, P_WMinus, P_ghWp, 3266, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WPlus, P_WQMinus, 1643, check)
      call createCurrent(P_AQ, P_WPlus, P_GQMinus, 2784, check)
      call createCurrent(P_WMinus, P_ghWpAnti, P_WPlus, P_ghWp, 2301, check)
      call createCurrent(P_GQPlus, P_A, P_GMinus, P_AQ, 3065, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWmAnti, P_ghWm, 3309, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 1908, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 3021, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 3528, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZ, P_ghAAnti, 314, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWm, P_ghWmAnti, 3712, check)
      call createCurrent(P_H, P_c, P_cAnti, 3803, check)
      call createCurrent(P_GQMinus, P_A, P_GPlus, P_AQ, 2888, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZAnti, P_ghZ, 871, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_GQMinus, 1009, check)
      call createCurrent(P_WPlus, P_ghWmAnti, P_ghWm, P_WMinus, 2818, check)
      call createCurrent(P_uAnti, P_u, P_A, 3738, check)
      call createCurrent(P_H, P_ghWp, P_H, P_ghWpAnti, 2781, check)
      call createCurrent(P_WQPlus, P_tauMinus, P_nu_tauAnti, 757, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GQ0, 2654, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 662, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghZ, P_ghWpAnti, 1097, check)
      call createCurrent(P_bAnti, P_b, P_H, 2924, check)
      call createCurrent(P_d, P_Z, P_dAnti, 1772, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 407, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 613, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_Z, 3121, check)
      call createCurrent(P_WMinus, P_ghWpAnti, P_ghWp, P_WPlus, 2494, check)
      call createCurrent(P_b, P_bAnti, P_H, 1722, check)
      call createCurrent(P_t, P_A, P_tAnti, 1967, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_GQMinus, 187, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 1610, check)
      call createCurrent(P_Z, P_d, P_dAnti, 1998, check)
      call createCurrent(P_ghWp, P_G0, P_GMinus, P_ghZAnti, 1213, check)
      call createCurrent(P_G0, P_Z, P_H, 1836, check)
      call createCurrent(P_cAnti, P_c, P_Z, 3328, check)
      call createCurrent(P_HQ, P_GMinus, P_WPlus, P_ZQ, 961, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_A, 1671, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 2450, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, P_A, 3641, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_G0, 2918, check)
      call createCurrent(P_ghWpAnti, P_A, P_WPlus, P_ghA, 1279, check)
      call createCurrent(P_ghWm, P_H, P_ghZAnti, P_GPlus, 1547, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_A, 874, check)
      call createCurrent(P_H, P_Z, P_A, P_H, 3854, check)
      call createCurrent(P_HQ, P_b, P_bAnti, 2700, check)
      call createCurrent(P_HQ, P_ghZAnti, P_GMinus, P_ghWp, 2930, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghA, P_GMinus, 713, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_GQ0, 2715, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_GPlus, 3418, check)
      call createCurrent(P_G0, P_GPlus, P_ghWm, P_ghAAnti, 2630, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 2222, check)
      call createCurrent(P_GQ0, P_Z, P_GPlus, P_WQMinus, 3638, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 3667, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_G0, P_ghWm, 1860, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 2517, check)
      call createCurrent(P_WPlus, P_Z, P_ghAAnti, P_ghWm, 2348, check)
      call createCurrent(P_ghZAnti, P_A, P_ghWm, P_WPlus, 683, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghWm, P_ghWmAnti, 820, check)
      call createCurrent(P_AQ, P_ghWm, P_A, P_ghWmAnti, 2337, check)
      call createCurrent(P_cAnti, P_c, P_AQ, 1807, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_AQ, 616, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 2757, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_G0, 3351, check)
      call createCurrent(P_ghWpAnti, P_Z, P_WPlus, P_ghZ, 3496, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 3856, check)
      call createCurrent(P_HQ, P_ghAAnti, P_GPlus, P_ghWm, 2535, check)
      call createCurrent(P_ghWm, P_G0, P_GPlus, P_ghZAnti, 1723, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghZ, P_GMinus, 2825, check)
      call createCurrent(P_ghWm, P_H, P_ghAAnti, P_GPlus, 3201, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghWmAnti, P_ghWm, 55, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_H, P_GPlus, 1991, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 909, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 2796, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 1995, check)
      call createCurrent(P_ghWp, P_H, P_H, P_ghWpAnti, 2760, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GQMinus, 1066, check)
      call createCurrent(P_AQ, P_Z, P_GPlus, P_GQMinus, 2989, check)
      call createCurrent(P_HQ, P_ghZ, P_ghZAnti, 3033, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_A, P_WPlus, 1508, check)
      call createCurrent(P_WQMinus, P_A, P_ghWmAnti, P_ghA, 3637, check)
      call createCurrent(P_ZQ, P_ghWm, P_Z, P_ghWmAnti, 3740, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_ZQ, 962, check)
      call createCurrent(P_GQPlus, P_b, P_tAnti, 2296, check)
      call createCurrent(P_GQPlus, P_WMinus, P_AQ, 1445, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_GQPlus, 2955, check)
      call createCurrent(P_dAnti, P_G0, P_d, 679, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, P_Z, 2309, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 3431, check)
      call createCurrent(P_A, P_A, 3818, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 1395, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 1424, check)
      call createCurrent(P_GQ0, P_GMinus, P_H, P_GQPlus, 341, check)
      call createCurrent(P_ghWm, P_WPlus, P_A, P_ghAAnti, 251, check)
      call createCurrent(P_H, P_GMinus, P_ghZAnti, P_ghWp, 3430, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 718, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_G0, P_ghWp, 3812, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 2179, check)
      call createCurrent(P_ghZ, P_A, P_ghWmAnti, P_WMinus, 31, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_H, P_GMinus, 3581, check)
      call createCurrent(P_GQMinus, P_G0, P_WPlus, P_AQ, 1531, check)
      call createCurrent(P_uAnti, P_d, P_WQPlus, 221, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_AQ, 2670, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 1380, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 1826, check)
      call createCurrent(P_ghAAnti, P_Z, P_WMinus, P_ghWp, 2244, check)
      call createCurrent(P_cAnti, P_c, P_H, 504, check)
      call createCurrent(P_HQ, P_WMinus, P_H, P_WQPlus, 2427, check)
      call createCurrent(P_ghWp, P_WMinus, P_WPlus, P_ghWpAnti, 1551, check)
      call createCurrent(P_ZQ, P_H, P_WPlus, P_GQMinus, 1680, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_G0, 1149, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 2389, check)
      call createCurrent(P_HQ, P_ghZ, P_H, P_ghZAnti, 604, check)
      call createCurrent(P_WMinus, P_ghWp, P_A, P_ghZAnti, 1446, check)
      call createCurrent(P_tAnti, P_g, P_t, 875, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 1229, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_WPlus, P_ghZ, 3024, check)
      call createCurrent(P_HQ, P_Z, P_GQ0, 1145, check)
      call createCurrent(P_AQ, P_WMinus, P_WPlus, P_AQ, 1834, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZ, P_ghZAnti, 3034, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghA, P_WQPlus, 1921, check)
      call createCurrent(P_g, P_uAnti, P_u, 3345, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_Z, P_ghWp, 665, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_ghA, 3014, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 2019, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 1200, check)
      call createCurrent(P_b, P_bAnti, P_ZQ, 2983, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, P_Z, 3729, check)
      call createCurrent(P_GQMinus, P_GPlus, P_H, P_GQ0, 698, check)
      call createCurrent(P_u, P_uAnti, P_A, 455, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_A, P_ghWp, 2037, check)
      call createCurrent(P_HQ, P_WMinus, P_Z, P_GQPlus, 394, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_ZQ, 3156, check)
      call createCurrent(P_c, P_cAnti, P_ZQ, 2411, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 378, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_GQMinus, 3068, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 3333, check)
      call createCurrent(P_Z, P_ghWpAnti, P_WPlus, P_ghA, 53, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_HQ, 2511, check)
      call createCurrent(P_ghZ, P_GMinus, P_H, P_ghWmAnti, 2229, check)
      call createCurrent(P_GQ0, P_GPlus, P_GMinus, P_GQ0, 575, check)
      call createCurrent(P_GQ0, P_G0, P_ghWmAnti, P_ghWm, 506, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 2584, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 3938, check)
      call createCurrent(P_GMinus, P_ghWm, P_GPlus, P_ghWmAnti, 259, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, P_H, 247, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_WMinus, P_ghWp, 1919, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 2078, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_HQ, 1170, check)
      call createCurrent(P_G0, P_ghWpAnti, P_GPlus, P_ghZ, 983, check)
      call createCurrent(P_GPlus, P_ghZ, P_G0, P_ghWpAnti, 218, check)
      call createCurrent(P_GMinus, P_G0, P_ghAAnti, P_ghWp, 420, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghA, P_WQMinus, 3234, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 3392, check)
      call createCurrent(P_HQ, P_G0, P_H, P_GQ0, 151, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, 3728, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_H, P_ghA, 1058, check)
      call createCurrent(P_WPlus, P_ghWm, P_A, P_ghZAnti, 1402, check)
      call createCurrent(P_ghZ, P_WMinus, P_WPlus, P_ghZAnti, 2258, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_H, 3338, check)
      call createCurrent(P_HQ, P_WPlus, P_A, P_GQMinus, 2614, check)
      call createCurrent(P_WQPlus, P_b, P_tAnti, 3564, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, P_H, 2141, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghAAnti, P_ghZ, 525, check)
      call createCurrent(P_GQMinus, P_GMinus, P_GPlus, P_GQPlus, 1063, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_A, P_WQMinus, 329, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_WMinus, P_ghZ, 1785, check)
      call createCurrent(P_GQMinus, P_H, P_ghZ, P_ghWmAnti, 2710, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, 3630, check)
      call createCurrent(P_HQ, P_GMinus, P_WQPlus, 44, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_A, P_ghWm, 219, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_H, P_GMinus, 62, check)
      call createCurrent(P_tAnti, P_t, P_HQ, 3101, check)
      call createCurrent(P_t, P_bAnti, P_WQMinus, 3353, check)
      call createCurrent(P_c, P_cAnti, P_A, 2920, check)
      call createCurrent(P_AQ, P_WPlus, P_WMinus, P_ZQ, 704, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_ghWp, 1554, check)
      call createCurrent(P_G0, P_ghZ, P_ghWmAnti, P_GMinus, 3463, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 4004, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_H, P_GMinus, 2971, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 2921, check)
      call createCurrent(P_AQ, P_GMinus, P_GPlus, P_AQ, 964, check)
      call createCurrent(P_GQ0, P_GMinus, P_Z, P_WQPlus, 3282, check)
      call createCurrent(P_g, P_g, P_A, P_A, 3958, check)
      call createCurrent(P_A, P_WPlus, P_ghZAnti, P_ghWm, 2870, check)
      call createCurrent(P_ghWmAnti, P_Z, P_WMinus, P_ghZ, 812, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_A, P_WMinus, 2519, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 379, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(11)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(12)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(23)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(32)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(33)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(35)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(36)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(38)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(40)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(41)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(65)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(66)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(67)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(69)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(71)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(75)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(76)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(77)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(78)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(82)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(83)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(89)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(90)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(93)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(100)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(101)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(104)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(105)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
